use nalgebra::{Matrix3, Vector3};

use super::hall_symbol_database::HallNumber;

pub struct WyckoffPositionSpace {
    pub linear: Matrix3<i32>,
    pub origin: Vector3<f64>,
}

impl WyckoffPositionSpace {
    // Parse short-hand notation
    // EBNF for Wyckoff coordinates is as follows (we always ignore space):
    //     <shorthand>   ::= <term>, <term>, <term>
    //     <term>        ::= "-"?<factor> ([+-]<factor>)* ([+-]<translation>)?
    //     <factor>      ::= <integer>? <variable>
    //     <variable>    ::= "x" || "y" || "z"
    //     <translation> ::= <integer> ("/" <integer>)?
    //     <integer>     ::= ("0" || "1" || "2" || "3" || "4" || "5" || "6" || "7" || "8" || "9")+
    pub fn new(coordinates: &str) -> Self {
        let coordinates = coordinates.replace(' ', "");
        let terms = coordinates.split(',').collect::<Vec<_>>();
        assert_eq!(terms.len(), 3);

        let mut linear = Matrix3::zeros();
        let mut origin = Vector3::zeros();
        let variables = ['x', 'y', 'z'];
        for (i, term) in terms.iter().enumerate() {
            let mut tokens_with_sign = vec![]; // like [(-1, "y"), (1, "2x"), (-1, "1/2")]
            let mut sign = 1;
            let mut token = vec![];
            for c in term.chars() {
                if c == '+' {
                    assert!(!token.is_empty());
                    tokens_with_sign.push((sign, token.clone().into_iter().collect::<String>()));
                    sign = 1;
                    token.clear();
                } else if c == '-' {
                    if !token.is_empty() {
                        tokens_with_sign
                            .push((sign, token.clone().into_iter().collect::<String>()));
                        token.clear();
                    }
                    sign = -1;
                } else {
                    token.push(c);
                }
            }
            if !token.is_empty() {
                tokens_with_sign.push((sign, token.clone().into_iter().collect::<String>()));
            }

            for (sign, token) in tokens_with_sign {
                if token.chars().last().unwrap().is_ascii_digit() {
                    // translation case
                    let nums = token.split('/').collect::<Vec<_>>();
                    if nums.len() == 1 {
                        origin[i] += (sign as f64) * token.parse::<f64>().unwrap();
                    } else {
                        let numerator = nums[0].parse::<f64>().unwrap();
                        let denominator = nums[1].parse::<f64>().unwrap();
                        origin[i] += (sign as f64) * numerator / denominator;
                    }
                } else {
                    // variable case
                    for j in 0..3 {
                        if token.chars().last().unwrap() != variables[j] {
                            continue;
                        }
                        let coeff = if token.chars().count() - 1 == 0 {
                            1
                        } else {
                            token[..token.len() - 1].parse::<i32>().unwrap()
                        };
                        linear[(i, j)] += sign * coeff;
                    }
                }
            }
        }

        Self { linear, origin }
    }
}

#[derive(Debug, Clone)]
pub struct WyckoffPosition {
    pub hall_number: HallNumber,
    /// Multiplicity in conventional cell
    pub multiplicity: usize,
    /// Wyckoff letter
    pub letter: char,
    pub site_symmetry: &'static str,
    pub coordinates: &'static str,
}

impl WyckoffPosition {
    const fn new(
        hall_number: HallNumber,
        multiplicity: usize,
        letter: char,
        site_symmetry: &'static str,
        coordinates: &'static str,
    ) -> Self {
        Self {
            hall_number,
            multiplicity,
            letter,
            site_symmetry,
            coordinates,
        }
    }
}

pub fn iter_wyckoff_positions(
    hall_number: HallNumber,
    multiplicity: usize,
) -> impl Iterator<Item = &'static WyckoffPosition> {
    WYCKOFF_DATABASE
        .iter()
        .filter(move |wp| wp.hall_number == hall_number && wp.multiplicity == multiplicity)
}

const WYCKOFF_DATABASE: [WyckoffPosition; 3467] = [
    WyckoffPosition::new(1, 1, 'a', "1", "x,y,z"),
    WyckoffPosition::new(2, 2, 'i', "1", "x,y,z"),
    WyckoffPosition::new(2, 1, 'h', "-1", "1/2,1/2,1/2"),
    WyckoffPosition::new(2, 1, 'g', "-1", "0,1/2,1/2"),
    WyckoffPosition::new(2, 1, 'f', "-1", "1/2,0,1/2"),
    WyckoffPosition::new(2, 1, 'e', "-1", "1/2,1/2,0"),
    WyckoffPosition::new(2, 1, 'd', "-1", "1/2,0,0"),
    WyckoffPosition::new(2, 1, 'c', "-1", "0,1/2,0"),
    WyckoffPosition::new(2, 1, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(2, 1, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(3, 2, 'e', "1", "x,y,z"),
    WyckoffPosition::new(3, 1, 'd', "2", "1/2,y,1/2"),
    WyckoffPosition::new(3, 1, 'c', "2", "1/2,y,0"),
    WyckoffPosition::new(3, 1, 'b', "2", "0,y,1/2"),
    WyckoffPosition::new(3, 1, 'a', "2", "0,y,0"),
    WyckoffPosition::new(4, 2, 'e', "1", "x,y,z"),
    WyckoffPosition::new(4, 1, 'd', "2", "1/2,1/2,z"),
    WyckoffPosition::new(4, 1, 'c', "2", "0,1/2,z"),
    WyckoffPosition::new(4, 1, 'b', "2", "1/2,0,z"),
    WyckoffPosition::new(4, 1, 'a', "2", "0,0,z"),
    WyckoffPosition::new(5, 2, 'e', "1", "x,y,z"),
    WyckoffPosition::new(5, 1, 'd', "2", "x,1/2,1/2"),
    WyckoffPosition::new(5, 1, 'c', "2", "x,0,1/2"),
    WyckoffPosition::new(5, 1, 'b', "2", "x,1/2,0"),
    WyckoffPosition::new(5, 1, 'a', "2", "x,0,0"),
    WyckoffPosition::new(6, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(7, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(8, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(9, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(9, 2, 'b', "2", "0,y,1/2"),
    WyckoffPosition::new(9, 2, 'a', "2", "0,y,0"),
    WyckoffPosition::new(10, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(10, 2, 'b', "2", "1/2,y,0"),
    WyckoffPosition::new(10, 2, 'a', "2", "0,y,0"),
    WyckoffPosition::new(11, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(11, 2, 'b', "2", "1/2,y,0"),
    WyckoffPosition::new(11, 2, 'a', "2", "0,y,0"),
    WyckoffPosition::new(12, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(12, 2, 'b', "2", "1/2,0,z"),
    WyckoffPosition::new(12, 2, 'a', "2", "0,0,z"),
    WyckoffPosition::new(13, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(13, 2, 'b', "2", "0,1/2,z"),
    WyckoffPosition::new(13, 2, 'a', "2", "0,0,z"),
    WyckoffPosition::new(14, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(14, 2, 'b', "2", "0,1/2,z"),
    WyckoffPosition::new(14, 2, 'a', "2", "0,0,z"),
    WyckoffPosition::new(15, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(15, 2, 'b', "2", "x,1/2,0"),
    WyckoffPosition::new(15, 2, 'a', "2", "x,0,0"),
    WyckoffPosition::new(16, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(16, 2, 'b', "2", "x,0,1/2"),
    WyckoffPosition::new(16, 2, 'a', "2", "x,0,0"),
    WyckoffPosition::new(17, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(17, 2, 'b', "2", "x,0,1/2"),
    WyckoffPosition::new(17, 2, 'a', "2", "x,0,0"),
    WyckoffPosition::new(18, 2, 'c', "1", "x,y,z"),
    WyckoffPosition::new(18, 1, 'b', "m", "x,1/2,z"),
    WyckoffPosition::new(18, 1, 'a', "m", "x,0,z"),
    WyckoffPosition::new(19, 2, 'c', "1", "x,y,z"),
    WyckoffPosition::new(19, 1, 'b', "m", "x,y,1/2"),
    WyckoffPosition::new(19, 1, 'a', "m", "x,y,0"),
    WyckoffPosition::new(20, 2, 'c', "1", "x,y,z"),
    WyckoffPosition::new(20, 1, 'b', "m", "1/2,y,z"),
    WyckoffPosition::new(20, 1, 'a', "m", "0,y,z"),
    WyckoffPosition::new(21, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(22, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(23, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(24, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(25, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(26, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(27, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(28, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(29, 2, 'a', "1", "x,y,z"),
    WyckoffPosition::new(30, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(30, 2, 'a', "m", "x,0,z"),
    WyckoffPosition::new(31, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(31, 2, 'a', "m", "x,0,z"),
    WyckoffPosition::new(32, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(32, 2, 'a', "m", "x,0,z"),
    WyckoffPosition::new(33, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(33, 2, 'a', "m", "x,y,0"),
    WyckoffPosition::new(34, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(34, 2, 'a', "m", "x,y,0"),
    WyckoffPosition::new(35, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(35, 2, 'a', "m", "x,y,0"),
    WyckoffPosition::new(36, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(36, 2, 'a', "m", "0,y,z"),
    WyckoffPosition::new(37, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(37, 2, 'a', "m", "0,y,z"),
    WyckoffPosition::new(38, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(38, 2, 'a', "m", "0,y,z"),
    WyckoffPosition::new(39, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(40, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(41, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(42, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(43, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(44, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(45, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(46, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(47, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(48, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(49, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(50, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(51, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(52, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(53, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(54, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(55, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(56, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(57, 4, 'o', "1", "x,y,z"),
    WyckoffPosition::new(57, 2, 'n', "m", "x,1/2,z"),
    WyckoffPosition::new(57, 2, 'm', "m", "x,0,z"),
    WyckoffPosition::new(57, 2, 'l', "2", "1/2,y,1/2"),
    WyckoffPosition::new(57, 2, 'k', "2", "0,y,1/2"),
    WyckoffPosition::new(57, 2, 'j', "2", "1/2,y,0"),
    WyckoffPosition::new(57, 2, 'i', "2", "0,y,0"),
    WyckoffPosition::new(57, 1, 'h', "2/m", "1/2,1/2,1/2"),
    WyckoffPosition::new(57, 1, 'g', "2/m", "1/2,0,1/2"),
    WyckoffPosition::new(57, 1, 'f', "2/m", "0,1/2,1/2"),
    WyckoffPosition::new(57, 1, 'e', "2/m", "1/2,1/2,0"),
    WyckoffPosition::new(57, 1, 'd', "2/m", "1/2,0,0"),
    WyckoffPosition::new(57, 1, 'c', "2/m", "0,0,1/2"),
    WyckoffPosition::new(57, 1, 'b', "2/m", "0,1/2,0"),
    WyckoffPosition::new(57, 1, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(58, 4, 'o', "1", "x,y,z"),
    WyckoffPosition::new(58, 2, 'n', "m", "x,y,1/2"),
    WyckoffPosition::new(58, 2, 'm', "m", "x,y,0"),
    WyckoffPosition::new(58, 2, 'l', "2", "1/2,1/2,z"),
    WyckoffPosition::new(58, 2, 'k', "2", "1/2,0,z"),
    WyckoffPosition::new(58, 2, 'j', "2", "0,1/2,z"),
    WyckoffPosition::new(58, 2, 'i', "2", "0,0,z"),
    WyckoffPosition::new(58, 1, 'h', "2/m", "1/2,1/2,1/2"),
    WyckoffPosition::new(58, 1, 'g', "2/m", "1/2,1/2,0"),
    WyckoffPosition::new(58, 1, 'f', "2/m", "1/2,0,1/2"),
    WyckoffPosition::new(58, 1, 'e', "2/m", "0,1/2,1/2"),
    WyckoffPosition::new(58, 1, 'd', "2/m", "0,1/2,0"),
    WyckoffPosition::new(58, 1, 'c', "2/m", "1/2,0,0"),
    WyckoffPosition::new(58, 1, 'b', "2/m", "0,0,1/2"),
    WyckoffPosition::new(58, 1, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(59, 4, 'o', "1", "x,y,z"),
    WyckoffPosition::new(59, 2, 'n', "m", "1/2,y,z"),
    WyckoffPosition::new(59, 2, 'm', "m", "0,y,z"),
    WyckoffPosition::new(59, 2, 'l', "2", "x,1/2,1/2"),
    WyckoffPosition::new(59, 2, 'k', "2", "x,1/2,0"),
    WyckoffPosition::new(59, 2, 'j', "2", "x,0,1/2"),
    WyckoffPosition::new(59, 2, 'i', "2", "x,0,0"),
    WyckoffPosition::new(59, 1, 'h', "2/m", "1/2,1/2,1/2"),
    WyckoffPosition::new(59, 1, 'g', "2/m", "0,1/2,1/2"),
    WyckoffPosition::new(59, 1, 'f', "2/m", "1/2,1/2,0"),
    WyckoffPosition::new(59, 1, 'e', "2/m", "1/2,0,1/2"),
    WyckoffPosition::new(59, 1, 'd', "2/m", "0,0,1/2"),
    WyckoffPosition::new(59, 1, 'c', "2/m", "0,1/2,0"),
    WyckoffPosition::new(59, 1, 'b', "2/m", "1/2,0,0"),
    WyckoffPosition::new(59, 1, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(60, 4, 'f', "1", "x,y,z"),
    WyckoffPosition::new(60, 2, 'e', "m", "x,1/4,z"),
    WyckoffPosition::new(60, 2, 'd', "-1", "1/2,0,1/2"),
    WyckoffPosition::new(60, 2, 'c', "-1", "0,0,1/2"),
    WyckoffPosition::new(60, 2, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(60, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(61, 4, 'f', "1", "x,y,z"),
    WyckoffPosition::new(61, 2, 'e', "m", "x,y,1/4"),
    WyckoffPosition::new(61, 2, 'd', "-1", "1/2,1/2,0"),
    WyckoffPosition::new(61, 2, 'c', "-1", "1/2,0,0"),
    WyckoffPosition::new(61, 2, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(61, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(62, 4, 'f', "1", "x,y,z"),
    WyckoffPosition::new(62, 2, 'e', "m", "1/4,y,z"),
    WyckoffPosition::new(62, 2, 'd', "-1", "0,1/2,1/2"),
    WyckoffPosition::new(62, 2, 'c', "-1", "0,1/2,0"),
    WyckoffPosition::new(62, 2, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(62, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(63, 8, 'j', "1", "x,y,z"),
    WyckoffPosition::new(63, 4, 'i', "m", "x,0,z"),
    WyckoffPosition::new(63, 4, 'h', "2", "0,y,1/2"),
    WyckoffPosition::new(63, 4, 'g', "2", "0,y,0"),
    WyckoffPosition::new(63, 4, 'f', "-1", "1/4,1/4,1/2"),
    WyckoffPosition::new(63, 4, 'e', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(63, 2, 'd', "2/m", "0,1/2,1/2"),
    WyckoffPosition::new(63, 2, 'c', "2/m", "0,0,1/2"),
    WyckoffPosition::new(63, 2, 'b', "2/m", "0,1/2,0"),
    WyckoffPosition::new(63, 2, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(64, 8, 'j', "1", "x,y,z"),
    WyckoffPosition::new(64, 4, 'i', "m", "x,0,z"),
    WyckoffPosition::new(64, 4, 'h', "2", "1/2,y,0"),
    WyckoffPosition::new(64, 4, 'g', "2", "0,y,0"),
    WyckoffPosition::new(64, 4, 'f', "-1", "1/2,1/4,1/4"),
    WyckoffPosition::new(64, 4, 'e', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(64, 2, 'd', "2/m", "1/2,1/2,0"),
    WyckoffPosition::new(64, 2, 'c', "2/m", "1/2,0,0"),
    WyckoffPosition::new(64, 2, 'b', "2/m", "0,1/2,0"),
    WyckoffPosition::new(64, 2, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(65, 8, 'j', "1", "x,y,z"),
    WyckoffPosition::new(65, 4, 'i', "m", "x,0,z"),
    WyckoffPosition::new(65, 4, 'h', "2", "0,y,1/2"),
    WyckoffPosition::new(65, 4, 'g', "2", "0,y,0"),
    WyckoffPosition::new(65, 4, 'f', "-1", "1/4,1/4,3/4"),
    WyckoffPosition::new(65, 4, 'e', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(65, 2, 'd', "2/m", "0,1/2,1/2"),
    WyckoffPosition::new(65, 2, 'c', "2/m", "0,0,1/2"),
    WyckoffPosition::new(65, 2, 'b', "2/m", "0,1/2,0"),
    WyckoffPosition::new(65, 2, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(66, 8, 'j', "1", "x,y,z"),
    WyckoffPosition::new(66, 4, 'i', "m", "x,y,0"),
    WyckoffPosition::new(66, 4, 'h', "2", "1/2,0,z"),
    WyckoffPosition::new(66, 4, 'g', "2", "0,0,z"),
    WyckoffPosition::new(66, 4, 'f', "-1", "1/2,1/4,1/4"),
    WyckoffPosition::new(66, 4, 'e', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(66, 2, 'd', "2/m", "1/2,0,1/2"),
    WyckoffPosition::new(66, 2, 'c', "2/m", "1/2,0,0"),
    WyckoffPosition::new(66, 2, 'b', "2/m", "0,0,1/2"),
    WyckoffPosition::new(66, 2, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(67, 8, 'j', "1", "x,y,z"),
    WyckoffPosition::new(67, 4, 'i', "m", "x,y,0"),
    WyckoffPosition::new(67, 4, 'h', "2", "0,1/2,z"),
    WyckoffPosition::new(67, 4, 'g', "2", "0,0,z"),
    WyckoffPosition::new(67, 4, 'f', "-1", "1/4,1/2,1/4"),
    WyckoffPosition::new(67, 4, 'e', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(67, 2, 'd', "2/m", "0,1/2,1/2"),
    WyckoffPosition::new(67, 2, 'c', "2/m", "0,1/2,0"),
    WyckoffPosition::new(67, 2, 'b', "2/m", "0,0,1/2"),
    WyckoffPosition::new(67, 2, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(68, 8, 'j', "1", "x,y,z"),
    WyckoffPosition::new(68, 4, 'i', "m", "x,y,0"),
    WyckoffPosition::new(68, 4, 'h', "2", "1/2,0,z"),
    WyckoffPosition::new(68, 4, 'g', "2", "0,0,z"),
    WyckoffPosition::new(68, 4, 'f', "-1", "3/4,1/4,1/4"),
    WyckoffPosition::new(68, 4, 'e', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(68, 2, 'd', "2/m", "1/2,0,1/2"),
    WyckoffPosition::new(68, 2, 'c', "2/m", "1/2,0,0"),
    WyckoffPosition::new(68, 2, 'b', "2/m", "0,0,1/2"),
    WyckoffPosition::new(68, 2, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(69, 8, 'j', "1", "x,y,z"),
    WyckoffPosition::new(69, 4, 'i', "m", "0,y,z"),
    WyckoffPosition::new(69, 4, 'h', "2", "x,1/2,0"),
    WyckoffPosition::new(69, 4, 'g', "2", "x,0,0"),
    WyckoffPosition::new(69, 4, 'f', "-1", "1/4,1/2,1/4"),
    WyckoffPosition::new(69, 4, 'e', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(69, 2, 'd', "2/m", "1/2,1/2,0"),
    WyckoffPosition::new(69, 2, 'c', "2/m", "0,1/2,0"),
    WyckoffPosition::new(69, 2, 'b', "2/m", "1/2,0,0"),
    WyckoffPosition::new(69, 2, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(70, 8, 'j', "1", "x,y,z"),
    WyckoffPosition::new(70, 4, 'i', "m", "0,y,z"),
    WyckoffPosition::new(70, 4, 'h', "2", "x,0,1/2"),
    WyckoffPosition::new(70, 4, 'g', "2", "x,0,0"),
    WyckoffPosition::new(70, 4, 'f', "-1", "1/4,1/4,1/2"),
    WyckoffPosition::new(70, 4, 'e', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(70, 2, 'd', "2/m", "1/2,0,1/2"),
    WyckoffPosition::new(70, 2, 'c', "2/m", "0,0,1/2"),
    WyckoffPosition::new(70, 2, 'b', "2/m", "1/2,0,0"),
    WyckoffPosition::new(70, 2, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(71, 8, 'j', "1", "x,y,z"),
    WyckoffPosition::new(71, 4, 'i', "m", "0,y,z"),
    WyckoffPosition::new(71, 4, 'h', "2", "x,1/2,0"),
    WyckoffPosition::new(71, 4, 'g', "2", "x,0,0"),
    WyckoffPosition::new(71, 4, 'f', "-1", "1/4,3/4,1/4"),
    WyckoffPosition::new(71, 4, 'e', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(71, 2, 'd', "2/m", "1/2,1/2,0"),
    WyckoffPosition::new(71, 2, 'c', "2/m", "0,1/2,0"),
    WyckoffPosition::new(71, 2, 'b', "2/m", "1/2,0,0"),
    WyckoffPosition::new(71, 2, 'a', "2/m", "0,0,0"),
    WyckoffPosition::new(72, 4, 'g', "1", "x,y,z"),
    WyckoffPosition::new(72, 2, 'f', "2", "1/2,y,1/4"),
    WyckoffPosition::new(72, 2, 'e', "2", "0,y,1/4"),
    WyckoffPosition::new(72, 2, 'd', "-1", "1/2,0,0"),
    WyckoffPosition::new(72, 2, 'c', "-1", "0,1/2,0"),
    WyckoffPosition::new(72, 2, 'b', "-1", "1/2,1/2,0"),
    WyckoffPosition::new(72, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(73, 4, 'g', "1", "x,y,z"),
    WyckoffPosition::new(73, 2, 'f', "2", "3/4,y,1/4"),
    WyckoffPosition::new(73, 2, 'e', "2", "1/4,y,1/4"),
    WyckoffPosition::new(73, 2, 'd', "-1", "1/2,0,0"),
    WyckoffPosition::new(73, 2, 'c', "-1", "0,1/2,0"),
    WyckoffPosition::new(73, 2, 'b', "-1", "1/2,1/2,0"),
    WyckoffPosition::new(73, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(74, 4, 'g', "1", "x,y,z"),
    WyckoffPosition::new(74, 2, 'f', "2", "3/4,y,1/2"),
    WyckoffPosition::new(74, 2, 'e', "2", "3/4,y,0"),
    WyckoffPosition::new(74, 2, 'd', "-1", "0,0,1/2"),
    WyckoffPosition::new(74, 2, 'c', "-1", "0,1/2,0"),
    WyckoffPosition::new(74, 2, 'b', "-1", "0,1/2,1/2"),
    WyckoffPosition::new(74, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(75, 4, 'g', "1", "x,y,z"),
    WyckoffPosition::new(75, 2, 'f', "2", "1/4,1/2,z"),
    WyckoffPosition::new(75, 2, 'e', "2", "1/4,0,z"),
    WyckoffPosition::new(75, 2, 'd', "-1", "0,1/2,0"),
    WyckoffPosition::new(75, 2, 'c', "-1", "0,0,1/2"),
    WyckoffPosition::new(75, 2, 'b', "-1", "0,1/2,1/2"),
    WyckoffPosition::new(75, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(76, 4, 'g', "1", "x,y,z"),
    WyckoffPosition::new(76, 2, 'f', "2", "1/4,3/4,z"),
    WyckoffPosition::new(76, 2, 'e', "2", "1/4,1/4,z"),
    WyckoffPosition::new(76, 2, 'd', "-1", "0,1/2,0"),
    WyckoffPosition::new(76, 2, 'c', "-1", "0,0,1/2"),
    WyckoffPosition::new(76, 2, 'b', "-1", "0,1/2,1/2"),
    WyckoffPosition::new(76, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(77, 4, 'g', "1", "x,y,z"),
    WyckoffPosition::new(77, 2, 'f', "2", "1/2,3/4,z"),
    WyckoffPosition::new(77, 2, 'e', "2", "0,3/4,z"),
    WyckoffPosition::new(77, 2, 'd', "-1", "1/2,0,0"),
    WyckoffPosition::new(77, 2, 'c', "-1", "0,0,1/2"),
    WyckoffPosition::new(77, 2, 'b', "-1", "1/2,0,1/2"),
    WyckoffPosition::new(77, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(78, 4, 'g', "1", "x,y,z"),
    WyckoffPosition::new(78, 2, 'f', "2", "x,1/4,1/2"),
    WyckoffPosition::new(78, 2, 'e', "2", "x,1/4,0"),
    WyckoffPosition::new(78, 2, 'd', "-1", "0,0,1/2"),
    WyckoffPosition::new(78, 2, 'c', "-1", "1/2,0,0"),
    WyckoffPosition::new(78, 2, 'b', "-1", "1/2,0,1/2"),
    WyckoffPosition::new(78, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(79, 4, 'g', "1", "x,y,z"),
    WyckoffPosition::new(79, 2, 'f', "2", "x,1/4,3/4"),
    WyckoffPosition::new(79, 2, 'e', "2", "x,1/4,1/4"),
    WyckoffPosition::new(79, 2, 'd', "-1", "0,0,1/2"),
    WyckoffPosition::new(79, 2, 'c', "-1", "1/2,0,0"),
    WyckoffPosition::new(79, 2, 'b', "-1", "1/2,0,1/2"),
    WyckoffPosition::new(79, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(80, 4, 'g', "1", "x,y,z"),
    WyckoffPosition::new(80, 2, 'f', "2", "x,1/2,3/4"),
    WyckoffPosition::new(80, 2, 'e', "2", "x,0,3/4"),
    WyckoffPosition::new(80, 2, 'd', "-1", "0,1/2,0"),
    WyckoffPosition::new(80, 2, 'c', "-1", "1/2,0,0"),
    WyckoffPosition::new(80, 2, 'b', "-1", "1/2,1/2,0"),
    WyckoffPosition::new(80, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(81, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(81, 2, 'd', "-1", "1/2,0,1/2"),
    WyckoffPosition::new(81, 2, 'c', "-1", "0,0,1/2"),
    WyckoffPosition::new(81, 2, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(81, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(82, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(82, 2, 'd', "-1", "0,0,1/2"),
    WyckoffPosition::new(82, 2, 'c', "-1", "1/2,0,1/2"),
    WyckoffPosition::new(82, 2, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(82, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(83, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(83, 2, 'd', "-1", "1/2,0,1/2"),
    WyckoffPosition::new(83, 2, 'c', "-1", "1/2,0,0"),
    WyckoffPosition::new(83, 2, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(83, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(84, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(84, 2, 'd', "-1", "1/2,1/2,0"),
    WyckoffPosition::new(84, 2, 'c', "-1", "1/2,0,0"),
    WyckoffPosition::new(84, 2, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(84, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(85, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(85, 2, 'd', "-1", "1/2,0,0"),
    WyckoffPosition::new(85, 2, 'c', "-1", "1/2,1/2,0"),
    WyckoffPosition::new(85, 2, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(85, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(86, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(86, 2, 'd', "-1", "1/2,1/2,0"),
    WyckoffPosition::new(86, 2, 'c', "-1", "0,1/2,0"),
    WyckoffPosition::new(86, 2, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(86, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(87, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(87, 2, 'd', "-1", "0,1/2,1/2"),
    WyckoffPosition::new(87, 2, 'c', "-1", "0,1/2,0"),
    WyckoffPosition::new(87, 2, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(87, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(88, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(88, 2, 'd', "-1", "0,1/2,0"),
    WyckoffPosition::new(88, 2, 'c', "-1", "0,1/2,1/2"),
    WyckoffPosition::new(88, 2, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(88, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(89, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(89, 2, 'd', "-1", "0,1/2,1/2"),
    WyckoffPosition::new(89, 2, 'c', "-1", "0,0,1/2"),
    WyckoffPosition::new(89, 2, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(89, 2, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(90, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(90, 4, 'e', "2", "0,y,1/4"),
    WyckoffPosition::new(90, 4, 'd', "-1", "1/4,1/4,1/2"),
    WyckoffPosition::new(90, 4, 'c', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(90, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(90, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(91, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(91, 4, 'e', "2", "1/4,y,1/4"),
    WyckoffPosition::new(91, 4, 'd', "-1", "1/2,3/4,3/4"),
    WyckoffPosition::new(91, 4, 'c', "-1", "0,3/4,1/4"),
    WyckoffPosition::new(91, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(91, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(92, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(92, 4, 'e', "2", "1/4,y,0"),
    WyckoffPosition::new(92, 4, 'd', "-1", "3/4,3/4,1/4"),
    WyckoffPosition::new(92, 4, 'c', "-1", "1/4,3/4,1/4"),
    WyckoffPosition::new(92, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(92, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(93, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(93, 4, 'e', "2", "3/4,y,0"),
    WyckoffPosition::new(93, 4, 'd', "-1", "1/2,1/4,1/4"),
    WyckoffPosition::new(93, 4, 'c', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(93, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(93, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(94, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(94, 4, 'e', "2", "1/4,y,1/4"),
    WyckoffPosition::new(94, 4, 'd', "-1", "3/4,1/4,1/2"),
    WyckoffPosition::new(94, 4, 'c', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(94, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(94, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(95, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(95, 4, 'e', "2", "0,y,1/4"),
    WyckoffPosition::new(95, 4, 'd', "-1", "1/4,1/4,3/4"),
    WyckoffPosition::new(95, 4, 'c', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(95, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(95, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(96, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(96, 4, 'e', "2", "1/4,0,z"),
    WyckoffPosition::new(96, 4, 'd', "-1", "1/2,1/4,1/4"),
    WyckoffPosition::new(96, 4, 'c', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(96, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(96, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(97, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(97, 4, 'e', "2", "1/4,1/4,z"),
    WyckoffPosition::new(97, 4, 'd', "-1", "3/4,1/2,3/4"),
    WyckoffPosition::new(97, 4, 'c', "-1", "1/4,0,3/4"),
    WyckoffPosition::new(97, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(97, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(98, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(98, 4, 'e', "2", "0,1/4,z"),
    WyckoffPosition::new(98, 4, 'd', "-1", "1/4,3/4,3/4"),
    WyckoffPosition::new(98, 4, 'c', "-1", "1/4,1/4,3/4"),
    WyckoffPosition::new(98, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(98, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(99, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(99, 4, 'e', "2", "0,3/4,z"),
    WyckoffPosition::new(99, 4, 'd', "-1", "1/4,1/2,1/4"),
    WyckoffPosition::new(99, 4, 'c', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(99, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(99, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(100, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(100, 4, 'e', "2", "1/4,1/4,z"),
    WyckoffPosition::new(100, 4, 'd', "-1", "1/2,3/4,1/4"),
    WyckoffPosition::new(100, 4, 'c', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(100, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(100, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(101, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(101, 4, 'e', "2", "1/4,0,z"),
    WyckoffPosition::new(101, 4, 'd', "-1", "3/4,1/4,1/4"),
    WyckoffPosition::new(101, 4, 'c', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(101, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(101, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(102, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(102, 4, 'e', "2", "x,1/4,0"),
    WyckoffPosition::new(102, 4, 'd', "-1", "1/4,1/2,1/4"),
    WyckoffPosition::new(102, 4, 'c', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(102, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(102, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(103, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(103, 4, 'e', "2", "x,1/4,1/4"),
    WyckoffPosition::new(103, 4, 'd', "-1", "3/4,3/4,1/2"),
    WyckoffPosition::new(103, 4, 'c', "-1", "3/4,1/4,0"),
    WyckoffPosition::new(103, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(103, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(104, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(104, 4, 'e', "2", "x,0,1/4"),
    WyckoffPosition::new(104, 4, 'd', "-1", "3/4,1/4,3/4"),
    WyckoffPosition::new(104, 4, 'c', "-1", "3/4,1/4,1/4"),
    WyckoffPosition::new(104, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(104, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(105, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(105, 4, 'e', "2", "x,0,3/4"),
    WyckoffPosition::new(105, 4, 'd', "-1", "1/4,1/4,1/2"),
    WyckoffPosition::new(105, 4, 'c', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(105, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(105, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(106, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(106, 4, 'e', "2", "x,1/4,1/4"),
    WyckoffPosition::new(106, 4, 'd', "-1", "1/4,1/2,3/4"),
    WyckoffPosition::new(106, 4, 'c', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(106, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(106, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(107, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(107, 4, 'e', "2", "x,1/4,0"),
    WyckoffPosition::new(107, 4, 'd', "-1", "1/4,3/4,1/4"),
    WyckoffPosition::new(107, 4, 'c', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(107, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(107, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(108, 4, 'u', "1", "x,y,z"),
    WyckoffPosition::new(108, 2, 't', "..2", "1/2,1/2,z"),
    WyckoffPosition::new(108, 2, 's', "..2", "0,1/2,z"),
    WyckoffPosition::new(108, 2, 'r', "..2", "1/2,0,z"),
    WyckoffPosition::new(108, 2, 'q', "..2", "0,0,z"),
    WyckoffPosition::new(108, 2, 'p', ".2.", "1/2,y,1/2"),
    WyckoffPosition::new(108, 2, 'o', ".2.", "1/2,y,0"),
    WyckoffPosition::new(108, 2, 'n', ".2.", "0,y,1/2"),
    WyckoffPosition::new(108, 2, 'm', ".2.", "0,y,0"),
    WyckoffPosition::new(108, 2, 'l', "2..", "x,1/2,1/2"),
    WyckoffPosition::new(108, 2, 'k', "2..", "x,1/2,0"),
    WyckoffPosition::new(108, 2, 'j', "2..", "x,0,1/2"),
    WyckoffPosition::new(108, 2, 'i', "2..", "x,0,0"),
    WyckoffPosition::new(108, 1, 'h', "222", "1/2,1/2,1/2"),
    WyckoffPosition::new(108, 1, 'g', "222", "0,1/2,1/2"),
    WyckoffPosition::new(108, 1, 'f', "222", "1/2,0,1/2"),
    WyckoffPosition::new(108, 1, 'e', "222", "1/2,1/2,0"),
    WyckoffPosition::new(108, 1, 'd', "222", "0,0,1/2"),
    WyckoffPosition::new(108, 1, 'c', "222", "0,1/2,0"),
    WyckoffPosition::new(108, 1, 'b', "222", "1/2,0,0"),
    WyckoffPosition::new(108, 1, 'a', "222", "0,0,0"),
    WyckoffPosition::new(109, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(109, 2, 'd', ".2.", "1/2,y,1/4"),
    WyckoffPosition::new(109, 2, 'c', ".2.", "0,y,1/4"),
    WyckoffPosition::new(109, 2, 'b', "2..", "x,1/2,0"),
    WyckoffPosition::new(109, 2, 'a', "2..", "x,0,0"),
    WyckoffPosition::new(110, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(110, 2, 'd', ".2.", "1/4,1/2,z"),
    WyckoffPosition::new(110, 2, 'c', ".2.", "1/4,0,z"),
    WyckoffPosition::new(110, 2, 'b', "2..", "0,y,1/2"),
    WyckoffPosition::new(110, 2, 'a', "2..", "0,y,0"),
    WyckoffPosition::new(111, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(111, 2, 'd', ".2.", "x,1/4,1/2"),
    WyckoffPosition::new(111, 2, 'c', ".2.", "x,1/4,0"),
    WyckoffPosition::new(111, 2, 'b', "2..", "1/2,0,z"),
    WyckoffPosition::new(111, 2, 'a', "2..", "0,0,z"),
    WyckoffPosition::new(112, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(112, 2, 'b', "..2", "0,1/2,z"),
    WyckoffPosition::new(112, 2, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(113, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(113, 2, 'b', "..2", "x,0,1/2"),
    WyckoffPosition::new(113, 2, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(114, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(114, 2, 'b', "..2", "1/2,y,0"),
    WyckoffPosition::new(114, 2, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(115, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(116, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(116, 4, 'b', ".2.", "0,y,1/4"),
    WyckoffPosition::new(116, 4, 'a', "2..", "x,0,0"),
    WyckoffPosition::new(117, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(117, 4, 'b', ".2.", "1/4,0,z"),
    WyckoffPosition::new(117, 4, 'a', "2..", "0,y,0"),
    WyckoffPosition::new(118, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(118, 4, 'b', ".2.", "x,1/4,0"),
    WyckoffPosition::new(118, 4, 'a', "2..", "0,0,z"),
    WyckoffPosition::new(119, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(119, 4, 'k', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(119, 4, 'j', "..2", "0,1/2,z"),
    WyckoffPosition::new(119, 4, 'i', "..2", "0,0,z"),
    WyckoffPosition::new(119, 4, 'h', ".2.", "0,y,1/2"),
    WyckoffPosition::new(119, 4, 'g', ".2.", "0,y,0"),
    WyckoffPosition::new(119, 4, 'f', "2..", "x,0,1/2"),
    WyckoffPosition::new(119, 4, 'e', "2..", "x,0,0"),
    WyckoffPosition::new(119, 2, 'd', "222", "0,0,1/2"),
    WyckoffPosition::new(119, 2, 'c', "222", "1/2,0,1/2"),
    WyckoffPosition::new(119, 2, 'b', "222", "0,1/2,0"),
    WyckoffPosition::new(119, 2, 'a', "222", "0,0,0"),
    WyckoffPosition::new(120, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(120, 4, 'k', "..2", "x,1/4,1/4"),
    WyckoffPosition::new(120, 4, 'j', "..2", "x,0,1/2"),
    WyckoffPosition::new(120, 4, 'i', "..2", "x,0,0"),
    WyckoffPosition::new(120, 4, 'h', ".2.", "1/2,0,z"),
    WyckoffPosition::new(120, 4, 'g', ".2.", "0,0,z"),
    WyckoffPosition::new(120, 4, 'f', "2..", "1/2,y,0"),
    WyckoffPosition::new(120, 4, 'e', "2..", "0,y,0"),
    WyckoffPosition::new(120, 2, 'd', "222", "1/2,0,0"),
    WyckoffPosition::new(120, 2, 'c', "222", "1/2,1/2,0"),
    WyckoffPosition::new(120, 2, 'b', "222", "0,0,1/2"),
    WyckoffPosition::new(120, 2, 'a', "222", "0,0,0"),
    WyckoffPosition::new(121, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(121, 4, 'k', "..2", "1/4,y,1/4"),
    WyckoffPosition::new(121, 4, 'j', "..2", "1/2,y,0"),
    WyckoffPosition::new(121, 4, 'i', "..2", "0,y,0"),
    WyckoffPosition::new(121, 4, 'h', ".2.", "x,1/2,0"),
    WyckoffPosition::new(121, 4, 'g', ".2.", "x,0,0"),
    WyckoffPosition::new(121, 4, 'f', "2..", "0,1/2,z"),
    WyckoffPosition::new(121, 4, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(121, 2, 'd', "222", "0,1/2,0"),
    WyckoffPosition::new(121, 2, 'c', "222", "0,1/2,1/2"),
    WyckoffPosition::new(121, 2, 'b', "222", "1/2,0,0"),
    WyckoffPosition::new(121, 2, 'a', "222", "0,0,0"),
    WyckoffPosition::new(122, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(122, 8, 'j', "2..", "x,1/4,1/4"),
    WyckoffPosition::new(122, 8, 'i', ".2.", "1/4,y,1/4"),
    WyckoffPosition::new(122, 8, 'h', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(122, 8, 'g', "..2", "0,0,z"),
    WyckoffPosition::new(122, 8, 'f', ".2.", "0,y,0"),
    WyckoffPosition::new(122, 8, 'e', "2..", "x,0,0"),
    WyckoffPosition::new(122, 4, 'd', "222", "1/4,1/4,3/4"),
    WyckoffPosition::new(122, 4, 'c', "222", "1/4,1/4,1/4"),
    WyckoffPosition::new(122, 4, 'b', "222", "0,0,1/2"),
    WyckoffPosition::new(122, 4, 'a', "222", "0,0,0"),
    WyckoffPosition::new(123, 8, 'k', "1", "x,y,z"),
    WyckoffPosition::new(123, 4, 'j', "..2", "0,1/2,z"),
    WyckoffPosition::new(123, 4, 'i', "..2", "0,0,z"),
    WyckoffPosition::new(123, 4, 'h', ".2.", "1/2,y,0"),
    WyckoffPosition::new(123, 4, 'g', ".2.", "0,y,0"),
    WyckoffPosition::new(123, 4, 'f', "2..", "x,0,1/2"),
    WyckoffPosition::new(123, 4, 'e', "2..", "x,0,0"),
    WyckoffPosition::new(123, 2, 'd', "222", "0,1/2,0"),
    WyckoffPosition::new(123, 2, 'c', "222", "0,0,1/2"),
    WyckoffPosition::new(123, 2, 'b', "222", "1/2,0,0"),
    WyckoffPosition::new(123, 2, 'a', "222", "0,0,0"),
    WyckoffPosition::new(124, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(124, 4, 'c', "..2", "0,1/4,z"),
    WyckoffPosition::new(124, 4, 'b', ".2.", "1/4,y,0"),
    WyckoffPosition::new(124, 4, 'a', "2..", "x,0,1/4"),
    WyckoffPosition::new(125, 4, 'i', "1", "x,y,z"),
    WyckoffPosition::new(125, 2, 'h', "m..", "1/2,y,z"),
    WyckoffPosition::new(125, 2, 'g', "m..", "0,y,z"),
    WyckoffPosition::new(125, 2, 'f', ".m.", "x,1/2,z"),
    WyckoffPosition::new(125, 2, 'e', ".m.", "x,0,z"),
    WyckoffPosition::new(125, 1, 'd', "mm2", "1/2,1/2,z"),
    WyckoffPosition::new(125, 1, 'c', "mm2", "1/2,0,z"),
    WyckoffPosition::new(125, 1, 'b', "mm2", "0,1/2,z"),
    WyckoffPosition::new(125, 1, 'a', "mm2", "0,0,z"),
    WyckoffPosition::new(126, 4, 'i', "1", "x,y,z"),
    WyckoffPosition::new(126, 2, 'h', "m..", "x,1/2,z"),
    WyckoffPosition::new(126, 2, 'g', "m..", "x,0,z"),
    WyckoffPosition::new(126, 2, 'f', ".m.", "x,y,1/2"),
    WyckoffPosition::new(126, 2, 'e', ".m.", "x,y,0"),
    WyckoffPosition::new(126, 1, 'd', "mm2", "x,1/2,1/2"),
    WyckoffPosition::new(126, 1, 'c', "mm2", "x,1/2,0"),
    WyckoffPosition::new(126, 1, 'b', "mm2", "x,0,1/2"),
    WyckoffPosition::new(126, 1, 'a', "mm2", "x,0,0"),
    WyckoffPosition::new(127, 4, 'i', "1", "x,y,z"),
    WyckoffPosition::new(127, 2, 'h', "m..", "x,y,1/2"),
    WyckoffPosition::new(127, 2, 'g', "m..", "x,y,0"),
    WyckoffPosition::new(127, 2, 'f', ".m.", "1/2,y,z"),
    WyckoffPosition::new(127, 2, 'e', ".m.", "0,y,z"),
    WyckoffPosition::new(127, 1, 'd', "mm2", "1/2,y,1/2"),
    WyckoffPosition::new(127, 1, 'c', "mm2", "0,y,1/2"),
    WyckoffPosition::new(127, 1, 'b', "mm2", "1/2,y,0"),
    WyckoffPosition::new(127, 1, 'a', "mm2", "0,y,0"),
    WyckoffPosition::new(128, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(128, 2, 'b', "m..", "1/2,y,z"),
    WyckoffPosition::new(128, 2, 'a', "m..", "0,y,z"),
    WyckoffPosition::new(129, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(129, 2, 'b', "m..", "x,1/2,z"),
    WyckoffPosition::new(129, 2, 'a', "m..", "x,0,z"),
    WyckoffPosition::new(130, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(130, 2, 'b', "m..", "x,1/2,z"),
    WyckoffPosition::new(130, 2, 'a', "m..", "x,0,z"),
    WyckoffPosition::new(131, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(131, 2, 'b', "m..", "x,y,1/2"),
    WyckoffPosition::new(131, 2, 'a', "m..", "x,y,0"),
    WyckoffPosition::new(132, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(132, 2, 'b', "m..", "x,y,1/2"),
    WyckoffPosition::new(132, 2, 'a', "m..", "x,y,0"),
    WyckoffPosition::new(133, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(133, 2, 'b', "m..", "1/2,y,z"),
    WyckoffPosition::new(133, 2, 'a', "m..", "0,y,z"),
    WyckoffPosition::new(134, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(134, 2, 'd', "..2", "1/2,1/2,z"),
    WyckoffPosition::new(134, 2, 'c', "..2", "1/2,0,z"),
    WyckoffPosition::new(134, 2, 'b', "..2", "0,1/2,z"),
    WyckoffPosition::new(134, 2, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(135, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(135, 2, 'd', "..2", "x,1/2,1/2"),
    WyckoffPosition::new(135, 2, 'c', "..2", "x,1/2,0"),
    WyckoffPosition::new(135, 2, 'b', "..2", "x,0,1/2"),
    WyckoffPosition::new(135, 2, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(136, 4, 'e', "1", "x,y,z"),
    WyckoffPosition::new(136, 2, 'd', "..2", "1/2,y,1/2"),
    WyckoffPosition::new(136, 2, 'c', "..2", "0,y,1/2"),
    WyckoffPosition::new(136, 2, 'b', "..2", "1/2,y,0"),
    WyckoffPosition::new(136, 2, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(137, 4, 'd', "1", "x,y,z"),
    WyckoffPosition::new(137, 2, 'c', "m..", "1/4,y,z"),
    WyckoffPosition::new(137, 2, 'b', "..2", "0,1/2,z"),
    WyckoffPosition::new(137, 2, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(138, 4, 'd', "1", "x,y,z"),
    WyckoffPosition::new(138, 2, 'c', "m..", "x,1/4,z"),
    WyckoffPosition::new(138, 2, 'b', "..2", "1/2,0,z"),
    WyckoffPosition::new(138, 2, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(139, 4, 'd', "1", "x,y,z"),
    WyckoffPosition::new(139, 2, 'c', "m..", "x,1/4,z"),
    WyckoffPosition::new(139, 2, 'b', "..2", "x,0,1/2"),
    WyckoffPosition::new(139, 2, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(140, 4, 'd', "1", "x,y,z"),
    WyckoffPosition::new(140, 2, 'c', "m..", "x,y,1/4"),
    WyckoffPosition::new(140, 2, 'b', "..2", "x,1/2,0"),
    WyckoffPosition::new(140, 2, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(141, 4, 'd', "1", "x,y,z"),
    WyckoffPosition::new(141, 2, 'c', "m..", "x,y,1/4"),
    WyckoffPosition::new(141, 2, 'b', "..2", "1/2,y,0"),
    WyckoffPosition::new(141, 2, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(142, 4, 'd', "1", "x,y,z"),
    WyckoffPosition::new(142, 2, 'c', "m..", "1/4,y,z"),
    WyckoffPosition::new(142, 2, 'b', "..2", "0,y,1/2"),
    WyckoffPosition::new(142, 2, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(143, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(144, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(145, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(146, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(147, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(148, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(149, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(149, 2, 'b', "..2", "1/2,0,z"),
    WyckoffPosition::new(149, 2, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(150, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(150, 2, 'b', "..2", "0,1/2,z"),
    WyckoffPosition::new(150, 2, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(151, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(151, 2, 'b', "..2", "x,1/2,0"),
    WyckoffPosition::new(151, 2, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(152, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(152, 2, 'b', "..2", "x,0,1/2"),
    WyckoffPosition::new(152, 2, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(153, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(153, 2, 'b', "..2", "0,y,1/2"),
    WyckoffPosition::new(153, 2, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(154, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(154, 2, 'b', "..2", "1/2,y,0"),
    WyckoffPosition::new(154, 2, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(155, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(155, 2, 'a', "m..", "0,y,z"),
    WyckoffPosition::new(156, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(156, 2, 'a', "m..", "x,0,z"),
    WyckoffPosition::new(157, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(157, 2, 'a', "m..", "x,0,z"),
    WyckoffPosition::new(158, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(158, 2, 'a', "m..", "x,y,0"),
    WyckoffPosition::new(159, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(159, 2, 'a', "m..", "x,y,0"),
    WyckoffPosition::new(160, 4, 'b', "1", "x,y,z"),
    WyckoffPosition::new(160, 2, 'a', "m..", "0,y,z"),
    WyckoffPosition::new(161, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(161, 2, 'b', "..2", "0,1/2,z"),
    WyckoffPosition::new(161, 2, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(162, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(162, 2, 'b', "..2", "x,0,1/2"),
    WyckoffPosition::new(162, 2, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(163, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(163, 2, 'b', "..2", "1/2,y,0"),
    WyckoffPosition::new(163, 2, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(164, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(165, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(166, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(167, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(168, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(169, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(170, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(170, 2, 'b', "..2", "0,1/2,z"),
    WyckoffPosition::new(170, 2, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(171, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(171, 2, 'b', "..2", "x,0,1/2"),
    WyckoffPosition::new(171, 2, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(172, 4, 'c', "1", "x,y,z"),
    WyckoffPosition::new(172, 2, 'b', "..2", "1/2,y,0"),
    WyckoffPosition::new(172, 2, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(173, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(173, 4, 'e', "m..", "0,y,z"),
    WyckoffPosition::new(173, 4, 'd', ".m.", "x,0,z"),
    WyckoffPosition::new(173, 4, 'c', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(173, 2, 'b', "mm2", "0,1/2,z"),
    WyckoffPosition::new(173, 2, 'a', "mm2", "0,0,z"),
    WyckoffPosition::new(174, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(174, 4, 'e', "m..", "x,0,z"),
    WyckoffPosition::new(174, 4, 'd', ".m.", "x,y,0"),
    WyckoffPosition::new(174, 4, 'c', "..2", "x,1/4,1/4"),
    WyckoffPosition::new(174, 2, 'b', "mm2", "x,0,1/2"),
    WyckoffPosition::new(174, 2, 'a', "mm2", "x,0,0"),
    WyckoffPosition::new(175, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(175, 4, 'e', "m..", "x,y,0"),
    WyckoffPosition::new(175, 4, 'd', ".m.", "0,y,z"),
    WyckoffPosition::new(175, 4, 'c', "..2", "1/4,y,1/4"),
    WyckoffPosition::new(175, 2, 'b', "mm2", "1/2,y,0"),
    WyckoffPosition::new(175, 2, 'a', "mm2", "0,y,0"),
    WyckoffPosition::new(176, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(176, 4, 'a', "m..", "0,y,z"),
    WyckoffPosition::new(177, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(177, 4, 'a', "m..", "x,0,z"),
    WyckoffPosition::new(178, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(178, 4, 'a', "m..", "x,0,z"),
    WyckoffPosition::new(179, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(179, 4, 'a', "m..", "x,y,0"),
    WyckoffPosition::new(180, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(180, 4, 'a', "m..", "x,y,0"),
    WyckoffPosition::new(181, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(181, 4, 'a', "m..", "0,y,z"),
    WyckoffPosition::new(182, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(182, 4, 'c', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(182, 4, 'b', "..2", "0,1/2,z"),
    WyckoffPosition::new(182, 4, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(183, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(183, 4, 'c', "..2", "x,1/4,1/4"),
    WyckoffPosition::new(183, 4, 'b', "..2", "x,0,1/2"),
    WyckoffPosition::new(183, 4, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(184, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(184, 4, 'c', "..2", "1/4,y,1/4"),
    WyckoffPosition::new(184, 4, 'b', "..2", "1/2,y,0"),
    WyckoffPosition::new(184, 4, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(185, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(185, 4, 'e', "m..", "1/2,y,z"),
    WyckoffPosition::new(185, 4, 'd', "m..", "0,y,z"),
    WyckoffPosition::new(185, 4, 'c', ".m.", "x,0,z"),
    WyckoffPosition::new(185, 2, 'b', "mm2", "1/2,0,z"),
    WyckoffPosition::new(185, 2, 'a', "mm2", "0,0,z"),
    WyckoffPosition::new(186, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(186, 4, 'e', "m..", "x,1/2,z"),
    WyckoffPosition::new(186, 4, 'd', "m..", "x,0,z"),
    WyckoffPosition::new(186, 4, 'c', ".m.", "0,y,z"),
    WyckoffPosition::new(186, 2, 'b', "mm2", "0,1/2,z"),
    WyckoffPosition::new(186, 2, 'a', "mm2", "0,0,z"),
    WyckoffPosition::new(187, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(187, 4, 'e', "m..", "x,1/2,z"),
    WyckoffPosition::new(187, 4, 'd', "m..", "x,0,z"),
    WyckoffPosition::new(187, 4, 'c', ".m.", "x,y,0"),
    WyckoffPosition::new(187, 2, 'b', "mm2", "x,1/2,0"),
    WyckoffPosition::new(187, 2, 'a', "mm2", "x,0,0"),
    WyckoffPosition::new(188, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(188, 4, 'e', "m..", "x,y,1/2"),
    WyckoffPosition::new(188, 4, 'd', "m..", "x,y,0"),
    WyckoffPosition::new(188, 4, 'c', ".m.", "x,0,z"),
    WyckoffPosition::new(188, 2, 'b', "mm2", "x,0,1/2"),
    WyckoffPosition::new(188, 2, 'a', "mm2", "x,0,0"),
    WyckoffPosition::new(189, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(189, 4, 'e', "m..", "x,y,1/2"),
    WyckoffPosition::new(189, 4, 'd', "m..", "x,y,0"),
    WyckoffPosition::new(189, 4, 'c', ".m.", "0,y,z"),
    WyckoffPosition::new(189, 2, 'b', "mm2", "0,y,1/2"),
    WyckoffPosition::new(189, 2, 'a', "mm2", "0,y,0"),
    WyckoffPosition::new(190, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(190, 4, 'e', "m..", "1/2,y,z"),
    WyckoffPosition::new(190, 4, 'd', "m..", "0,y,z"),
    WyckoffPosition::new(190, 4, 'c', ".m.", "x,y,0"),
    WyckoffPosition::new(190, 2, 'b', "mm2", "1/2,y,0"),
    WyckoffPosition::new(190, 2, 'a', "mm2", "0,y,0"),
    WyckoffPosition::new(191, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(191, 4, 'c', ".m.", "x,1/4,z"),
    WyckoffPosition::new(191, 4, 'b', "..2", "1/2,0,z"),
    WyckoffPosition::new(191, 4, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(192, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(192, 4, 'c', ".m.", "1/4,y,z"),
    WyckoffPosition::new(192, 4, 'b', "..2", "0,1/2,z"),
    WyckoffPosition::new(192, 4, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(193, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(193, 4, 'c', ".m.", "x,y,1/4"),
    WyckoffPosition::new(193, 4, 'b', "..2", "x,1/2,0"),
    WyckoffPosition::new(193, 4, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(194, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(194, 4, 'c', ".m.", "x,1/4,z"),
    WyckoffPosition::new(194, 4, 'b', "..2", "x,0,1/2"),
    WyckoffPosition::new(194, 4, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(195, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(195, 4, 'c', ".m.", "1/4,y,z"),
    WyckoffPosition::new(195, 4, 'b', "..2", "0,y,1/2"),
    WyckoffPosition::new(195, 4, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(196, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(196, 4, 'c', ".m.", "x,y,1/4"),
    WyckoffPosition::new(196, 4, 'b', "..2", "1/2,y,0"),
    WyckoffPosition::new(196, 4, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(197, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(197, 4, 'b', "m..", "1/4,y,z"),
    WyckoffPosition::new(197, 4, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(198, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(198, 4, 'b', "m..", "x,1/4,z"),
    WyckoffPosition::new(198, 4, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(199, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(199, 4, 'b', "m..", "x,1/4,z"),
    WyckoffPosition::new(199, 4, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(200, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(200, 4, 'b', "m..", "x,y,1/4"),
    WyckoffPosition::new(200, 4, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(201, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(201, 4, 'b', "m..", "x,y,1/4"),
    WyckoffPosition::new(201, 4, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(202, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(202, 4, 'b', "m..", "1/4,y,z"),
    WyckoffPosition::new(202, 4, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(203, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(203, 4, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(204, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(204, 4, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(205, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(205, 4, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(206, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(206, 4, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(207, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(207, 4, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(208, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(208, 4, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(209, 16, 'e', "1", "x,y,z"),
    WyckoffPosition::new(209, 8, 'd', ".m.", "x,0,z"),
    WyckoffPosition::new(209, 8, 'c', "m..", "0,y,z"),
    WyckoffPosition::new(209, 8, 'b', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(209, 4, 'a', "mm2", "0,0,z"),
    WyckoffPosition::new(210, 16, 'e', "1", "x,y,z"),
    WyckoffPosition::new(210, 8, 'd', ".m.", "x,y,0"),
    WyckoffPosition::new(210, 8, 'c', "m..", "x,0,z"),
    WyckoffPosition::new(210, 8, 'b', "..2", "x,1/4,1/4"),
    WyckoffPosition::new(210, 4, 'a', "mm2", "x,0,0"),
    WyckoffPosition::new(211, 16, 'e', "1", "x,y,z"),
    WyckoffPosition::new(211, 8, 'd', ".m.", "0,y,z"),
    WyckoffPosition::new(211, 8, 'c', "m..", "x,y,0"),
    WyckoffPosition::new(211, 8, 'b', "..2", "1/4,y,1/4"),
    WyckoffPosition::new(211, 4, 'a', "mm2", "0,y,0"),
    WyckoffPosition::new(212, 16, 'b', "1", "x,y,z"),
    WyckoffPosition::new(212, 8, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(213, 16, 'b', "1", "x,y,z"),
    WyckoffPosition::new(213, 8, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(214, 16, 'b', "1", "x,y,z"),
    WyckoffPosition::new(214, 8, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(215, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(215, 4, 'd', "m..", "0,y,z"),
    WyckoffPosition::new(215, 4, 'c', ".m.", "x,0,z"),
    WyckoffPosition::new(215, 2, 'b', "mm2", "0,1/2,z"),
    WyckoffPosition::new(215, 2, 'a', "mm2", "0,0,z"),
    WyckoffPosition::new(216, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(216, 4, 'd', "m..", "x,0,z"),
    WyckoffPosition::new(216, 4, 'c', ".m.", "x,y,0"),
    WyckoffPosition::new(216, 2, 'b', "mm2", "x,0,1/2"),
    WyckoffPosition::new(216, 2, 'a', "mm2", "x,0,0"),
    WyckoffPosition::new(217, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(217, 4, 'd', "m..", "x,y,0"),
    WyckoffPosition::new(217, 4, 'c', ".m.", "0,y,z"),
    WyckoffPosition::new(217, 2, 'b', "mm2", "1/2,y,0"),
    WyckoffPosition::new(217, 2, 'a', "mm2", "0,y,0"),
    WyckoffPosition::new(218, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(218, 4, 'b', "..2", "0,1/2,z"),
    WyckoffPosition::new(218, 4, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(219, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(219, 4, 'b', "..2", "x,0,1/2"),
    WyckoffPosition::new(219, 4, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(220, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(220, 4, 'b', "..2", "1/2,y,0"),
    WyckoffPosition::new(220, 4, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(221, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(221, 4, 'b', "m..", "1/4,y,z"),
    WyckoffPosition::new(221, 4, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(222, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(222, 4, 'b', "m..", "x,1/4,z"),
    WyckoffPosition::new(222, 4, 'a', "..2", "0,0,z"),
    WyckoffPosition::new(223, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(223, 4, 'b', "m..", "x,1/4,z"),
    WyckoffPosition::new(223, 4, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(224, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(224, 4, 'b', "m..", "x,y,1/4"),
    WyckoffPosition::new(224, 4, 'a', "..2", "x,0,0"),
    WyckoffPosition::new(225, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(225, 4, 'b', "m..", "x,y,1/4"),
    WyckoffPosition::new(225, 4, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(226, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(226, 4, 'b', "m..", "1/4,y,z"),
    WyckoffPosition::new(226, 4, 'a', "..2", "0,y,0"),
    WyckoffPosition::new(227, 8, 'A', "1", "x,y,z"),
    WyckoffPosition::new(227, 4, 'z', "..m", "x,y,1/2"),
    WyckoffPosition::new(227, 4, 'y', "..m", "x,y,0"),
    WyckoffPosition::new(227, 4, 'x', ".m.", "x,1/2,z"),
    WyckoffPosition::new(227, 4, 'w', ".m.", "x,0,z"),
    WyckoffPosition::new(227, 4, 'v', "m..", "1/2,y,z"),
    WyckoffPosition::new(227, 4, 'u', "m..", "0,y,z"),
    WyckoffPosition::new(227, 2, 't', "mm2", "1/2,1/2,z"),
    WyckoffPosition::new(227, 2, 's', "mm2", "1/2,0,z"),
    WyckoffPosition::new(227, 2, 'r', "mm2", "0,1/2,z"),
    WyckoffPosition::new(227, 2, 'q', "mm2", "0,0,z"),
    WyckoffPosition::new(227, 2, 'p', "m2m", "1/2,y,1/2"),
    WyckoffPosition::new(227, 2, 'o', "m2m", "1/2,y,0"),
    WyckoffPosition::new(227, 2, 'n', "m2m", "0,y,1/2"),
    WyckoffPosition::new(227, 2, 'm', "m2m", "0,y,0"),
    WyckoffPosition::new(227, 2, 'l', "2mm", "x,1/2,1/2"),
    WyckoffPosition::new(227, 2, 'k', "2mm", "x,1/2,0"),
    WyckoffPosition::new(227, 2, 'j', "2mm", "x,0,1/2"),
    WyckoffPosition::new(227, 2, 'i', "2mm", "x,0,0"),
    WyckoffPosition::new(227, 1, 'h', "mmm", "1/2,1/2,1/2"),
    WyckoffPosition::new(227, 1, 'g', "mmm", "0,1/2,1/2"),
    WyckoffPosition::new(227, 1, 'f', "mmm", "1/2,1/2,0"),
    WyckoffPosition::new(227, 1, 'e', "mmm", "0,1/2,0"),
    WyckoffPosition::new(227, 1, 'd', "mmm", "1/2,0,1/2"),
    WyckoffPosition::new(227, 1, 'c', "mmm", "0,0,1/2"),
    WyckoffPosition::new(227, 1, 'b', "mmm", "1/2,0,0"),
    WyckoffPosition::new(227, 1, 'a', "mmm", "0,0,0"),
    WyckoffPosition::new(228, 8, 'm', "1", "x,y,z"),
    WyckoffPosition::new(228, 4, 'l', "..2", "0,1/2,z"),
    WyckoffPosition::new(228, 4, 'k', "..2", "0,0,z"),
    WyckoffPosition::new(228, 4, 'j', ".2.", "1/2,y,0"),
    WyckoffPosition::new(228, 4, 'i', ".2.", "0,y,0"),
    WyckoffPosition::new(228, 4, 'h', "2..", "x,0,1/2"),
    WyckoffPosition::new(228, 4, 'g', "2..", "x,0,0"),
    WyckoffPosition::new(228, 4, 'f', "-1", "3/4,3/4,3/4"),
    WyckoffPosition::new(228, 4, 'e', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(228, 2, 'd', "222", "0,1/2,0"),
    WyckoffPosition::new(228, 2, 'c', "222", "0,0,1/2"),
    WyckoffPosition::new(228, 2, 'b', "222", "1/2,0,0"),
    WyckoffPosition::new(228, 2, 'a', "222", "0,0,0"),
    WyckoffPosition::new(229, 8, 'm', "1", "x,y,z"),
    WyckoffPosition::new(229, 4, 'l', "..2", "1/4,3/4,z"),
    WyckoffPosition::new(229, 4, 'k', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(229, 4, 'j', ".2.", "3/4,y,1/4"),
    WyckoffPosition::new(229, 4, 'i', ".2.", "1/4,y,1/4"),
    WyckoffPosition::new(229, 4, 'h', "2..", "x,1/4,3/4"),
    WyckoffPosition::new(229, 4, 'g', "2..", "x,1/4,1/4"),
    WyckoffPosition::new(229, 4, 'f', "-1", "0,0,0"),
    WyckoffPosition::new(229, 4, 'e', "-1", "1/2,1/2,1/2"),
    WyckoffPosition::new(229, 2, 'd', "222", "1/4,3/4,1/4"),
    WyckoffPosition::new(229, 2, 'c', "222", "1/4,1/4,3/4"),
    WyckoffPosition::new(229, 2, 'b', "222", "3/4,1/4,1/4"),
    WyckoffPosition::new(229, 2, 'a', "222", "1/4,1/4,1/4"),
    WyckoffPosition::new(230, 8, 'r', "1", "x,y,z"),
    WyckoffPosition::new(230, 4, 'q', "..m", "x,y,0"),
    WyckoffPosition::new(230, 4, 'p', "..2", "1/2,0,z"),
    WyckoffPosition::new(230, 4, 'o', "..2", "0,1/2,z"),
    WyckoffPosition::new(230, 4, 'n', "..2", "1/2,1/2,z"),
    WyckoffPosition::new(230, 4, 'm', "..2", "0,0,z"),
    WyckoffPosition::new(230, 4, 'l', ".2.", "1/2,y,1/4"),
    WyckoffPosition::new(230, 4, 'k', ".2.", "0,y,1/4"),
    WyckoffPosition::new(230, 4, 'j', "2..", "x,1/2,1/4"),
    WyckoffPosition::new(230, 4, 'i', "2..", "x,0,1/4"),
    WyckoffPosition::new(230, 2, 'h', "222", "1/2,1/2,1/4"),
    WyckoffPosition::new(230, 2, 'g', "222", "0,1/2,1/4"),
    WyckoffPosition::new(230, 2, 'f', "222", "1/2,0,1/4"),
    WyckoffPosition::new(230, 2, 'e', "222", "0,0,1/4"),
    WyckoffPosition::new(230, 2, 'd', "..2/m", "1/2,0,0"),
    WyckoffPosition::new(230, 2, 'c', "..2/m", "0,1/2,0"),
    WyckoffPosition::new(230, 2, 'b', "..2/m", "1/2,1/2,0"),
    WyckoffPosition::new(230, 2, 'a', "..2/m", "0,0,0"),
    WyckoffPosition::new(231, 8, 'r', "1", "x,y,z"),
    WyckoffPosition::new(231, 4, 'q', "..m", "0,y,z"),
    WyckoffPosition::new(231, 4, 'p', "..2", "x,1/2,0"),
    WyckoffPosition::new(231, 4, 'o', "..2", "x,0,1/2"),
    WyckoffPosition::new(231, 4, 'n', "..2", "x,1/2,1/2"),
    WyckoffPosition::new(231, 4, 'm', "..2", "x,0,0"),
    WyckoffPosition::new(231, 4, 'l', ".2.", "1/4,1/2,z"),
    WyckoffPosition::new(231, 4, 'k', ".2.", "1/4,0,z"),
    WyckoffPosition::new(231, 4, 'j', "2..", "1/4,y,1/2"),
    WyckoffPosition::new(231, 4, 'i', "2..", "1/4,y,0"),
    WyckoffPosition::new(231, 2, 'h', "222", "1/4,1/2,1/2"),
    WyckoffPosition::new(231, 2, 'g', "222", "1/4,0,1/2"),
    WyckoffPosition::new(231, 2, 'f', "222", "1/4,1/2,0"),
    WyckoffPosition::new(231, 2, 'e', "222", "1/4,0,0"),
    WyckoffPosition::new(231, 2, 'd', "..2/m", "0,1/2,0"),
    WyckoffPosition::new(231, 2, 'c', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(231, 2, 'b', "..2/m", "0,1/2,1/2"),
    WyckoffPosition::new(231, 2, 'a', "..2/m", "0,0,0"),
    WyckoffPosition::new(232, 8, 'r', "1", "x,y,z"),
    WyckoffPosition::new(232, 4, 'q', "..m", "x,0,z"),
    WyckoffPosition::new(232, 4, 'p', "..2", "0,y,1/2"),
    WyckoffPosition::new(232, 4, 'o', "..2", "1/2,y,0"),
    WyckoffPosition::new(232, 4, 'n', "..2", "1/2,y,1/2"),
    WyckoffPosition::new(232, 4, 'm', "..2", "0,y,0"),
    WyckoffPosition::new(232, 4, 'l', ".2.", "x,1/4,1/2"),
    WyckoffPosition::new(232, 4, 'k', ".2.", "x,1/4,0"),
    WyckoffPosition::new(232, 4, 'j', "2..", "1/2,1/4,z"),
    WyckoffPosition::new(232, 4, 'i', "2..", "0,1/4,z"),
    WyckoffPosition::new(232, 2, 'h', "222", "1/2,1/4,1/2"),
    WyckoffPosition::new(232, 2, 'g', "222", "1/2,1/4,0"),
    WyckoffPosition::new(232, 2, 'f', "222", "0,1/4,1/2"),
    WyckoffPosition::new(232, 2, 'e', "222", "0,1/4,0"),
    WyckoffPosition::new(232, 2, 'd', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(232, 2, 'c', "..2/m", "1/2,0,0"),
    WyckoffPosition::new(232, 2, 'b', "..2/m", "1/2,0,1/2"),
    WyckoffPosition::new(232, 2, 'a', "..2/m", "0,0,0"),
    WyckoffPosition::new(233, 8, 'm', "1", "x,y,z"),
    WyckoffPosition::new(233, 4, 'l', "..2", "0,1/2,z"),
    WyckoffPosition::new(233, 4, 'k', "..2", "0,0,z"),
    WyckoffPosition::new(233, 4, 'j', ".2.", "0,y,1/2"),
    WyckoffPosition::new(233, 4, 'i', ".2.", "0,y,0"),
    WyckoffPosition::new(233, 4, 'h', "2..", "x,0,1/2"),
    WyckoffPosition::new(233, 4, 'g', "2..", "x,0,0"),
    WyckoffPosition::new(233, 4, 'f', "-1", "1/4,1/4,1/2"),
    WyckoffPosition::new(233, 4, 'e', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(233, 2, 'd', "222", "0,0,1/2"),
    WyckoffPosition::new(233, 2, 'c', "222", "1/2,0,1/2"),
    WyckoffPosition::new(233, 2, 'b', "222", "1/2,0,0"),
    WyckoffPosition::new(233, 2, 'a', "222", "0,0,0"),
    WyckoffPosition::new(234, 8, 'm', "1", "x,y,z"),
    WyckoffPosition::new(234, 4, 'l', "..2", "1/4,3/4,z"),
    WyckoffPosition::new(234, 4, 'k', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(234, 4, 'j', ".2.", "1/4,y,1/2"),
    WyckoffPosition::new(234, 4, 'i', ".2.", "1/4,y,0"),
    WyckoffPosition::new(234, 4, 'h', "2..", "x,1/4,1/2"),
    WyckoffPosition::new(234, 4, 'g', "2..", "x,1/4,0"),
    WyckoffPosition::new(234, 4, 'f', "-1", "0,0,1/2"),
    WyckoffPosition::new(234, 4, 'e', "-1", "0,0,0"),
    WyckoffPosition::new(234, 2, 'd', "222", "1/4,1/4,1/2"),
    WyckoffPosition::new(234, 2, 'c', "222", "3/4,1/4,1/2"),
    WyckoffPosition::new(234, 2, 'b', "222", "3/4,1/4,0"),
    WyckoffPosition::new(234, 2, 'a', "222", "1/4,1/4,0"),
    WyckoffPosition::new(235, 8, 'm', "1", "x,y,z"),
    WyckoffPosition::new(235, 4, 'l', "..2", "x,0,1/2"),
    WyckoffPosition::new(235, 4, 'k', "..2", "x,0,0"),
    WyckoffPosition::new(235, 4, 'j', ".2.", "1/2,0,z"),
    WyckoffPosition::new(235, 4, 'i', ".2.", "0,0,z"),
    WyckoffPosition::new(235, 4, 'h', "2..", "1/2,y,0"),
    WyckoffPosition::new(235, 4, 'g', "2..", "0,y,0"),
    WyckoffPosition::new(235, 4, 'f', "-1", "1/2,1/4,1/4"),
    WyckoffPosition::new(235, 4, 'e', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(235, 2, 'd', "222", "1/2,0,0"),
    WyckoffPosition::new(235, 2, 'c', "222", "1/2,1/2,0"),
    WyckoffPosition::new(235, 2, 'b', "222", "0,1/2,0"),
    WyckoffPosition::new(235, 2, 'a', "222", "0,0,0"),
    WyckoffPosition::new(236, 8, 'm', "1", "x,y,z"),
    WyckoffPosition::new(236, 4, 'l', "..2", "x,1/4,3/4"),
    WyckoffPosition::new(236, 4, 'k', "..2", "x,1/4,1/4"),
    WyckoffPosition::new(236, 4, 'j', ".2.", "1/2,1/4,z"),
    WyckoffPosition::new(236, 4, 'i', ".2.", "0,1/4,z"),
    WyckoffPosition::new(236, 4, 'h', "2..", "1/2,y,1/4"),
    WyckoffPosition::new(236, 4, 'g', "2..", "0,y,1/4"),
    WyckoffPosition::new(236, 4, 'f', "-1", "1/2,0,0"),
    WyckoffPosition::new(236, 4, 'e', "-1", "0,0,0"),
    WyckoffPosition::new(236, 2, 'd', "222", "1/2,1/4,1/4"),
    WyckoffPosition::new(236, 2, 'c', "222", "1/2,3/4,1/4"),
    WyckoffPosition::new(236, 2, 'b', "222", "0,3/4,1/4"),
    WyckoffPosition::new(236, 2, 'a', "222", "0,1/4,1/4"),
    WyckoffPosition::new(237, 8, 'm', "1", "x,y,z"),
    WyckoffPosition::new(237, 4, 'l', "..2", "1/2,y,0"),
    WyckoffPosition::new(237, 4, 'k', "..2", "0,y,0"),
    WyckoffPosition::new(237, 4, 'j', ".2.", "x,1/2,0"),
    WyckoffPosition::new(237, 4, 'i', ".2.", "x,0,0"),
    WyckoffPosition::new(237, 4, 'h', "2..", "0,1/2,z"),
    WyckoffPosition::new(237, 4, 'g', "2..", "0,0,z"),
    WyckoffPosition::new(237, 4, 'f', "-1", "1/4,1/2,1/4"),
    WyckoffPosition::new(237, 4, 'e', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(237, 2, 'd', "222", "0,1/2,0"),
    WyckoffPosition::new(237, 2, 'c', "222", "0,1/2,1/2"),
    WyckoffPosition::new(237, 2, 'b', "222", "0,0,1/2"),
    WyckoffPosition::new(237, 2, 'a', "222", "0,0,0"),
    WyckoffPosition::new(238, 8, 'm', "1", "x,y,z"),
    WyckoffPosition::new(238, 4, 'l', "..2", "3/4,y,1/4"),
    WyckoffPosition::new(238, 4, 'k', "..2", "1/4,y,1/4"),
    WyckoffPosition::new(238, 4, 'j', ".2.", "x,1/2,1/4"),
    WyckoffPosition::new(238, 4, 'i', ".2.", "x,0,1/4"),
    WyckoffPosition::new(238, 4, 'h', "2..", "1/4,1/2,z"),
    WyckoffPosition::new(238, 4, 'g', "2..", "1/4,0,z"),
    WyckoffPosition::new(238, 4, 'f', "-1", "0,1/2,0"),
    WyckoffPosition::new(238, 4, 'e', "-1", "0,0,0"),
    WyckoffPosition::new(238, 2, 'd', "222", "1/4,1/2,1/4"),
    WyckoffPosition::new(238, 2, 'c', "222", "1/4,1/2,3/4"),
    WyckoffPosition::new(238, 2, 'b', "222", "1/4,0,3/4"),
    WyckoffPosition::new(238, 2, 'a', "222", "1/4,0,1/4"),
    WyckoffPosition::new(239, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(239, 4, 'k', "m..", "1/4,y,z"),
    WyckoffPosition::new(239, 4, 'j', ".m.", "x,1/2,z"),
    WyckoffPosition::new(239, 4, 'i', ".m.", "x,0,z"),
    WyckoffPosition::new(239, 4, 'h', ".2.", "0,y,1/2"),
    WyckoffPosition::new(239, 4, 'g', ".2.", "0,y,0"),
    WyckoffPosition::new(239, 2, 'f', "mm2", "1/4,1/2,z"),
    WyckoffPosition::new(239, 2, 'e', "mm2", "1/4,0,z"),
    WyckoffPosition::new(239, 2, 'd', ".2/m.", "0,1/2,1/2"),
    WyckoffPosition::new(239, 2, 'c', ".2/m.", "0,0,1/2"),
    WyckoffPosition::new(239, 2, 'b', ".2/m.", "0,1/2,0"),
    WyckoffPosition::new(239, 2, 'a', ".2/m.", "0,0,0"),
    WyckoffPosition::new(240, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(240, 4, 'k', "m..", "x,1/4,z"),
    WyckoffPosition::new(240, 4, 'j', ".m.", "1/2,y,z"),
    WyckoffPosition::new(240, 4, 'i', ".m.", "0,y,z"),
    WyckoffPosition::new(240, 4, 'h', ".2.", "x,0,1/2"),
    WyckoffPosition::new(240, 4, 'g', ".2.", "x,0,0"),
    WyckoffPosition::new(240, 2, 'f', "mm2", "1/2,1/4,z"),
    WyckoffPosition::new(240, 2, 'e', "mm2", "0,1/4,z"),
    WyckoffPosition::new(240, 2, 'd', ".2/m.", "1/2,0,1/2"),
    WyckoffPosition::new(240, 2, 'c', ".2/m.", "0,0,1/2"),
    WyckoffPosition::new(240, 2, 'b', ".2/m.", "1/2,0,0"),
    WyckoffPosition::new(240, 2, 'a', ".2/m.", "0,0,0"),
    WyckoffPosition::new(241, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(241, 4, 'k', "m..", "x,1/4,z"),
    WyckoffPosition::new(241, 4, 'j', ".m.", "x,y,1/2"),
    WyckoffPosition::new(241, 4, 'i', ".m.", "x,y,0"),
    WyckoffPosition::new(241, 4, 'h', ".2.", "1/2,0,z"),
    WyckoffPosition::new(241, 4, 'g', ".2.", "0,0,z"),
    WyckoffPosition::new(241, 2, 'f', "mm2", "x,1/4,1/2"),
    WyckoffPosition::new(241, 2, 'e', "mm2", "x,1/4,0"),
    WyckoffPosition::new(241, 2, 'd', ".2/m.", "1/2,0,1/2"),
    WyckoffPosition::new(241, 2, 'c', ".2/m.", "1/2,0,0"),
    WyckoffPosition::new(241, 2, 'b', ".2/m.", "0,0,1/2"),
    WyckoffPosition::new(241, 2, 'a', ".2/m.", "0,0,0"),
    WyckoffPosition::new(242, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(242, 4, 'k', "m..", "x,y,1/4"),
    WyckoffPosition::new(242, 4, 'j', ".m.", "x,1/2,z"),
    WyckoffPosition::new(242, 4, 'i', ".m.", "x,0,z"),
    WyckoffPosition::new(242, 4, 'h', ".2.", "1/2,y,0"),
    WyckoffPosition::new(242, 4, 'g', ".2.", "0,y,0"),
    WyckoffPosition::new(242, 2, 'f', "mm2", "x,1/2,1/4"),
    WyckoffPosition::new(242, 2, 'e', "mm2", "x,0,1/4"),
    WyckoffPosition::new(242, 2, 'd', ".2/m.", "1/2,1/2,0"),
    WyckoffPosition::new(242, 2, 'c', ".2/m.", "1/2,0,0"),
    WyckoffPosition::new(242, 2, 'b', ".2/m.", "0,1/2,0"),
    WyckoffPosition::new(242, 2, 'a', ".2/m.", "0,0,0"),
    WyckoffPosition::new(243, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(243, 4, 'k', "m..", "x,y,1/4"),
    WyckoffPosition::new(243, 4, 'j', ".m.", "1/2,y,z"),
    WyckoffPosition::new(243, 4, 'i', ".m.", "0,y,z"),
    WyckoffPosition::new(243, 4, 'h', ".2.", "x,1/2,0"),
    WyckoffPosition::new(243, 4, 'g', ".2.", "x,0,0"),
    WyckoffPosition::new(243, 2, 'f', "mm2", "1/2,y,1/4"),
    WyckoffPosition::new(243, 2, 'e', "mm2", "0,y,1/4"),
    WyckoffPosition::new(243, 2, 'd', ".2/m.", "1/2,1/2,0"),
    WyckoffPosition::new(243, 2, 'c', ".2/m.", "0,1/2,0"),
    WyckoffPosition::new(243, 2, 'b', ".2/m.", "1/2,0,0"),
    WyckoffPosition::new(243, 2, 'a', ".2/m.", "0,0,0"),
    WyckoffPosition::new(244, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(244, 4, 'k', "m..", "1/4,y,z"),
    WyckoffPosition::new(244, 4, 'j', ".m.", "x,y,1/2"),
    WyckoffPosition::new(244, 4, 'i', ".m.", "x,y,0"),
    WyckoffPosition::new(244, 4, 'h', ".2.", "0,1/2,z"),
    WyckoffPosition::new(244, 4, 'g', ".2.", "0,0,z"),
    WyckoffPosition::new(244, 2, 'f', "mm2", "1/4,y,1/2"),
    WyckoffPosition::new(244, 2, 'e', "mm2", "1/4,y,0"),
    WyckoffPosition::new(244, 2, 'd', ".2/m.", "0,1/2,1/2"),
    WyckoffPosition::new(244, 2, 'c', ".2/m.", "0,1/2,0"),
    WyckoffPosition::new(244, 2, 'b', ".2/m.", "0,0,1/2"),
    WyckoffPosition::new(244, 2, 'a', ".2/m.", "0,0,0"),
    WyckoffPosition::new(245, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(245, 4, 'd', "2..", "x,1/4,1/4"),
    WyckoffPosition::new(245, 4, 'c', "..2", "1/4,0,z"),
    WyckoffPosition::new(245, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(245, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(246, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(246, 4, 'd', "2..", "1/4,y,3/4"),
    WyckoffPosition::new(246, 4, 'c', "..2", "0,1/4,z"),
    WyckoffPosition::new(246, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(246, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(247, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(247, 4, 'd', "2..", "1/4,y,1/4"),
    WyckoffPosition::new(247, 4, 'c', "..2", "x,1/4,0"),
    WyckoffPosition::new(247, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(247, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(248, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(248, 4, 'd', "2..", "3/4,1/4,z"),
    WyckoffPosition::new(248, 4, 'c', "..2", "x,0,1/4"),
    WyckoffPosition::new(248, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(248, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(249, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(249, 4, 'd', "2..", "1/4,1/4,z"),
    WyckoffPosition::new(249, 4, 'c', "..2", "0,y,1/4"),
    WyckoffPosition::new(249, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(249, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(250, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(250, 4, 'd', "2..", "x,3/4,1/4"),
    WyckoffPosition::new(250, 4, 'c', "..2", "1/4,y,0"),
    WyckoffPosition::new(250, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(250, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(251, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(251, 4, 'h', "m..", "0,y,z"),
    WyckoffPosition::new(251, 4, 'g', ".2.", "1/4,y,1/4"),
    WyckoffPosition::new(251, 4, 'f', "2..", "x,1/2,0"),
    WyckoffPosition::new(251, 4, 'e', "2..", "x,0,0"),
    WyckoffPosition::new(251, 2, 'd', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(251, 2, 'c', "2/m..", "1/2,1/2,0"),
    WyckoffPosition::new(251, 2, 'b', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(251, 2, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(252, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(252, 4, 'h', "m..", "x,0,z"),
    WyckoffPosition::new(252, 4, 'g', ".2.", "x,1/4,3/4"),
    WyckoffPosition::new(252, 4, 'f', "2..", "1/2,y,0"),
    WyckoffPosition::new(252, 4, 'e', "2..", "0,y,0"),
    WyckoffPosition::new(252, 2, 'd', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(252, 2, 'c', "2/m..", "1/2,1/2,0"),
    WyckoffPosition::new(252, 2, 'b', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(252, 2, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(253, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(253, 4, 'h', "m..", "x,0,z"),
    WyckoffPosition::new(253, 4, 'g', ".2.", "1/4,1/4,z"),
    WyckoffPosition::new(253, 4, 'f', "2..", "0,y,1/2"),
    WyckoffPosition::new(253, 4, 'e', "2..", "0,y,0"),
    WyckoffPosition::new(253, 2, 'd', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(253, 2, 'c', "2/m..", "0,1/2,1/2"),
    WyckoffPosition::new(253, 2, 'b', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(253, 2, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(254, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(254, 4, 'h', "m..", "x,y,0"),
    WyckoffPosition::new(254, 4, 'g', ".2.", "3/4,y,1/4"),
    WyckoffPosition::new(254, 4, 'f', "2..", "0,1/2,z"),
    WyckoffPosition::new(254, 4, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(254, 2, 'd', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(254, 2, 'c', "2/m..", "0,1/2,1/2"),
    WyckoffPosition::new(254, 2, 'b', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(254, 2, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(255, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(255, 4, 'h', "m..", "x,y,0"),
    WyckoffPosition::new(255, 4, 'g', ".2.", "x,1/4,1/4"),
    WyckoffPosition::new(255, 4, 'f', "2..", "1/2,0,z"),
    WyckoffPosition::new(255, 4, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(255, 2, 'd', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(255, 2, 'c', "2/m..", "1/2,0,1/2"),
    WyckoffPosition::new(255, 2, 'b', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(255, 2, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(256, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(256, 4, 'h', "m..", "0,y,z"),
    WyckoffPosition::new(256, 4, 'g', ".2.", "1/4,3/4,z"),
    WyckoffPosition::new(256, 4, 'f', "2..", "x,0,1/2"),
    WyckoffPosition::new(256, 4, 'e', "2..", "x,0,0"),
    WyckoffPosition::new(256, 2, 'd', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(256, 2, 'c', "2/m..", "1/2,0,1/2"),
    WyckoffPosition::new(256, 2, 'b', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(256, 2, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(257, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(257, 4, 'e', "..2", "1/4,1/2,z"),
    WyckoffPosition::new(257, 4, 'd', "..2", "1/4,0,z"),
    WyckoffPosition::new(257, 4, 'c', ".2.", "0,y,1/4"),
    WyckoffPosition::new(257, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(257, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(258, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(258, 4, 'e', "..2", "1/2,1/4,z"),
    WyckoffPosition::new(258, 4, 'd', "..2", "0,1/4,z"),
    WyckoffPosition::new(258, 4, 'c', ".2.", "x,0,3/4"),
    WyckoffPosition::new(258, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(258, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(259, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(259, 4, 'e', "..2", "x,1/4,1/2"),
    WyckoffPosition::new(259, 4, 'd', "..2", "x,1/4,0"),
    WyckoffPosition::new(259, 4, 'c', ".2.", "1/4,0,z"),
    WyckoffPosition::new(259, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(259, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(260, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(260, 4, 'e', "..2", "x,1/2,1/4"),
    WyckoffPosition::new(260, 4, 'd', "..2", "x,0,1/4"),
    WyckoffPosition::new(260, 4, 'c', ".2.", "3/4,y,0"),
    WyckoffPosition::new(260, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(260, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(261, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(261, 4, 'e', "..2", "1/2,y,1/4"),
    WyckoffPosition::new(261, 4, 'd', "..2", "0,y,1/4"),
    WyckoffPosition::new(261, 4, 'c', ".2.", "x,1/4,0"),
    WyckoffPosition::new(261, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(261, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(262, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(262, 4, 'e', "..2", "1/4,y,1/2"),
    WyckoffPosition::new(262, 4, 'd', "..2", "1/4,y,0"),
    WyckoffPosition::new(262, 4, 'c', ".2.", "0,3/4,z"),
    WyckoffPosition::new(262, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(262, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(263, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(263, 4, 'h', "..m", "x,y,1/2"),
    WyckoffPosition::new(263, 4, 'g', "..m", "x,y,0"),
    WyckoffPosition::new(263, 4, 'f', "..2", "0,1/2,z"),
    WyckoffPosition::new(263, 4, 'e', "..2", "0,0,z"),
    WyckoffPosition::new(263, 2, 'd', "..2/m", "0,1/2,1/2"),
    WyckoffPosition::new(263, 2, 'c', "..2/m", "0,1/2,0"),
    WyckoffPosition::new(263, 2, 'b', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(263, 2, 'a', "..2/m", "0,0,0"),
    WyckoffPosition::new(264, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(264, 4, 'h', "..m", "1/2,y,z"),
    WyckoffPosition::new(264, 4, 'g', "..m", "0,y,z"),
    WyckoffPosition::new(264, 4, 'f', "..2", "x,0,1/2"),
    WyckoffPosition::new(264, 4, 'e', "..2", "x,0,0"),
    WyckoffPosition::new(264, 2, 'd', "..2/m", "1/2,0,1/2"),
    WyckoffPosition::new(264, 2, 'c', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(264, 2, 'b', "..2/m", "1/2,0,0"),
    WyckoffPosition::new(264, 2, 'a', "..2/m", "0,0,0"),
    WyckoffPosition::new(265, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(265, 4, 'h', "..m", "x,1/2,z"),
    WyckoffPosition::new(265, 4, 'g', "..m", "x,0,z"),
    WyckoffPosition::new(265, 4, 'f', "..2", "1/2,y,0"),
    WyckoffPosition::new(265, 4, 'e', "..2", "0,y,0"),
    WyckoffPosition::new(265, 2, 'd', "..2/m", "1/2,1/2,0"),
    WyckoffPosition::new(265, 2, 'c', "..2/m", "1/2,0,0"),
    WyckoffPosition::new(265, 2, 'b', "..2/m", "0,1/2,0"),
    WyckoffPosition::new(265, 2, 'a', "..2/m", "0,0,0"),
    WyckoffPosition::new(266, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(266, 4, 'd', "..2", "1/4,3/4,z"),
    WyckoffPosition::new(266, 4, 'c', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(266, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(266, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(267, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(267, 4, 'd', "..2", "x,1/4,3/4"),
    WyckoffPosition::new(267, 4, 'c', "..2", "x,1/4,1/4"),
    WyckoffPosition::new(267, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(267, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(268, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(268, 4, 'd', "..2", "3/4,y,1/4"),
    WyckoffPosition::new(268, 4, 'c', "..2", "1/4,y,1/4"),
    WyckoffPosition::new(268, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(268, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(269, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(269, 4, 'd', "..m", "x,y,1/4"),
    WyckoffPosition::new(269, 4, 'c', "2..", "x,1/4,0"),
    WyckoffPosition::new(269, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(269, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(270, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(270, 4, 'd', "..m", "x,y,3/4"),
    WyckoffPosition::new(270, 4, 'c', "2..", "1/4,y,0"),
    WyckoffPosition::new(270, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(270, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(271, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(271, 4, 'd', "..m", "1/4,y,z"),
    WyckoffPosition::new(271, 4, 'c', "2..", "0,y,1/4"),
    WyckoffPosition::new(271, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(271, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(272, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(272, 4, 'd', "..m", "3/4,y,z"),
    WyckoffPosition::new(272, 4, 'c', "2..", "0,1/4,z"),
    WyckoffPosition::new(272, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(272, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(273, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(273, 4, 'd', "..m", "x,1/4,z"),
    WyckoffPosition::new(273, 4, 'c', "2..", "1/4,0,z"),
    WyckoffPosition::new(273, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(273, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(274, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(274, 4, 'd', "..m", "x,3/4,z"),
    WyckoffPosition::new(274, 4, 'c', "2..", "x,0,1/4"),
    WyckoffPosition::new(274, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(274, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(275, 8, 'h', "1", "x,y,z"),
    WyckoffPosition::new(275, 4, 'g', "..m", "x,y,0"),
    WyckoffPosition::new(275, 4, 'f', "..2", "0,1/2,z"),
    WyckoffPosition::new(275, 4, 'e', "..2", "0,0,z"),
    WyckoffPosition::new(275, 2, 'd', "..2/m", "0,1/2,1/2"),
    WyckoffPosition::new(275, 2, 'c', "..2/m", "0,1/2,0"),
    WyckoffPosition::new(275, 2, 'b', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(275, 2, 'a', "..2/m", "0,0,0"),
    WyckoffPosition::new(276, 8, 'h', "1", "x,y,z"),
    WyckoffPosition::new(276, 4, 'g', "..m", "0,y,z"),
    WyckoffPosition::new(276, 4, 'f', "..2", "x,0,1/2"),
    WyckoffPosition::new(276, 4, 'e', "..2", "x,0,0"),
    WyckoffPosition::new(276, 2, 'd', "..2/m", "1/2,0,1/2"),
    WyckoffPosition::new(276, 2, 'c', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(276, 2, 'b', "..2/m", "1/2,0,0"),
    WyckoffPosition::new(276, 2, 'a', "..2/m", "0,0,0"),
    WyckoffPosition::new(277, 8, 'h', "1", "x,y,z"),
    WyckoffPosition::new(277, 4, 'g', "..m", "x,0,z"),
    WyckoffPosition::new(277, 4, 'f', "..2", "1/2,y,0"),
    WyckoffPosition::new(277, 4, 'e', "..2", "0,y,0"),
    WyckoffPosition::new(277, 2, 'd', "..2/m", "1/2,1/2,0"),
    WyckoffPosition::new(277, 2, 'c', "..2/m", "1/2,0,0"),
    WyckoffPosition::new(277, 2, 'b', "..2/m", "0,1/2,0"),
    WyckoffPosition::new(277, 2, 'a', "..2/m", "0,0,0"),
    WyckoffPosition::new(278, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(278, 4, 'f', ".m.", "x,0,z"),
    WyckoffPosition::new(278, 4, 'e', "m..", "0,y,z"),
    WyckoffPosition::new(278, 4, 'd', "-1", "1/4,1/4,1/2"),
    WyckoffPosition::new(278, 4, 'c', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(278, 2, 'b', "mm2", "0,1/2,z"),
    WyckoffPosition::new(278, 2, 'a', "mm2", "0,0,z"),
    WyckoffPosition::new(279, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(279, 4, 'f', ".m.", "x,1/4,z"),
    WyckoffPosition::new(279, 4, 'e', "m..", "1/4,y,z"),
    WyckoffPosition::new(279, 4, 'd', "-1", "0,0,1/2"),
    WyckoffPosition::new(279, 4, 'c', "-1", "0,0,0"),
    WyckoffPosition::new(279, 2, 'b', "mm2", "1/4,3/4,z"),
    WyckoffPosition::new(279, 2, 'a', "mm2", "1/4,1/4,z"),
    WyckoffPosition::new(280, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(280, 4, 'f', ".m.", "x,y,0"),
    WyckoffPosition::new(280, 4, 'e', "m..", "x,0,z"),
    WyckoffPosition::new(280, 4, 'd', "-1", "1/2,1/4,1/4"),
    WyckoffPosition::new(280, 4, 'c', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(280, 2, 'b', "mm2", "x,0,1/2"),
    WyckoffPosition::new(280, 2, 'a', "mm2", "x,0,0"),
    WyckoffPosition::new(281, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(281, 4, 'f', ".m.", "x,y,1/4"),
    WyckoffPosition::new(281, 4, 'e', "m..", "x,1/4,z"),
    WyckoffPosition::new(281, 4, 'd', "-1", "1/2,0,0"),
    WyckoffPosition::new(281, 4, 'c', "-1", "0,0,0"),
    WyckoffPosition::new(281, 2, 'b', "mm2", "x,1/4,3/4"),
    WyckoffPosition::new(281, 2, 'a', "mm2", "x,1/4,1/4"),
    WyckoffPosition::new(282, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(282, 4, 'f', ".m.", "0,y,z"),
    WyckoffPosition::new(282, 4, 'e', "m..", "x,y,0"),
    WyckoffPosition::new(282, 4, 'd', "-1", "1/4,1/2,1/4"),
    WyckoffPosition::new(282, 4, 'c', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(282, 2, 'b', "mm2", "1/2,y,0"),
    WyckoffPosition::new(282, 2, 'a', "mm2", "0,y,0"),
    WyckoffPosition::new(283, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(283, 4, 'f', ".m.", "1/4,y,z"),
    WyckoffPosition::new(283, 4, 'e', "m..", "x,y,1/4"),
    WyckoffPosition::new(283, 4, 'd', "-1", "0,1/2,0"),
    WyckoffPosition::new(283, 4, 'c', "-1", "0,0,0"),
    WyckoffPosition::new(283, 2, 'b', "mm2", "3/4,y,1/4"),
    WyckoffPosition::new(283, 2, 'a', "mm2", "1/4,y,1/4"),
    WyckoffPosition::new(284, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(284, 4, 'c', ".2.", "0,y,1/4"),
    WyckoffPosition::new(284, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(284, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(285, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(285, 4, 'c', ".2.", "x,0,3/4"),
    WyckoffPosition::new(285, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(285, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(286, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(286, 4, 'c', ".2.", "1/4,0,z"),
    WyckoffPosition::new(286, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(286, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(287, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(287, 4, 'c', ".2.", "3/4,y,0"),
    WyckoffPosition::new(287, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(287, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(288, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(288, 4, 'c', ".2.", "x,1/4,0"),
    WyckoffPosition::new(288, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(288, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(289, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(289, 4, 'c', ".2.", "0,3/4,z"),
    WyckoffPosition::new(289, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(289, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(290, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(290, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(290, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(291, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(291, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(291, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(292, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(292, 4, 'c', ".m.", "x,1/4,z"),
    WyckoffPosition::new(292, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(292, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(293, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(293, 4, 'c', ".m.", "1/4,y,z"),
    WyckoffPosition::new(293, 4, 'b', "-1", "0,0,1/2"),
    WyckoffPosition::new(293, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(294, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(294, 4, 'c', ".m.", "x,y,1/4"),
    WyckoffPosition::new(294, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(294, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(295, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(295, 4, 'c', ".m.", "x,1/4,z"),
    WyckoffPosition::new(295, 4, 'b', "-1", "1/2,0,0"),
    WyckoffPosition::new(295, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(296, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(296, 4, 'c', ".m.", "1/4,y,z"),
    WyckoffPosition::new(296, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(296, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(297, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(297, 4, 'c', ".m.", "x,y,1/4"),
    WyckoffPosition::new(297, 4, 'b', "-1", "0,1/2,0"),
    WyckoffPosition::new(297, 4, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(298, 16, 'h', "1", "x,y,z"),
    WyckoffPosition::new(298, 8, 'g', "..m", "x,y,1/4"),
    WyckoffPosition::new(298, 8, 'f', "m..", "0,y,z"),
    WyckoffPosition::new(298, 8, 'e', "2..", "x,0,0"),
    WyckoffPosition::new(298, 8, 'd', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(298, 4, 'c', "m2m", "0,y,1/4"),
    WyckoffPosition::new(298, 4, 'b', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(298, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(299, 16, 'h', "1", "x,y,z"),
    WyckoffPosition::new(299, 8, 'g', "..m", "x,y,3/4"),
    WyckoffPosition::new(299, 8, 'f', "m..", "x,0,z"),
    WyckoffPosition::new(299, 8, 'e', "2..", "0,y,0"),
    WyckoffPosition::new(299, 8, 'd', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(299, 4, 'c', "m2m", "x,0,3/4"),
    WyckoffPosition::new(299, 4, 'b', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(299, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(300, 16, 'h', "1", "x,y,z"),
    WyckoffPosition::new(300, 8, 'g', "..m", "1/4,y,z"),
    WyckoffPosition::new(300, 8, 'f', "m..", "x,0,z"),
    WyckoffPosition::new(300, 8, 'e', "2..", "0,y,0"),
    WyckoffPosition::new(300, 8, 'd', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(300, 4, 'c', "m2m", "1/4,0,z"),
    WyckoffPosition::new(300, 4, 'b', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(300, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(301, 16, 'h', "1", "x,y,z"),
    WyckoffPosition::new(301, 8, 'g', "..m", "3/4,y,z"),
    WyckoffPosition::new(301, 8, 'f', "m..", "x,y,0"),
    WyckoffPosition::new(301, 8, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(301, 8, 'd', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(301, 4, 'c', "m2m", "3/4,y,0"),
    WyckoffPosition::new(301, 4, 'b', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(301, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(302, 16, 'h', "1", "x,y,z"),
    WyckoffPosition::new(302, 8, 'g', "..m", "x,1/4,z"),
    WyckoffPosition::new(302, 8, 'f', "m..", "x,y,0"),
    WyckoffPosition::new(302, 8, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(302, 8, 'd', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(302, 4, 'c', "m2m", "x,1/4,0"),
    WyckoffPosition::new(302, 4, 'b', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(302, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(303, 16, 'h', "1", "x,y,z"),
    WyckoffPosition::new(303, 8, 'g', "..m", "x,3/4,z"),
    WyckoffPosition::new(303, 8, 'f', "m..", "0,y,z"),
    WyckoffPosition::new(303, 8, 'e', "2..", "x,0,0"),
    WyckoffPosition::new(303, 8, 'd', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(303, 4, 'c', "m2m", "0,3/4,z"),
    WyckoffPosition::new(303, 4, 'b', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(303, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(304, 16, 'g', "1", "x,y,z"),
    WyckoffPosition::new(304, 8, 'f', "m..", "0,y,z"),
    WyckoffPosition::new(304, 8, 'e', ".2.", "1/4,y,1/4"),
    WyckoffPosition::new(304, 8, 'd', "2..", "x,0,0"),
    WyckoffPosition::new(304, 8, 'c', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(304, 4, 'b', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(304, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(305, 16, 'g', "1", "x,y,z"),
    WyckoffPosition::new(305, 8, 'f', "m..", "x,0,z"),
    WyckoffPosition::new(305, 8, 'e', ".2.", "x,1/4,3/4"),
    WyckoffPosition::new(305, 8, 'd', "2..", "0,y,0"),
    WyckoffPosition::new(305, 8, 'c', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(305, 4, 'b', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(305, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(306, 16, 'g', "1", "x,y,z"),
    WyckoffPosition::new(306, 8, 'f', "m..", "x,0,z"),
    WyckoffPosition::new(306, 8, 'e', ".2.", "1/4,1/4,z"),
    WyckoffPosition::new(306, 8, 'd', "2..", "0,y,0"),
    WyckoffPosition::new(306, 8, 'c', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(306, 4, 'b', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(306, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(307, 16, 'g', "1", "x,y,z"),
    WyckoffPosition::new(307, 8, 'f', "m..", "x,y,0"),
    WyckoffPosition::new(307, 8, 'e', ".2.", "3/4,y,1/4"),
    WyckoffPosition::new(307, 8, 'd', "2..", "0,0,z"),
    WyckoffPosition::new(307, 8, 'c', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(307, 4, 'b', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(307, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(308, 16, 'g', "1", "x,y,z"),
    WyckoffPosition::new(308, 8, 'f', "m..", "x,y,0"),
    WyckoffPosition::new(308, 8, 'e', ".2.", "x,1/4,1/4"),
    WyckoffPosition::new(308, 8, 'd', "2..", "0,0,z"),
    WyckoffPosition::new(308, 8, 'c', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(308, 4, 'b', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(308, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(309, 16, 'g', "1", "x,y,z"),
    WyckoffPosition::new(309, 8, 'f', "m..", "0,y,z"),
    WyckoffPosition::new(309, 8, 'e', ".2.", "1/4,3/4,z"),
    WyckoffPosition::new(309, 8, 'd', "2..", "x,0,0"),
    WyckoffPosition::new(309, 8, 'c', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(309, 4, 'b', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(309, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(310, 16, 'r', "1", "x,y,z"),
    WyckoffPosition::new(310, 8, 'q', "..m", "x,y,1/2"),
    WyckoffPosition::new(310, 8, 'p', "..m", "x,y,0"),
    WyckoffPosition::new(310, 8, 'o', ".m.", "x,0,z"),
    WyckoffPosition::new(310, 8, 'n', "m..", "0,y,z"),
    WyckoffPosition::new(310, 8, 'm', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(310, 4, 'l', "mm2", "0,1/2,z"),
    WyckoffPosition::new(310, 4, 'k', "mm2", "0,0,z"),
    WyckoffPosition::new(310, 4, 'j', "m2m", "0,y,1/2"),
    WyckoffPosition::new(310, 4, 'i', "m2m", "0,y,0"),
    WyckoffPosition::new(310, 4, 'h', "2mm", "x,0,1/2"),
    WyckoffPosition::new(310, 4, 'g', "2mm", "x,0,0"),
    WyckoffPosition::new(310, 4, 'f', "..2/m", "1/4,1/4,1/2"),
    WyckoffPosition::new(310, 4, 'e', "..2/m", "1/4,1/4,0"),
    WyckoffPosition::new(310, 2, 'd', "mmm", "0,0,1/2"),
    WyckoffPosition::new(310, 2, 'c', "mmm", "1/2,0,1/2"),
    WyckoffPosition::new(310, 2, 'b', "mmm", "1/2,0,0"),
    WyckoffPosition::new(310, 2, 'a', "mmm", "0,0,0"),
    WyckoffPosition::new(311, 16, 'r', "1", "x,y,z"),
    WyckoffPosition::new(311, 8, 'q', "..m", "1/2,y,z"),
    WyckoffPosition::new(311, 8, 'p', "..m", "0,y,z"),
    WyckoffPosition::new(311, 8, 'o', ".m.", "x,y,0"),
    WyckoffPosition::new(311, 8, 'n', "m..", "x,0,z"),
    WyckoffPosition::new(311, 8, 'm', "..2", "x,1/4,1/4"),
    WyckoffPosition::new(311, 4, 'l', "mm2", "x,0,1/2"),
    WyckoffPosition::new(311, 4, 'k', "mm2", "x,0,0"),
    WyckoffPosition::new(311, 4, 'j', "m2m", "1/2,0,z"),
    WyckoffPosition::new(311, 4, 'i', "m2m", "0,0,z"),
    WyckoffPosition::new(311, 4, 'h', "2mm", "1/2,y,0"),
    WyckoffPosition::new(311, 4, 'g', "2mm", "0,y,0"),
    WyckoffPosition::new(311, 4, 'f', "..2/m", "1/2,1/4,1/4"),
    WyckoffPosition::new(311, 4, 'e', "..2/m", "0,1/4,1/4"),
    WyckoffPosition::new(311, 2, 'd', "mmm", "1/2,0,0"),
    WyckoffPosition::new(311, 2, 'c', "mmm", "1/2,1/2,0"),
    WyckoffPosition::new(311, 2, 'b', "mmm", "0,1/2,0"),
    WyckoffPosition::new(311, 2, 'a', "mmm", "0,0,0"),
    WyckoffPosition::new(312, 16, 'r', "1", "x,y,z"),
    WyckoffPosition::new(312, 8, 'q', "..m", "x,1/2,z"),
    WyckoffPosition::new(312, 8, 'p', "..m", "x,0,z"),
    WyckoffPosition::new(312, 8, 'o', ".m.", "0,y,z"),
    WyckoffPosition::new(312, 8, 'n', "m..", "x,y,0"),
    WyckoffPosition::new(312, 8, 'm', "..2", "1/4,y,1/4"),
    WyckoffPosition::new(312, 4, 'l', "mm2", "1/2,y,0"),
    WyckoffPosition::new(312, 4, 'k', "mm2", "0,y,0"),
    WyckoffPosition::new(312, 4, 'j', "m2m", "x,1/2,0"),
    WyckoffPosition::new(312, 4, 'i', "m2m", "x,0,0"),
    WyckoffPosition::new(312, 4, 'h', "2mm", "0,1/2,z"),
    WyckoffPosition::new(312, 4, 'g', "2mm", "0,0,z"),
    WyckoffPosition::new(312, 4, 'f', "..2/m", "1/4,1/2,1/4"),
    WyckoffPosition::new(312, 4, 'e', "..2/m", "1/4,0,1/4"),
    WyckoffPosition::new(312, 2, 'd', "mmm", "0,1/2,0"),
    WyckoffPosition::new(312, 2, 'c', "mmm", "0,1/2,1/2"),
    WyckoffPosition::new(312, 2, 'b', "mmm", "0,0,1/2"),
    WyckoffPosition::new(312, 2, 'a', "mmm", "0,0,0"),
    WyckoffPosition::new(313, 16, 'm', "1", "x,y,z"),
    WyckoffPosition::new(313, 8, 'l', "..m", "x,y,0"),
    WyckoffPosition::new(313, 8, 'k', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(313, 8, 'j', "..2", "0,1/2,z"),
    WyckoffPosition::new(313, 8, 'i', "..2", "0,0,z"),
    WyckoffPosition::new(313, 8, 'h', ".2.", "0,y,1/4"),
    WyckoffPosition::new(313, 8, 'g', "2..", "x,0,1/4"),
    WyckoffPosition::new(313, 4, 'f', "..2/m", "1/4,3/4,0"),
    WyckoffPosition::new(313, 4, 'e', "..2/m", "1/4,1/4,0"),
    WyckoffPosition::new(313, 4, 'd', "..2/m", "0,1/2,0"),
    WyckoffPosition::new(313, 4, 'c', "..2/m", "0,0,0"),
    WyckoffPosition::new(313, 4, 'b', "222", "0,1/2,1/4"),
    WyckoffPosition::new(313, 4, 'a', "222", "0,0,1/4"),
    WyckoffPosition::new(314, 16, 'm', "1", "x,y,z"),
    WyckoffPosition::new(314, 8, 'l', "..m", "0,y,z"),
    WyckoffPosition::new(314, 8, 'k', "..2", "x,1/4,1/4"),
    WyckoffPosition::new(314, 8, 'j', "..2", "x,0,1/2"),
    WyckoffPosition::new(314, 8, 'i', "..2", "x,0,0"),
    WyckoffPosition::new(314, 8, 'h', ".2.", "1/4,0,z"),
    WyckoffPosition::new(314, 8, 'g', "2..", "1/4,y,0"),
    WyckoffPosition::new(314, 4, 'f', "..2/m", "0,1/4,3/4"),
    WyckoffPosition::new(314, 4, 'e', "..2/m", "0,1/4,1/4"),
    WyckoffPosition::new(314, 4, 'd', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(314, 4, 'c', "..2/m", "0,0,0"),
    WyckoffPosition::new(314, 4, 'b', "222", "1/4,0,1/2"),
    WyckoffPosition::new(314, 4, 'a', "222", "1/4,0,0"),
    WyckoffPosition::new(315, 16, 'm', "1", "x,y,z"),
    WyckoffPosition::new(315, 8, 'l', "..m", "x,0,z"),
    WyckoffPosition::new(315, 8, 'k', "..2", "1/4,y,1/4"),
    WyckoffPosition::new(315, 8, 'j', "..2", "1/2,y,0"),
    WyckoffPosition::new(315, 8, 'i', "..2", "0,y,0"),
    WyckoffPosition::new(315, 8, 'h', ".2.", "x,1/4,0"),
    WyckoffPosition::new(315, 8, 'g', "2..", "0,1/4,z"),
    WyckoffPosition::new(315, 4, 'f', "..2/m", "3/4,0,1/4"),
    WyckoffPosition::new(315, 4, 'e', "..2/m", "1/4,0,1/4"),
    WyckoffPosition::new(315, 4, 'd', "..2/m", "1/2,0,0"),
    WyckoffPosition::new(315, 4, 'c', "..2/m", "0,0,0"),
    WyckoffPosition::new(315, 4, 'b', "222", "1/2,1/4,0"),
    WyckoffPosition::new(315, 4, 'a', "222", "0,1/4,0"),
    WyckoffPosition::new(316, 16, 'o', "1", "x,y,z"),
    WyckoffPosition::new(316, 8, 'n', ".m.", "x,1/4,z"),
    WyckoffPosition::new(316, 8, 'm', "m..", "0,y,z"),
    WyckoffPosition::new(316, 8, 'l', "..2", "1/4,0,z"),
    WyckoffPosition::new(316, 8, 'k', ".2.", "1/4,y,1/2"),
    WyckoffPosition::new(316, 8, 'j', ".2.", "1/4,y,0"),
    WyckoffPosition::new(316, 8, 'i', "2..", "x,0,1/2"),
    WyckoffPosition::new(316, 8, 'h', "2..", "x,0,0"),
    WyckoffPosition::new(316, 4, 'g', "mm2", "0,1/4,z"),
    WyckoffPosition::new(316, 4, 'f', ".2/m.", "1/4,1/4,1/2"),
    WyckoffPosition::new(316, 4, 'e', ".2/m.", "1/4,1/4,0"),
    WyckoffPosition::new(316, 4, 'd', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(316, 4, 'c', "2/m..", "0,0,0"),
    WyckoffPosition::new(316, 4, 'b', "222", "1/4,0,1/2"),
    WyckoffPosition::new(316, 4, 'a', "222", "1/4,0,0"),
    WyckoffPosition::new(317, 16, 'o', "1", "x,y,z"),
    WyckoffPosition::new(317, 8, 'n', ".m.", "1/4,y,z"),
    WyckoffPosition::new(317, 8, 'm', "m..", "x,0,z"),
    WyckoffPosition::new(317, 8, 'l', "..2", "0,1/4,z"),
    WyckoffPosition::new(317, 8, 'k', ".2.", "x,1/4,1/2"),
    WyckoffPosition::new(317, 8, 'j', ".2.", "x,1/4,0"),
    WyckoffPosition::new(317, 8, 'i', "2..", "0,y,1/2"),
    WyckoffPosition::new(317, 8, 'h', "2..", "0,y,0"),
    WyckoffPosition::new(317, 4, 'g', "mm2", "1/4,0,z"),
    WyckoffPosition::new(317, 4, 'f', ".2/m.", "1/4,1/4,1/2"),
    WyckoffPosition::new(317, 4, 'e', ".2/m.", "1/4,1/4,0"),
    WyckoffPosition::new(317, 4, 'd', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(317, 4, 'c', "2/m..", "0,0,0"),
    WyckoffPosition::new(317, 4, 'b', "222", "0,1/4,1/2"),
    WyckoffPosition::new(317, 4, 'a', "222", "0,1/4,0"),
    WyckoffPosition::new(318, 16, 'o', "1", "x,y,z"),
    WyckoffPosition::new(318, 8, 'n', ".m.", "x,y,1/4"),
    WyckoffPosition::new(318, 8, 'm', "m..", "x,0,z"),
    WyckoffPosition::new(318, 8, 'l', "..2", "x,1/4,0"),
    WyckoffPosition::new(318, 8, 'k', ".2.", "1/2,1/4,z"),
    WyckoffPosition::new(318, 8, 'j', ".2.", "0,1/4,z"),
    WyckoffPosition::new(318, 8, 'i', "2..", "1/2,y,0"),
    WyckoffPosition::new(318, 8, 'h', "2..", "0,y,0"),
    WyckoffPosition::new(318, 4, 'g', "mm2", "x,0,1/4"),
    WyckoffPosition::new(318, 4, 'f', ".2/m.", "1/2,1/4,1/4"),
    WyckoffPosition::new(318, 4, 'e', ".2/m.", "0,1/4,1/4"),
    WyckoffPosition::new(318, 4, 'd', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(318, 4, 'c', "2/m..", "0,0,0"),
    WyckoffPosition::new(318, 4, 'b', "222", "1/2,1/4,0"),
    WyckoffPosition::new(318, 4, 'a', "222", "0,1/4,0"),
    WyckoffPosition::new(319, 16, 'o', "1", "x,y,z"),
    WyckoffPosition::new(319, 8, 'n', ".m.", "x,1/4,z"),
    WyckoffPosition::new(319, 8, 'm', "m..", "x,y,0"),
    WyckoffPosition::new(319, 8, 'l', "..2", "x,0,1/4"),
    WyckoffPosition::new(319, 8, 'k', ".2.", "1/2,y,1/4"),
    WyckoffPosition::new(319, 8, 'j', ".2.", "0,y,1/4"),
    WyckoffPosition::new(319, 8, 'i', "2..", "1/2,0,z"),
    WyckoffPosition::new(319, 8, 'h', "2..", "0,0,z"),
    WyckoffPosition::new(319, 4, 'g', "mm2", "x,1/4,0"),
    WyckoffPosition::new(319, 4, 'f', ".2/m.", "1/2,1/4,1/4"),
    WyckoffPosition::new(319, 4, 'e', ".2/m.", "0,1/4,1/4"),
    WyckoffPosition::new(319, 4, 'd', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(319, 4, 'c', "2/m..", "0,0,0"),
    WyckoffPosition::new(319, 4, 'b', "222", "1/2,0,1/4"),
    WyckoffPosition::new(319, 4, 'a', "222", "0,0,1/4"),
    WyckoffPosition::new(320, 16, 'o', "1", "x,y,z"),
    WyckoffPosition::new(320, 8, 'n', ".m.", "1/4,y,z"),
    WyckoffPosition::new(320, 8, 'm', "m..", "x,y,0"),
    WyckoffPosition::new(320, 8, 'l', "..2", "0,y,1/4"),
    WyckoffPosition::new(320, 8, 'k', ".2.", "x,1/2,1/4"),
    WyckoffPosition::new(320, 8, 'j', ".2.", "x,0,1/4"),
    WyckoffPosition::new(320, 8, 'i', "2..", "0,1/2,z"),
    WyckoffPosition::new(320, 8, 'h', "2..", "0,0,z"),
    WyckoffPosition::new(320, 4, 'g', "mm2", "1/4,y,0"),
    WyckoffPosition::new(320, 4, 'f', ".2/m.", "1/4,1/2,1/4"),
    WyckoffPosition::new(320, 4, 'e', ".2/m.", "1/4,0,1/4"),
    WyckoffPosition::new(320, 4, 'd', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(320, 4, 'c', "2/m..", "0,0,0"),
    WyckoffPosition::new(320, 4, 'b', "222", "0,1/2,1/4"),
    WyckoffPosition::new(320, 4, 'a', "222", "0,0,1/4"),
    WyckoffPosition::new(321, 16, 'o', "1", "x,y,z"),
    WyckoffPosition::new(321, 8, 'n', ".m.", "x,y,1/4"),
    WyckoffPosition::new(321, 8, 'm', "m..", "0,y,z"),
    WyckoffPosition::new(321, 8, 'l', "..2", "1/4,y,0"),
    WyckoffPosition::new(321, 8, 'k', ".2.", "1/4,1/2,z"),
    WyckoffPosition::new(321, 8, 'j', ".2.", "1/4,0,z"),
    WyckoffPosition::new(321, 8, 'i', "2..", "x,1/2,0"),
    WyckoffPosition::new(321, 8, 'h', "2..", "x,0,0"),
    WyckoffPosition::new(321, 4, 'g', "mm2", "0,y,1/4"),
    WyckoffPosition::new(321, 4, 'f', ".2/m.", "1/4,1/2,1/4"),
    WyckoffPosition::new(321, 4, 'e', ".2/m.", "1/4,0,1/4"),
    WyckoffPosition::new(321, 4, 'd', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(321, 4, 'c', "2/m..", "0,0,0"),
    WyckoffPosition::new(321, 4, 'b', "222", "1/4,1/2,0"),
    WyckoffPosition::new(321, 4, 'a', "222", "1/4,0,0"),
    WyckoffPosition::new(322, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(322, 8, 'h', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(322, 8, 'g', "..2", "0,0,z"),
    WyckoffPosition::new(322, 8, 'f', ".2.", "0,y,0"),
    WyckoffPosition::new(322, 8, 'e', "2..", "x,0,0"),
    WyckoffPosition::new(322, 8, 'd', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(322, 8, 'c', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(322, 4, 'b', "222", "0,0,1/2"),
    WyckoffPosition::new(322, 4, 'a', "222", "0,0,0"),
    WyckoffPosition::new(323, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(323, 8, 'h', "..2", "1/4,0,z"),
    WyckoffPosition::new(323, 8, 'g', "..2", "0,1/4,z"),
    WyckoffPosition::new(323, 8, 'f', ".2.", "0,y,1/4"),
    WyckoffPosition::new(323, 8, 'e', "2..", "x,1/4,1/4"),
    WyckoffPosition::new(323, 8, 'd', "-1", "0,0,0"),
    WyckoffPosition::new(323, 8, 'c', "-1", "1/4,3/4,0"),
    WyckoffPosition::new(323, 4, 'b', "222", "0,1/4,3/4"),
    WyckoffPosition::new(323, 4, 'a', "222", "0,1/4,1/4"),
    WyckoffPosition::new(324, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(324, 8, 'h', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(324, 8, 'g', "..2", "0,0,z"),
    WyckoffPosition::new(324, 8, 'f', ".2.", "x,0,0"),
    WyckoffPosition::new(324, 8, 'e', "2..", "0,y,0"),
    WyckoffPosition::new(324, 8, 'd', "-1", "1/4,0,3/4"),
    WyckoffPosition::new(324, 8, 'c', "-1", "0,1/4,3/4"),
    WyckoffPosition::new(324, 4, 'b', "222", "0,0,1/2"),
    WyckoffPosition::new(324, 4, 'a', "222", "0,0,0"),
    WyckoffPosition::new(325, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(325, 8, 'h', "..2", "0,1/4,z"),
    WyckoffPosition::new(325, 8, 'g', "..2", "1/4,0,z"),
    WyckoffPosition::new(325, 8, 'f', ".2.", "x,0,3/4"),
    WyckoffPosition::new(325, 8, 'e', "2..", "1/4,y,3/4"),
    WyckoffPosition::new(325, 8, 'd', "-1", "0,0,0"),
    WyckoffPosition::new(325, 8, 'c', "-1", "3/4,1/4,0"),
    WyckoffPosition::new(325, 4, 'b', "222", "1/4,0,1/4"),
    WyckoffPosition::new(325, 4, 'a', "222", "1/4,0,3/4"),
    WyckoffPosition::new(326, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(326, 8, 'h', "..2", "x,1/4,1/4"),
    WyckoffPosition::new(326, 8, 'g', "..2", "x,0,0"),
    WyckoffPosition::new(326, 8, 'f', ".2.", "0,0,z"),
    WyckoffPosition::new(326, 8, 'e', "2..", "0,y,0"),
    WyckoffPosition::new(326, 8, 'd', "-1", "1/4,0,1/4"),
    WyckoffPosition::new(326, 8, 'c', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(326, 4, 'b', "222", "1/2,0,0"),
    WyckoffPosition::new(326, 4, 'a', "222", "0,0,0"),
    WyckoffPosition::new(327, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(327, 8, 'h', "..2", "x,1/4,0"),
    WyckoffPosition::new(327, 8, 'g', "..2", "x,0,1/4"),
    WyckoffPosition::new(327, 8, 'f', ".2.", "1/4,0,z"),
    WyckoffPosition::new(327, 8, 'e', "2..", "1/4,y,1/4"),
    WyckoffPosition::new(327, 8, 'd', "-1", "0,0,0"),
    WyckoffPosition::new(327, 8, 'c', "-1", "0,1/4,3/4"),
    WyckoffPosition::new(327, 4, 'b', "222", "3/4,0,1/4"),
    WyckoffPosition::new(327, 4, 'a', "222", "1/4,0,1/4"),
    WyckoffPosition::new(328, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(328, 8, 'h', "..2", "x,1/4,1/4"),
    WyckoffPosition::new(328, 8, 'g', "..2", "x,0,0"),
    WyckoffPosition::new(328, 8, 'f', ".2.", "0,y,0"),
    WyckoffPosition::new(328, 8, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(328, 8, 'd', "-1", "3/4,1/4,0"),
    WyckoffPosition::new(328, 8, 'c', "-1", "3/4,0,1/4"),
    WyckoffPosition::new(328, 4, 'b', "222", "1/2,0,0"),
    WyckoffPosition::new(328, 4, 'a', "222", "0,0,0"),
    WyckoffPosition::new(329, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(329, 8, 'h', "..2", "x,0,1/4"),
    WyckoffPosition::new(329, 8, 'g', "..2", "x,1/4,0"),
    WyckoffPosition::new(329, 8, 'f', ".2.", "3/4,y,0"),
    WyckoffPosition::new(329, 8, 'e', "2..", "3/4,1/4,z"),
    WyckoffPosition::new(329, 8, 'd', "-1", "0,0,0"),
    WyckoffPosition::new(329, 8, 'c', "-1", "0,3/4,1/4"),
    WyckoffPosition::new(329, 4, 'b', "222", "1/4,1/4,0"),
    WyckoffPosition::new(329, 4, 'a', "222", "3/4,1/4,0"),
    WyckoffPosition::new(330, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(330, 8, 'h', "..2", "1/4,y,1/4"),
    WyckoffPosition::new(330, 8, 'g', "..2", "0,y,0"),
    WyckoffPosition::new(330, 8, 'f', ".2.", "x,0,0"),
    WyckoffPosition::new(330, 8, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(330, 8, 'd', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(330, 8, 'c', "-1", "0,1/4,1/4"),
    WyckoffPosition::new(330, 4, 'b', "222", "0,1/2,0"),
    WyckoffPosition::new(330, 4, 'a', "222", "0,0,0"),
    WyckoffPosition::new(331, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(331, 8, 'h', "..2", "0,y,1/4"),
    WyckoffPosition::new(331, 8, 'g', "..2", "1/4,y,0"),
    WyckoffPosition::new(331, 8, 'f', ".2.", "x,1/4,0"),
    WyckoffPosition::new(331, 8, 'e', "2..", "1/4,1/4,z"),
    WyckoffPosition::new(331, 8, 'd', "-1", "0,0,0"),
    WyckoffPosition::new(331, 8, 'c', "-1", "3/4,0,1/4"),
    WyckoffPosition::new(331, 4, 'b', "222", "1/4,3/4,0"),
    WyckoffPosition::new(331, 4, 'a', "222", "1/4,1/4,0"),
    WyckoffPosition::new(332, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(332, 8, 'h', "..2", "1/4,y,1/4"),
    WyckoffPosition::new(332, 8, 'g', "..2", "0,y,0"),
    WyckoffPosition::new(332, 8, 'f', ".2.", "0,0,z"),
    WyckoffPosition::new(332, 8, 'e', "2..", "x,0,0"),
    WyckoffPosition::new(332, 8, 'd', "-1", "0,3/4,1/4"),
    WyckoffPosition::new(332, 8, 'c', "-1", "1/4,3/4,0"),
    WyckoffPosition::new(332, 4, 'b', "222", "0,1/2,0"),
    WyckoffPosition::new(332, 4, 'a', "222", "0,0,0"),
    WyckoffPosition::new(333, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(333, 8, 'h', "..2", "1/4,y,0"),
    WyckoffPosition::new(333, 8, 'g', "..2", "0,y,1/4"),
    WyckoffPosition::new(333, 8, 'f', ".2.", "0,3/4,z"),
    WyckoffPosition::new(333, 8, 'e', "2..", "x,3/4,1/4"),
    WyckoffPosition::new(333, 8, 'd', "-1", "0,0,0"),
    WyckoffPosition::new(333, 8, 'c', "-1", "1/4,0,3/4"),
    WyckoffPosition::new(333, 4, 'b', "222", "0,1/4,1/4"),
    WyckoffPosition::new(333, 4, 'a', "222", "0,3/4,1/4"),
    WyckoffPosition::new(334, 32, 'p', "1", "x,y,z"),
    WyckoffPosition::new(334, 16, 'o', "..m", "x,y,0"),
    WyckoffPosition::new(334, 16, 'n', ".m.", "x,0,z"),
    WyckoffPosition::new(334, 16, 'm', "m..", "0,y,z"),
    WyckoffPosition::new(334, 16, 'l', "2..", "x,1/4,1/4"),
    WyckoffPosition::new(334, 16, 'k', ".2.", "1/4,y,1/4"),
    WyckoffPosition::new(334, 16, 'j', "..2", "1/4,1/4,z"),
    WyckoffPosition::new(334, 8, 'i', "mm2", "0,0,z"),
    WyckoffPosition::new(334, 8, 'h', "m2m", "0,y,0"),
    WyckoffPosition::new(334, 8, 'g', "2mm", "x,0,0"),
    WyckoffPosition::new(334, 8, 'f', "222", "1/4,1/4,1/4"),
    WyckoffPosition::new(334, 8, 'e', "..2/m", "1/4,1/4,0"),
    WyckoffPosition::new(334, 8, 'd', ".2/m.", "1/4,0,1/4"),
    WyckoffPosition::new(334, 8, 'c', "2/m..", "0,1/4,1/4"),
    WyckoffPosition::new(334, 4, 'b', "mmm", "0,0,1/2"),
    WyckoffPosition::new(334, 4, 'a', "mmm", "0,0,0"),
    WyckoffPosition::new(335, 32, 'h', "1", "x,y,z"),
    WyckoffPosition::new(335, 16, 'g', "..2", "0,0,z"),
    WyckoffPosition::new(335, 16, 'f', ".2.", "0,y,0"),
    WyckoffPosition::new(335, 16, 'e', "2..", "x,0,0"),
    WyckoffPosition::new(335, 16, 'd', "-1", "5/8,5/8,5/8"),
    WyckoffPosition::new(335, 16, 'c', "-1", "1/8,1/8,1/8"),
    WyckoffPosition::new(335, 8, 'b', "222", "0,0,1/2"),
    WyckoffPosition::new(335, 8, 'a', "222", "0,0,0"),
    WyckoffPosition::new(336, 32, 'h', "1", "x,y,z"),
    WyckoffPosition::new(336, 16, 'g', "..2", "1/8,1/8,z"),
    WyckoffPosition::new(336, 16, 'f', ".2.", "1/8,y,1/8"),
    WyckoffPosition::new(336, 16, 'e', "2..", "x,1/8,1/8"),
    WyckoffPosition::new(336, 16, 'd', "-1", "1/2,1/2,1/2"),
    WyckoffPosition::new(336, 16, 'c', "-1", "0,0,0"),
    WyckoffPosition::new(336, 8, 'b', "222", "1/8,1/8,5/8"),
    WyckoffPosition::new(336, 8, 'a', "222", "1/8,1/8,1/8"),
    WyckoffPosition::new(337, 16, 'o', "1", "x,y,z"),
    WyckoffPosition::new(337, 8, 'n', "..m", "x,y,0"),
    WyckoffPosition::new(337, 8, 'm', ".m.", "x,0,z"),
    WyckoffPosition::new(337, 8, 'l', "m..", "0,y,z"),
    WyckoffPosition::new(337, 8, 'k', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(337, 4, 'j', "mm2", "1/2,0,z"),
    WyckoffPosition::new(337, 4, 'i', "mm2", "0,0,z"),
    WyckoffPosition::new(337, 4, 'h', "m2m", "0,y,1/2"),
    WyckoffPosition::new(337, 4, 'g', "m2m", "0,y,0"),
    WyckoffPosition::new(337, 4, 'f', "2mm", "x,1/2,0"),
    WyckoffPosition::new(337, 4, 'e', "2mm", "x,0,0"),
    WyckoffPosition::new(337, 2, 'd', "mmm", "1/2,0,1/2"),
    WyckoffPosition::new(337, 2, 'c', "mmm", "1/2,1/2,0"),
    WyckoffPosition::new(337, 2, 'b', "mmm", "0,1/2,1/2"),
    WyckoffPosition::new(337, 2, 'a', "mmm", "0,0,0"),
    WyckoffPosition::new(338, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(338, 8, 'j', "..m", "x,y,0"),
    WyckoffPosition::new(338, 8, 'i', "..2", "0,1/2,z"),
    WyckoffPosition::new(338, 8, 'h', "..2", "0,0,z"),
    WyckoffPosition::new(338, 8, 'g', ".2.", "0,y,1/4"),
    WyckoffPosition::new(338, 8, 'f', "2..", "x,0,1/4"),
    WyckoffPosition::new(338, 8, 'e', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(338, 4, 'd', "..2/m", "1/2,0,0"),
    WyckoffPosition::new(338, 4, 'c', "..2/m", "0,0,0"),
    WyckoffPosition::new(338, 4, 'b', "222", "1/2,0,1/4"),
    WyckoffPosition::new(338, 4, 'a', "222", "0,0,1/4"),
    WyckoffPosition::new(339, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(339, 8, 'j', "..m", "0,y,z"),
    WyckoffPosition::new(339, 8, 'i', "..2", "x,0,1/2"),
    WyckoffPosition::new(339, 8, 'h', "..2", "x,0,0"),
    WyckoffPosition::new(339, 8, 'g', ".2.", "1/4,0,z"),
    WyckoffPosition::new(339, 8, 'f', "2..", "1/4,y,0"),
    WyckoffPosition::new(339, 8, 'e', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(339, 4, 'd', "..2/m", "0,1/2,0"),
    WyckoffPosition::new(339, 4, 'c', "..2/m", "0,0,0"),
    WyckoffPosition::new(339, 4, 'b', "222", "1/4,1/2,0"),
    WyckoffPosition::new(339, 4, 'a', "222", "1/4,0,0"),
    WyckoffPosition::new(340, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(340, 8, 'j', "..m", "x,0,z"),
    WyckoffPosition::new(340, 8, 'i', "..2", "1/2,y,0"),
    WyckoffPosition::new(340, 8, 'h', "..2", "0,y,0"),
    WyckoffPosition::new(340, 8, 'g', ".2.", "x,1/4,0"),
    WyckoffPosition::new(340, 8, 'f', "2..", "0,1/4,z"),
    WyckoffPosition::new(340, 8, 'e', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(340, 4, 'd', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(340, 4, 'c', "..2/m", "0,0,0"),
    WyckoffPosition::new(340, 4, 'b', "222", "0,1/4,1/2"),
    WyckoffPosition::new(340, 4, 'a', "222", "0,1/4,0"),
    WyckoffPosition::new(341, 16, 'f', "1", "x,y,z"),
    WyckoffPosition::new(341, 8, 'e', "..2", "0,1/4,z"),
    WyckoffPosition::new(341, 8, 'd', ".2.", "1/4,y,0"),
    WyckoffPosition::new(341, 8, 'c', "2..", "x,0,1/4"),
    WyckoffPosition::new(341, 8, 'b', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(341, 8, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(342, 16, 'f', "1", "x,y,z"),
    WyckoffPosition::new(342, 8, 'e', "..2", "1/4,0,z"),
    WyckoffPosition::new(342, 8, 'd', ".2.", "x,1/4,0"),
    WyckoffPosition::new(342, 8, 'c', "2..", "0,y,3/4"),
    WyckoffPosition::new(342, 8, 'b', "-1", "1/4,1/4,3/4"),
    WyckoffPosition::new(342, 8, 'a', "-1", "0,0,0"),
    WyckoffPosition::new(343, 16, 'j', "1", "x,y,z"),
    WyckoffPosition::new(343, 8, 'i', ".m.", "x,1/4,z"),
    WyckoffPosition::new(343, 8, 'h', "m..", "0,y,z"),
    WyckoffPosition::new(343, 8, 'g', ".2.", "1/4,y,1/4"),
    WyckoffPosition::new(343, 8, 'f', "2..", "x,0,0"),
    WyckoffPosition::new(343, 4, 'e', "mm2", "0,1/4,z"),
    WyckoffPosition::new(343, 4, 'd', ".2/m.", "1/4,1/4,3/4"),
    WyckoffPosition::new(343, 4, 'c', ".2/m.", "1/4,1/4,1/4"),
    WyckoffPosition::new(343, 4, 'b', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(343, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(344, 16, 'j', "1", "x,y,z"),
    WyckoffPosition::new(344, 8, 'i', ".m.", "1/4,y,z"),
    WyckoffPosition::new(344, 8, 'h', "m..", "x,0,z"),
    WyckoffPosition::new(344, 8, 'g', ".2.", "x,1/4,3/4"),
    WyckoffPosition::new(344, 8, 'f', "2..", "0,y,0"),
    WyckoffPosition::new(344, 4, 'e', "mm2", "1/4,0,z"),
    WyckoffPosition::new(344, 4, 'd', ".2/m.", "1/4,1/4,1/4"),
    WyckoffPosition::new(344, 4, 'c', ".2/m.", "1/4,1/4,3/4"),
    WyckoffPosition::new(344, 4, 'b', "2/m..", "0,0,1/2"),
    WyckoffPosition::new(344, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(345, 16, 'j', "1", "x,y,z"),
    WyckoffPosition::new(345, 8, 'i', ".m.", "x,y,1/4"),
    WyckoffPosition::new(345, 8, 'h', "m..", "x,0,z"),
    WyckoffPosition::new(345, 8, 'g', ".2.", "1/4,1/4,z"),
    WyckoffPosition::new(345, 8, 'f', "2..", "0,y,0"),
    WyckoffPosition::new(345, 4, 'e', "mm2", "x,0,1/4"),
    WyckoffPosition::new(345, 4, 'd', ".2/m.", "3/4,1/4,1/4"),
    WyckoffPosition::new(345, 4, 'c', ".2/m.", "1/4,1/4,1/4"),
    WyckoffPosition::new(345, 4, 'b', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(345, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(346, 16, 'j', "1", "x,y,z"),
    WyckoffPosition::new(346, 8, 'i', ".m.", "x,1/4,z"),
    WyckoffPosition::new(346, 8, 'h', "m..", "x,y,0"),
    WyckoffPosition::new(346, 8, 'g', ".2.", "3/4,y,1/4"),
    WyckoffPosition::new(346, 8, 'f', "2..", "0,0,z"),
    WyckoffPosition::new(346, 4, 'e', "mm2", "x,1/4,0"),
    WyckoffPosition::new(346, 4, 'd', ".2/m.", "1/4,1/4,1/4"),
    WyckoffPosition::new(346, 4, 'c', ".2/m.", "3/4,1/4,1/4"),
    WyckoffPosition::new(346, 4, 'b', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(346, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(347, 16, 'j', "1", "x,y,z"),
    WyckoffPosition::new(347, 8, 'i', ".m.", "1/4,y,z"),
    WyckoffPosition::new(347, 8, 'h', "m..", "x,y,0"),
    WyckoffPosition::new(347, 8, 'g', ".2.", "x,1/4,1/4"),
    WyckoffPosition::new(347, 8, 'f', "2..", "0,0,z"),
    WyckoffPosition::new(347, 4, 'e', "mm2", "1/4,y,0"),
    WyckoffPosition::new(347, 4, 'd', ".2/m.", "1/4,3/4,1/4"),
    WyckoffPosition::new(347, 4, 'c', ".2/m.", "1/4,1/4,1/4"),
    WyckoffPosition::new(347, 4, 'b', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(347, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(348, 16, 'j', "1", "x,y,z"),
    WyckoffPosition::new(348, 8, 'i', ".m.", "x,y,1/4"),
    WyckoffPosition::new(348, 8, 'h', "m..", "0,y,z"),
    WyckoffPosition::new(348, 8, 'g', ".2.", "1/4,3/4,z"),
    WyckoffPosition::new(348, 8, 'f', "2..", "x,0,0"),
    WyckoffPosition::new(348, 4, 'e', "mm2", "0,y,1/4"),
    WyckoffPosition::new(348, 4, 'd', ".2/m.", "1/4,1/4,1/4"),
    WyckoffPosition::new(348, 4, 'c', ".2/m.", "1/4,3/4,1/4"),
    WyckoffPosition::new(348, 4, 'b', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(348, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(349, 4, 'd', "1", "x,y,z"),
    WyckoffPosition::new(349, 2, 'c', "2..", "0,1/2,z"),
    WyckoffPosition::new(349, 1, 'b', "4..", "1/2,1/2,z"),
    WyckoffPosition::new(349, 1, 'a', "4..", "0,0,z"),
    WyckoffPosition::new(350, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(351, 4, 'd', "1", "x,y,z"),
    WyckoffPosition::new(351, 2, 'c', "2..", "0,1/2,z"),
    WyckoffPosition::new(351, 2, 'b', "2..", "1/2,1/2,z"),
    WyckoffPosition::new(351, 2, 'a', "2..", "0,0,z"),
    WyckoffPosition::new(352, 4, 'a', "1", "x,y,z"),
    WyckoffPosition::new(353, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(353, 4, 'b', "2..", "0,1/2,z"),
    WyckoffPosition::new(353, 2, 'a', "4..", "0,0,z"),
    WyckoffPosition::new(354, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(354, 4, 'a', "2..", "0,0,z"),
    WyckoffPosition::new(355, 4, 'h', "1", "x,y,z"),
    WyckoffPosition::new(355, 2, 'g', "2..", "0,1/2,z"),
    WyckoffPosition::new(355, 2, 'f', "2..", "1/2,1/2,z"),
    WyckoffPosition::new(355, 2, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(355, 1, 'd', "-4..", "1/2,1/2,1/2"),
    WyckoffPosition::new(355, 1, 'c', "-4..", "1/2,1/2,0"),
    WyckoffPosition::new(355, 1, 'b', "-4..", "0,0,1/2"),
    WyckoffPosition::new(355, 1, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(356, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(356, 4, 'f', "2..", "0,1/2,z"),
    WyckoffPosition::new(356, 4, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(356, 2, 'd', "-4..", "0,1/2,3/4"),
    WyckoffPosition::new(356, 2, 'c', "-4..", "0,1/2,1/4"),
    WyckoffPosition::new(356, 2, 'b', "-4..", "0,0,1/2"),
    WyckoffPosition::new(356, 2, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(357, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(357, 4, 'k', "m..", "x,y,1/2"),
    WyckoffPosition::new(357, 4, 'j', "m..", "x,y,0"),
    WyckoffPosition::new(357, 4, 'i', "2..", "0,1/2,z"),
    WyckoffPosition::new(357, 2, 'h', "4..", "1/2,1/2,z"),
    WyckoffPosition::new(357, 2, 'g', "4..", "0,0,z"),
    WyckoffPosition::new(357, 2, 'f', "2/m..", "0,1/2,1/2"),
    WyckoffPosition::new(357, 2, 'e', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(357, 1, 'd', "4/m..", "1/2,1/2,1/2"),
    WyckoffPosition::new(357, 1, 'c', "4/m..", "1/2,1/2,0"),
    WyckoffPosition::new(357, 1, 'b', "4/m..", "0,0,1/2"),
    WyckoffPosition::new(357, 1, 'a', "4/m..", "0,0,0"),
    WyckoffPosition::new(358, 8, 'k', "1", "x,y,z"),
    WyckoffPosition::new(358, 4, 'j', "m..", "x,y,0"),
    WyckoffPosition::new(358, 4, 'i', "2..", "0,1/2,z"),
    WyckoffPosition::new(358, 4, 'h', "2..", "1/2,1/2,z"),
    WyckoffPosition::new(358, 4, 'g', "2..", "0,0,z"),
    WyckoffPosition::new(358, 2, 'f', "-4..", "1/2,1/2,1/4"),
    WyckoffPosition::new(358, 2, 'e', "-4..", "0,0,1/4"),
    WyckoffPosition::new(358, 2, 'd', "2/m..", "0,1/2,1/2"),
    WyckoffPosition::new(358, 2, 'c', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(358, 2, 'b', "2/m..", "1/2,1/2,0"),
    WyckoffPosition::new(358, 2, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(359, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(359, 4, 'f', "2..", "0,0,z"),
    WyckoffPosition::new(359, 4, 'e', "-1", "1/4,1/4,1/2"),
    WyckoffPosition::new(359, 4, 'd', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(359, 2, 'c', "4..", "0,1/2,z"),
    WyckoffPosition::new(359, 2, 'b', "-4..", "0,0,1/2"),
    WyckoffPosition::new(359, 2, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(360, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(360, 4, 'f', "2..", "1/4,3/4,z"),
    WyckoffPosition::new(360, 4, 'e', "-1", "0,0,1/2"),
    WyckoffPosition::new(360, 4, 'd', "-1", "0,0,0"),
    WyckoffPosition::new(360, 2, 'c', "4..", "1/4,1/4,z"),
    WyckoffPosition::new(360, 2, 'b', "-4..", "1/4,3/4,1/2"),
    WyckoffPosition::new(360, 2, 'a', "-4..", "1/4,3/4,0"),
    WyckoffPosition::new(361, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(361, 4, 'f', "2..", "0,0,z"),
    WyckoffPosition::new(361, 4, 'e', "2..", "0,1/2,z"),
    WyckoffPosition::new(361, 4, 'd', "-1", "1/4,1/4,3/4"),
    WyckoffPosition::new(361, 4, 'c', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(361, 2, 'b', "-4..", "0,0,1/2"),
    WyckoffPosition::new(361, 2, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(362, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(362, 4, 'f', "2..", "1/4,1/4,z"),
    WyckoffPosition::new(362, 4, 'e', "2..", "3/4,1/4,z"),
    WyckoffPosition::new(362, 4, 'd', "-1", "0,0,1/2"),
    WyckoffPosition::new(362, 4, 'c', "-1", "0,0,0"),
    WyckoffPosition::new(362, 2, 'b', "-4..", "1/4,1/4,3/4"),
    WyckoffPosition::new(362, 2, 'a', "-4..", "1/4,1/4,1/4"),
    WyckoffPosition::new(363, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(363, 8, 'h', "m..", "x,y,0"),
    WyckoffPosition::new(363, 8, 'g', "2..", "0,1/2,z"),
    WyckoffPosition::new(363, 8, 'f', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(363, 4, 'e', "4..", "0,0,z"),
    WyckoffPosition::new(363, 4, 'd', "-4..", "0,1/2,1/4"),
    WyckoffPosition::new(363, 4, 'c', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(363, 2, 'b', "4/m..", "0,0,1/2"),
    WyckoffPosition::new(363, 2, 'a', "4/m..", "0,0,0"),
    WyckoffPosition::new(364, 16, 'f', "1", "x,y,z"),
    WyckoffPosition::new(364, 8, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(364, 8, 'd', "-1", "0,1/4,5/8"),
    WyckoffPosition::new(364, 8, 'c', "-1", "0,1/4,1/8"),
    WyckoffPosition::new(364, 4, 'b', "-4..", "0,0,1/2"),
    WyckoffPosition::new(364, 4, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(365, 16, 'f', "1", "x,y,z"),
    WyckoffPosition::new(365, 8, 'e', "2..", "0,1/4,z"),
    WyckoffPosition::new(365, 8, 'd', "-1", "0,0,1/2"),
    WyckoffPosition::new(365, 8, 'c', "-1", "0,0,0"),
    WyckoffPosition::new(365, 4, 'b', "-4..", "0,1/4,5/8"),
    WyckoffPosition::new(365, 4, 'a', "-4..", "0,1/4,1/8"),
    WyckoffPosition::new(366, 8, 'p', "1", "x,y,z"),
    WyckoffPosition::new(366, 4, 'o', ".2.", "x,1/2,0"),
    WyckoffPosition::new(366, 4, 'n', ".2.", "x,0,1/2"),
    WyckoffPosition::new(366, 4, 'm', ".2.", "x,1/2,1/2"),
    WyckoffPosition::new(366, 4, 'l', ".2.", "x,0,0"),
    WyckoffPosition::new(366, 4, 'k', "..2", "x,x,1/2"),
    WyckoffPosition::new(366, 4, 'j', "..2", "x,x,0"),
    WyckoffPosition::new(366, 4, 'i', "2..", "0,1/2,z"),
    WyckoffPosition::new(366, 2, 'h', "4..", "1/2,1/2,z"),
    WyckoffPosition::new(366, 2, 'g', "4..", "0,0,z"),
    WyckoffPosition::new(366, 2, 'f', "222.", "1/2,0,1/2"),
    WyckoffPosition::new(366, 2, 'e', "222.", "1/2,0,0"),
    WyckoffPosition::new(366, 1, 'd', "422", "1/2,1/2,1/2"),
    WyckoffPosition::new(366, 1, 'c', "422", "1/2,1/2,0"),
    WyckoffPosition::new(366, 1, 'b', "422", "0,0,1/2"),
    WyckoffPosition::new(366, 1, 'a', "422", "0,0,0"),
    WyckoffPosition::new(367, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(367, 4, 'f', "..2", "x,x,1/2"),
    WyckoffPosition::new(367, 4, 'e', "..2", "x,x,0"),
    WyckoffPosition::new(367, 4, 'd', "2..", "0,0,z"),
    WyckoffPosition::new(367, 2, 'c', "4..", "0,1/2,z"),
    WyckoffPosition::new(367, 2, 'b', "2.22", "0,0,1/2"),
    WyckoffPosition::new(367, 2, 'a', "2.22", "0,0,0"),
    WyckoffPosition::new(368, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(368, 4, 'c', "..2", "x,x,3/8"),
    WyckoffPosition::new(368, 4, 'b', ".2.", "1/2,y,0"),
    WyckoffPosition::new(368, 4, 'a', ".2.", "0,y,0"),
    WyckoffPosition::new(369, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(369, 4, 'a', "..2", "x,x,0"),
    WyckoffPosition::new(370, 8, 'p', "1", "x,y,z"),
    WyckoffPosition::new(370, 4, 'o', "..2", "x,x,3/4"),
    WyckoffPosition::new(370, 4, 'n', "..2", "x,x,1/4"),
    WyckoffPosition::new(370, 4, 'm', ".2.", "x,1/2,0"),
    WyckoffPosition::new(370, 4, 'l', ".2.", "x,0,1/2"),
    WyckoffPosition::new(370, 4, 'k', ".2.", "x,1/2,1/2"),
    WyckoffPosition::new(370, 4, 'j', ".2.", "x,0,0"),
    WyckoffPosition::new(370, 4, 'i', "2..", "0,1/2,z"),
    WyckoffPosition::new(370, 4, 'h', "2..", "1/2,1/2,z"),
    WyckoffPosition::new(370, 4, 'g', "2..", "0,0,z"),
    WyckoffPosition::new(370, 2, 'f', "2.22", "1/2,1/2,1/4"),
    WyckoffPosition::new(370, 2, 'e', "2.22", "0,0,1/4"),
    WyckoffPosition::new(370, 2, 'd', "222.", "0,1/2,1/2"),
    WyckoffPosition::new(370, 2, 'c', "222.", "0,1/2,0"),
    WyckoffPosition::new(370, 2, 'b', "222.", "1/2,1/2,0"),
    WyckoffPosition::new(370, 2, 'a', "222.", "0,0,0"),
    WyckoffPosition::new(371, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(371, 4, 'f', "..2", "x,x,1/2"),
    WyckoffPosition::new(371, 4, 'e', "..2", "x,x,0"),
    WyckoffPosition::new(371, 4, 'd', "2..", "0,1/2,z"),
    WyckoffPosition::new(371, 4, 'c', "2..", "0,0,z"),
    WyckoffPosition::new(371, 2, 'b', "2.22", "0,0,1/2"),
    WyckoffPosition::new(371, 2, 'a', "2.22", "0,0,0"),
    WyckoffPosition::new(372, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(372, 4, 'c', "..2", "x,x,5/8"),
    WyckoffPosition::new(372, 4, 'b', ".2.", "1/2,y,0"),
    WyckoffPosition::new(372, 4, 'a', ".2.", "0,y,0"),
    WyckoffPosition::new(373, 8, 'b', "1", "x,y,z"),
    WyckoffPosition::new(373, 4, 'a', "..2", "x,x,0"),
    WyckoffPosition::new(374, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(374, 8, 'j', "..2", "x,x+1/2,1/4"),
    WyckoffPosition::new(374, 8, 'i', ".2.", "x,0,1/2"),
    WyckoffPosition::new(374, 8, 'h', ".2.", "x,0,0"),
    WyckoffPosition::new(374, 8, 'g', "..2", "x,x,0"),
    WyckoffPosition::new(374, 8, 'f', "2..", "0,1/2,z"),
    WyckoffPosition::new(374, 4, 'e', "4..", "0,0,z"),
    WyckoffPosition::new(374, 4, 'd', "2.22", "0,1/2,1/4"),
    WyckoffPosition::new(374, 4, 'c', "222.", "0,1/2,0"),
    WyckoffPosition::new(374, 2, 'b', "422", "0,0,1/2"),
    WyckoffPosition::new(374, 2, 'a', "422", "0,0,0"),
    WyckoffPosition::new(375, 16, 'g', "1", "x,y,z"),
    WyckoffPosition::new(375, 8, 'f', ".2.", "x,1/4,1/8"),
    WyckoffPosition::new(375, 8, 'e', "..2", "x,-x,0"),
    WyckoffPosition::new(375, 8, 'd', "..2", "x,x,0"),
    WyckoffPosition::new(375, 8, 'c', "2..", "0,0,z"),
    WyckoffPosition::new(375, 4, 'b', "2.22", "0,0,1/2"),
    WyckoffPosition::new(375, 4, 'a', "2.22", "0,0,0"),
    WyckoffPosition::new(376, 8, 'g', "1", "x,y,z"),
    WyckoffPosition::new(376, 4, 'f', ".m.", "x,1/2,z"),
    WyckoffPosition::new(376, 4, 'e', ".m.", "x,0,z"),
    WyckoffPosition::new(376, 4, 'd', "..m", "x,x,z"),
    WyckoffPosition::new(376, 2, 'c', "2mm.", "1/2,0,z"),
    WyckoffPosition::new(376, 1, 'b', "4mm", "1/2,1/2,z"),
    WyckoffPosition::new(376, 1, 'a', "4mm", "0,0,z"),
    WyckoffPosition::new(377, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(377, 4, 'c', "..m", "x,x+1/2,z"),
    WyckoffPosition::new(377, 2, 'b', "2.mm", "1/2,0,z"),
    WyckoffPosition::new(377, 2, 'a', "4..", "0,0,z"),
    WyckoffPosition::new(378, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(378, 4, 'd', "..m", "x,x,z"),
    WyckoffPosition::new(378, 4, 'c', "2..", "0,1/2,z"),
    WyckoffPosition::new(378, 2, 'b', "2.mm", "1/2,1/2,z"),
    WyckoffPosition::new(378, 2, 'a', "2.mm", "0,0,z"),
    WyckoffPosition::new(379, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(379, 4, 'c', "..m", "x,x,z"),
    WyckoffPosition::new(379, 4, 'b', "2..", "0,1/2,z"),
    WyckoffPosition::new(379, 2, 'a', "2.mm", "0,0,z"),
    WyckoffPosition::new(380, 8, 'd', "1", "x,y,z"),
    WyckoffPosition::new(380, 4, 'c', "2..", "0,1/2,z"),
    WyckoffPosition::new(380, 2, 'b', "4..", "1/2,1/2,z"),
    WyckoffPosition::new(380, 2, 'a', "4..", "0,0,z"),
    WyckoffPosition::new(381, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(381, 4, 'b', "2..", "0,1/2,z"),
    WyckoffPosition::new(381, 2, 'a', "4..", "0,0,z"),
    WyckoffPosition::new(382, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(382, 4, 'e', ".m.", "x,1/2,z"),
    WyckoffPosition::new(382, 4, 'd', ".m.", "x,0,z"),
    WyckoffPosition::new(382, 2, 'c', "2mm.", "0,1/2,z"),
    WyckoffPosition::new(382, 2, 'b', "2mm.", "1/2,1/2,z"),
    WyckoffPosition::new(382, 2, 'a', "2mm.", "0,0,z"),
    WyckoffPosition::new(383, 8, 'c', "1", "x,y,z"),
    WyckoffPosition::new(383, 4, 'b', "2..", "0,1/2,z"),
    WyckoffPosition::new(383, 4, 'a', "2..", "0,0,z"),
    WyckoffPosition::new(384, 16, 'e', "1", "x,y,z"),
    WyckoffPosition::new(384, 8, 'd', ".m.", "x,0,z"),
    WyckoffPosition::new(384, 8, 'c', "..m", "x,x,z"),
    WyckoffPosition::new(384, 4, 'b', "2mm.", "0,1/2,z"),
    WyckoffPosition::new(384, 2, 'a', "4mm", "0,0,z"),
    WyckoffPosition::new(385, 16, 'd', "1", "x,y,z"),
    WyckoffPosition::new(385, 8, 'c', "..m", "x,x+1/2,z"),
    WyckoffPosition::new(385, 4, 'b', "2.mm", "1/2,0,z"),
    WyckoffPosition::new(385, 4, 'a', "4..", "0,0,z"),
    WyckoffPosition::new(386, 16, 'c', "1", "x,y,z"),
    WyckoffPosition::new(386, 8, 'b', ".m.", "0,y,z"),
    WyckoffPosition::new(386, 4, 'a', "2mm.", "0,0,z"),
    WyckoffPosition::new(387, 16, 'b', "1", "x,y,z"),
    WyckoffPosition::new(387, 8, 'a', "2..", "0,0,z"),
    WyckoffPosition::new(388, 8, 'o', "1", "x,y,z"),
    WyckoffPosition::new(388, 4, 'n', "..m", "x,x,z"),
    WyckoffPosition::new(388, 4, 'm', "2..", "0,1/2,z"),
    WyckoffPosition::new(388, 4, 'l', ".2.", "x,1/2,0"),
    WyckoffPosition::new(388, 4, 'k', ".2.", "x,0,1/2"),
    WyckoffPosition::new(388, 4, 'j', ".2.", "x,1/2,1/2"),
    WyckoffPosition::new(388, 4, 'i', ".2.", "x,0,0"),
    WyckoffPosition::new(388, 2, 'h', "2.mm", "1/2,1/2,z"),
    WyckoffPosition::new(388, 2, 'g', "2.mm", "0,0,z"),
    WyckoffPosition::new(388, 2, 'f', "222.", "1/2,0,1/2"),
    WyckoffPosition::new(388, 2, 'e', "222.", "1/2,0,0"),
    WyckoffPosition::new(388, 1, 'd', "-42m", "1/2,1/2,0"),
    WyckoffPosition::new(388, 1, 'c', "-42m", "0,0,1/2"),
    WyckoffPosition::new(388, 1, 'b', "-42m", "1/2,1/2,1/2"),
    WyckoffPosition::new(388, 1, 'a', "-42m", "0,0,0"),
    WyckoffPosition::new(389, 8, 'n', "1", "x,y,z"),
    WyckoffPosition::new(389, 4, 'm', "2..", "0,1/2,z"),
    WyckoffPosition::new(389, 4, 'l', "2..", "1/2,1/2,z"),
    WyckoffPosition::new(389, 4, 'k', "2..", "0,0,z"),
    WyckoffPosition::new(389, 4, 'j', ".2.", "0,y,1/4"),
    WyckoffPosition::new(389, 4, 'i', ".2.", "x,1/2,1/4"),
    WyckoffPosition::new(389, 4, 'h', ".2.", "1/2,y,1/4"),
    WyckoffPosition::new(389, 4, 'g', ".2.", "x,0,1/4"),
    WyckoffPosition::new(389, 2, 'f', "-4..", "1/2,1/2,0"),
    WyckoffPosition::new(389, 2, 'e', "-4..", "0,0,0"),
    WyckoffPosition::new(389, 2, 'd', "222.", "0,1/2,1/4"),
    WyckoffPosition::new(389, 2, 'c', "222.", "1/2,1/2,1/4"),
    WyckoffPosition::new(389, 2, 'b', "222.", "1/2,0,1/4"),
    WyckoffPosition::new(389, 2, 'a', "222.", "0,0,1/4"),
    WyckoffPosition::new(390, 8, 'f', "1", "x,y,z"),
    WyckoffPosition::new(390, 4, 'e', "..m", "x,x+1/2,z"),
    WyckoffPosition::new(390, 4, 'd', "2..", "0,0,z"),
    WyckoffPosition::new(390, 2, 'c', "2.mm", "0,1/2,z"),
    WyckoffPosition::new(390, 2, 'b', "-4..", "0,0,1/2"),
    WyckoffPosition::new(390, 2, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(391, 8, 'e', "1", "x,y,z"),
    WyckoffPosition::new(391, 4, 'd', "2..", "0,1/2,z"),
    WyckoffPosition::new(391, 4, 'c', "2..", "0,0,z"),
    WyckoffPosition::new(391, 2, 'b', "-4..", "0,0,1/2"),
    WyckoffPosition::new(391, 2, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(392, 8, 'l', "1", "x,y,z"),
    WyckoffPosition::new(392, 4, 'k', ".m.", "x,1/2,z"),
    WyckoffPosition::new(392, 4, 'j', ".m.", "x,0,z"),
    WyckoffPosition::new(392, 4, 'i', "..2", "x,x,1/2"),
    WyckoffPosition::new(392, 4, 'h', "..2", "x,x,0"),
    WyckoffPosition::new(392, 2, 'g', "2mm.", "0,1/2,z"),
    WyckoffPosition::new(392, 2, 'f', "2mm.", "1/2,1/2,z"),
    WyckoffPosition::new(392, 2, 'e', "2mm.", "0,0,z"),
    WyckoffPosition::new(392, 1, 'd', "-4m2", "0,0,1/2"),
    WyckoffPosition::new(392, 1, 'c', "-4m2", "1/2,1/2,1/2"),
    WyckoffPosition::new(392, 1, 'b', "-4m2", "1/2,1/2,0"),
    WyckoffPosition::new(392, 1, 'a', "-4m2", "0,0,0"),
    WyckoffPosition::new(393, 8, 'j', "1", "x,y,z"),
    WyckoffPosition::new(393, 4, 'i', "2..", "0,1/2,z"),
    WyckoffPosition::new(393, 4, 'h', "2..", "1/2,1/2,z"),
    WyckoffPosition::new(393, 4, 'g', "2..", "0,0,z"),
    WyckoffPosition::new(393, 4, 'f', "..2", "x,x,3/4"),
    WyckoffPosition::new(393, 4, 'e', "..2", "x,x,1/4"),
    WyckoffPosition::new(393, 2, 'd', "-4..", "1/2,1/2,0"),
    WyckoffPosition::new(393, 2, 'c', "-4..", "0,0,0"),
    WyckoffPosition::new(393, 2, 'b', "2.22", "1/2,1/2,1/4"),
    WyckoffPosition::new(393, 2, 'a', "2.22", "0,0,1/4"),
    WyckoffPosition::new(394, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(394, 4, 'h', "..2", "x,x+1/2,1/2"),
    WyckoffPosition::new(394, 4, 'g', "..2", "x,x+1/2,0"),
    WyckoffPosition::new(394, 4, 'f', "2..", "0,1/2,z"),
    WyckoffPosition::new(394, 4, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(394, 2, 'd', "2.22", "0,1/2,1/2"),
    WyckoffPosition::new(394, 2, 'c', "2.22", "0,1/2,0"),
    WyckoffPosition::new(394, 2, 'b', "-4..", "0,0,1/2"),
    WyckoffPosition::new(394, 2, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(395, 8, 'i', "1", "x,y,z"),
    WyckoffPosition::new(395, 4, 'h', "2..", "0,1/2,z"),
    WyckoffPosition::new(395, 4, 'g', "..2", "x,x+1/2,1/4"),
    WyckoffPosition::new(395, 4, 'f', "..2", "x,-x+1/2,1/4"),
    WyckoffPosition::new(395, 4, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(395, 2, 'd', "2.22", "0,1/2,3/4"),
    WyckoffPosition::new(395, 2, 'c', "2.22", "0,1/2,1/4"),
    WyckoffPosition::new(395, 2, 'b', "-4..", "0,0,1/2"),
    WyckoffPosition::new(395, 2, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(396, 16, 'j', "1", "x,y,z"),
    WyckoffPosition::new(396, 8, 'i', ".m.", "x,0,z"),
    WyckoffPosition::new(396, 8, 'h', "..2", "x,x+1/2,1/4"),
    WyckoffPosition::new(396, 8, 'g', "..2", "x,x,0"),
    WyckoffPosition::new(396, 4, 'f', "2mm.", "0,1/2,z"),
    WyckoffPosition::new(396, 4, 'e', "2mm.", "0,0,z"),
    WyckoffPosition::new(396, 2, 'd', "-4m2", "0,1/2,3/4"),
    WyckoffPosition::new(396, 2, 'c', "-4m2", "0,1/2,1/4"),
    WyckoffPosition::new(396, 2, 'b', "-4m2", "0,0,1/2"),
    WyckoffPosition::new(396, 2, 'a', "-4m2", "0,0,0"),
    WyckoffPosition::new(397, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(397, 8, 'h', "..2", "x,x+1/2,0"),
    WyckoffPosition::new(397, 8, 'g', "2..", "0,1/2,z"),
    WyckoffPosition::new(397, 8, 'f', "2..", "0,0,z"),
    WyckoffPosition::new(397, 8, 'e', "..2", "x,x,1/4"),
    WyckoffPosition::new(397, 4, 'd', "2.22", "0,1/2,0"),
    WyckoffPosition::new(397, 4, 'c', "-4..", "0,1/2,1/4"),
    WyckoffPosition::new(397, 4, 'b', "-4..", "0,0,0"),
    WyckoffPosition::new(397, 4, 'a', "2.22", "0,0,1/4"),
    WyckoffPosition::new(398, 16, 'j', "1", "x,y,z"),
    WyckoffPosition::new(398, 8, 'i', "..m", "x,x,z"),
    WyckoffPosition::new(398, 8, 'h', "2..", "0,1/2,z"),
    WyckoffPosition::new(398, 8, 'g', ".2.", "x,0,1/2"),
    WyckoffPosition::new(398, 8, 'f', ".2.", "x,0,0"),
    WyckoffPosition::new(398, 4, 'e', "2.mm", "0,0,z"),
    WyckoffPosition::new(398, 4, 'd', "-4..", "0,1/2,1/4"),
    WyckoffPosition::new(398, 4, 'c', "222.", "0,1/2,0"),
    WyckoffPosition::new(398, 2, 'b', "-42m", "0,0,1/2"),
    WyckoffPosition::new(398, 2, 'a', "-42m", "0,0,0"),
    WyckoffPosition::new(399, 16, 'e', "1", "x,y,z"),
    WyckoffPosition::new(399, 8, 'd', ".2.", "x,1/4,1/8"),
    WyckoffPosition::new(399, 8, 'c', "2..", "0,0,z"),
    WyckoffPosition::new(399, 4, 'b', "-4..", "0,0,1/2"),
    WyckoffPosition::new(399, 4, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(400, 16, 'u', "1", "x,y,z"),
    WyckoffPosition::new(400, 8, 't', ".m.", "x,1/2,z"),
    WyckoffPosition::new(400, 8, 's', ".m.", "x,0,z"),
    WyckoffPosition::new(400, 8, 'r', "..m", "x,x,z"),
    WyckoffPosition::new(400, 8, 'q', "m..", "x,y,1/2"),
    WyckoffPosition::new(400, 8, 'p', "m..", "x,y,0"),
    WyckoffPosition::new(400, 4, 'o', "m2m.", "x,1/2,1/2"),
    WyckoffPosition::new(400, 4, 'n', "m2m.", "x,1/2,0"),
    WyckoffPosition::new(400, 4, 'm', "m2m.", "x,0,1/2"),
    WyckoffPosition::new(400, 4, 'l', "m2m.", "x,0,0"),
    WyckoffPosition::new(400, 4, 'k', "m.2m", "x,x,1/2"),
    WyckoffPosition::new(400, 4, 'j', "m.2m", "x,x,0"),
    WyckoffPosition::new(400, 4, 'i', "2mm.", "0,1/2,z"),
    WyckoffPosition::new(400, 2, 'h', "4mm", "1/2,1/2,z"),
    WyckoffPosition::new(400, 2, 'g', "4mm", "0,0,z"),
    WyckoffPosition::new(400, 2, 'f', "mmm.", "0,1/2,0"),
    WyckoffPosition::new(400, 2, 'e', "mmm.", "0,1/2,1/2"),
    WyckoffPosition::new(400, 1, 'd', "4/mmm", "1/2,1/2,1/2"),
    WyckoffPosition::new(400, 1, 'c', "4/mmm", "1/2,1/2,0"),
    WyckoffPosition::new(400, 1, 'b', "4/mmm", "0,0,1/2"),
    WyckoffPosition::new(400, 1, 'a', "4/mmm", "0,0,0"),
    WyckoffPosition::new(401, 16, 'n', "1", "x,y,z"),
    WyckoffPosition::new(401, 8, 'm', "m..", "x,y,0"),
    WyckoffPosition::new(401, 8, 'l', ".2.", "x,1/2,1/4"),
    WyckoffPosition::new(401, 8, 'k', ".2.", "x,0,1/4"),
    WyckoffPosition::new(401, 8, 'j', "..2", "x,x,1/4"),
    WyckoffPosition::new(401, 8, 'i', "2..", "0,1/2,z"),
    WyckoffPosition::new(401, 4, 'h', "4..", "1/2,1/2,z"),
    WyckoffPosition::new(401, 4, 'g', "4..", "0,0,z"),
    WyckoffPosition::new(401, 4, 'f', "222.", "0,1/2,1/4"),
    WyckoffPosition::new(401, 4, 'e', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(401, 2, 'd', "4/m..", "1/2,1/2,0"),
    WyckoffPosition::new(401, 2, 'c', "422", "1/2,1/2,1/4"),
    WyckoffPosition::new(401, 2, 'b', "4/m..", "0,0,0"),
    WyckoffPosition::new(401, 2, 'a', "422", "0,0,1/4"),
    WyckoffPosition::new(402, 16, 'n', "1", "x,y,z"),
    WyckoffPosition::new(402, 8, 'm', "..m", "x,x+1/2,z"),
    WyckoffPosition::new(402, 8, 'l', ".2.", "x,0,1/2"),
    WyckoffPosition::new(402, 8, 'k', ".2.", "x,0,0"),
    WyckoffPosition::new(402, 8, 'j', "..2", "x,x,1/2"),
    WyckoffPosition::new(402, 8, 'i', "..2", "x,x,0"),
    WyckoffPosition::new(402, 4, 'h', "2.mm", "0,1/2,z"),
    WyckoffPosition::new(402, 4, 'g', "4..", "0,0,z"),
    WyckoffPosition::new(402, 4, 'f', "..2/m", "1/4,1/4,1/2"),
    WyckoffPosition::new(402, 4, 'e', "..2/m", "1/4,1/4,0"),
    WyckoffPosition::new(402, 2, 'd', "-42m", "0,1/2,1/2"),
    WyckoffPosition::new(402, 2, 'c', "-42m", "0,1/2,0"),
    WyckoffPosition::new(402, 2, 'b', "422", "0,0,1/2"),
    WyckoffPosition::new(402, 2, 'a', "422", "0,0,0"),
    WyckoffPosition::new(403, 16, 'n', "1", "x,y,z"),
    WyckoffPosition::new(403, 8, 'm', "..m", "x,-x,z"),
    WyckoffPosition::new(403, 8, 'l', ".2.", "x,1/4,1/2"),
    WyckoffPosition::new(403, 8, 'k', ".2.", "x,1/4,0"),
    WyckoffPosition::new(403, 8, 'j', "..2", "x,x,1/2"),
    WyckoffPosition::new(403, 8, 'i', "..2", "x,x,0"),
    WyckoffPosition::new(403, 4, 'h', "2.mm", "3/4,1/4,z"),
    WyckoffPosition::new(403, 4, 'g', "4..", "1/4,1/4,z"),
    WyckoffPosition::new(403, 4, 'f', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(403, 4, 'e', "..2/m", "0,0,0"),
    WyckoffPosition::new(403, 2, 'd', "-42m", "3/4,1/4,1/2"),
    WyckoffPosition::new(403, 2, 'c', "-42m", "3/4,1/4,0"),
    WyckoffPosition::new(403, 2, 'b', "422", "1/4,1/4,1/2"),
    WyckoffPosition::new(403, 2, 'a', "422", "1/4,1/4,0"),
    WyckoffPosition::new(404, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(404, 8, 'j', ".2.", "x,0,1/2"),
    WyckoffPosition::new(404, 8, 'i', ".2.", "x,0,0"),
    WyckoffPosition::new(404, 8, 'h', "..2", "x,x,0"),
    WyckoffPosition::new(404, 8, 'g', "2..", "1/2,0,z"),
    WyckoffPosition::new(404, 8, 'f', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(404, 4, 'e', "4..", "0,0,z"),
    WyckoffPosition::new(404, 4, 'd', "-4..", "1/2,0,1/4"),
    WyckoffPosition::new(404, 4, 'c', "222.", "1/2,0,0"),
    WyckoffPosition::new(404, 2, 'b', "422", "0,0,1/2"),
    WyckoffPosition::new(404, 2, 'a', "422", "0,0,0"),
    WyckoffPosition::new(405, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(405, 8, 'j', ".2.", "x,3/4,1/4"),
    WyckoffPosition::new(405, 8, 'i', ".2.", "x,1/4,1/4"),
    WyckoffPosition::new(405, 8, 'h', "..2", "x,x,1/4"),
    WyckoffPosition::new(405, 8, 'g', "2..", "1/4,3/4,z"),
    WyckoffPosition::new(405, 8, 'f', "-1", "0,0,0"),
    WyckoffPosition::new(405, 4, 'e', "4..", "1/4,1/4,z"),
    WyckoffPosition::new(405, 4, 'd', "-4..", "1/4,3/4,0"),
    WyckoffPosition::new(405, 4, 'c', "222.", "1/4,3/4,3/4"),
    WyckoffPosition::new(405, 2, 'b', "422", "1/4,1/4,3/4"),
    WyckoffPosition::new(405, 2, 'a', "422", "1/4,1/4,1/4"),
    WyckoffPosition::new(406, 16, 'l', "1", "x,y,z"),
    WyckoffPosition::new(406, 8, 'k', "..m", "x,x+1/2,z"),
    WyckoffPosition::new(406, 8, 'j', "m..", "x,y,1/2"),
    WyckoffPosition::new(406, 8, 'i', "m..", "x,y,0"),
    WyckoffPosition::new(406, 4, 'h', "m.2m", "x,x+1/2,1/2"),
    WyckoffPosition::new(406, 4, 'g', "m.2m", "x,x+1/2,0"),
    WyckoffPosition::new(406, 4, 'f', "2.mm", "0,1/2,z"),
    WyckoffPosition::new(406, 4, 'e', "4..", "0,0,z"),
    WyckoffPosition::new(406, 2, 'd', "m.mm", "0,1/2,0"),
    WyckoffPosition::new(406, 2, 'c', "m.mm", "0,1/2,1/2"),
    WyckoffPosition::new(406, 2, 'b', "4/m..", "0,0,1/2"),
    WyckoffPosition::new(406, 2, 'a', "4/m..", "0,0,0"),
    WyckoffPosition::new(407, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(407, 8, 'h', "m..", "x,y,0"),
    WyckoffPosition::new(407, 8, 'g', "..2", "x,x+1/2,1/4"),
    WyckoffPosition::new(407, 8, 'f', "2..", "0,1/2,z"),
    WyckoffPosition::new(407, 4, 'e', "4..", "0,0,z"),
    WyckoffPosition::new(407, 4, 'd', "2.22", "0,1/2,1/4"),
    WyckoffPosition::new(407, 4, 'c', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(407, 2, 'b', "4/m..", "0,0,1/2"),
    WyckoffPosition::new(407, 2, 'a', "4/m..", "0,0,0"),
    WyckoffPosition::new(408, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(408, 8, 'j', "..m", "x,x+1/2,z"),
    WyckoffPosition::new(408, 8, 'i', ".m.", "0,y,z"),
    WyckoffPosition::new(408, 8, 'h', "..2", "x,x,1/2"),
    WyckoffPosition::new(408, 8, 'g', "..2", "x,x,0"),
    WyckoffPosition::new(408, 4, 'f', "2mm.", "0,0,z"),
    WyckoffPosition::new(408, 4, 'e', "..2/m", "1/4,1/4,1/2"),
    WyckoffPosition::new(408, 4, 'd', "..2/m", "1/4,1/4,0"),
    WyckoffPosition::new(408, 2, 'c', "4mm", "0,1/2,z"),
    WyckoffPosition::new(408, 2, 'b', "-4m2", "0,0,1/2"),
    WyckoffPosition::new(408, 2, 'a', "-4m2", "0,0,0"),
    WyckoffPosition::new(409, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(409, 8, 'j', "..m", "x,x,z"),
    WyckoffPosition::new(409, 8, 'i', ".m.", "1/4,y,z"),
    WyckoffPosition::new(409, 8, 'h', "..2", "x,-x,1/2"),
    WyckoffPosition::new(409, 8, 'g', "..2", "x,-x,0"),
    WyckoffPosition::new(409, 4, 'f', "2mm.", "3/4,1/4,z"),
    WyckoffPosition::new(409, 4, 'e', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(409, 4, 'd', "..2/m", "0,0,0"),
    WyckoffPosition::new(409, 2, 'c', "4mm", "1/4,1/4,z"),
    WyckoffPosition::new(409, 2, 'b', "-4m2", "3/4,1/4,1/2"),
    WyckoffPosition::new(409, 2, 'a', "-4m2", "3/4,1/4,0"),
    WyckoffPosition::new(410, 16, 'g', "1", "x,y,z"),
    WyckoffPosition::new(410, 8, 'f', "..2", "x,x,1/4"),
    WyckoffPosition::new(410, 8, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(410, 8, 'd', "-1", "1/4,1/4,0"),
    WyckoffPosition::new(410, 4, 'c', "4..", "0,1/2,z"),
    WyckoffPosition::new(410, 4, 'b', "-4..", "0,0,0"),
    WyckoffPosition::new(410, 4, 'a', "2.22", "0,0,1/4"),
    WyckoffPosition::new(411, 16, 'g', "1", "x,y,z"),
    WyckoffPosition::new(411, 8, 'f', "..2", "x,-x,1/4"),
    WyckoffPosition::new(411, 8, 'e', "2..", "3/4,1/4,z"),
    WyckoffPosition::new(411, 8, 'd', "-1", "0,0,0"),
    WyckoffPosition::new(411, 4, 'c', "4..", "1/4,1/4,z"),
    WyckoffPosition::new(411, 4, 'b', "-4..", "3/4,1/4,0"),
    WyckoffPosition::new(411, 4, 'a', "2.22", "3/4,1/4,1/4"),
    WyckoffPosition::new(412, 16, 'r', "1", "x,y,z"),
    WyckoffPosition::new(412, 8, 'q', "m..", "x,y,0"),
    WyckoffPosition::new(412, 8, 'p', ".m.", "1/2,y,z"),
    WyckoffPosition::new(412, 8, 'o', ".m.", "0,y,z"),
    WyckoffPosition::new(412, 8, 'n', "..2", "x,x,1/4"),
    WyckoffPosition::new(412, 4, 'm', "m2m.", "x,1/2,0"),
    WyckoffPosition::new(412, 4, 'l', "m2m.", "x,0,1/2"),
    WyckoffPosition::new(412, 4, 'k', "m2m.", "x,1/2,1/2"),
    WyckoffPosition::new(412, 4, 'j', "m2m.", "x,0,0"),
    WyckoffPosition::new(412, 4, 'i', "2mm.", "0,1/2,z"),
    WyckoffPosition::new(412, 4, 'h', "2mm.", "1/2,1/2,z"),
    WyckoffPosition::new(412, 4, 'g', "2mm.", "0,0,z"),
    WyckoffPosition::new(412, 2, 'f', "-4m2", "1/2,1/2,1/4"),
    WyckoffPosition::new(412, 2, 'e', "-4m2", "0,0,1/4"),
    WyckoffPosition::new(412, 2, 'd', "mmm.", "0,1/2,1/2"),
    WyckoffPosition::new(412, 2, 'c', "mmm.", "0,1/2,0"),
    WyckoffPosition::new(412, 2, 'b', "mmm.", "1/2,1/2,0"),
    WyckoffPosition::new(412, 2, 'a', "mmm.", "0,0,0"),
    WyckoffPosition::new(413, 16, 'p', "1", "x,y,z"),
    WyckoffPosition::new(413, 8, 'o', "..m", "x,x,z"),
    WyckoffPosition::new(413, 8, 'n', "m..", "x,y,0"),
    WyckoffPosition::new(413, 8, 'm', ".2.", "x,1/2,1/4"),
    WyckoffPosition::new(413, 8, 'l', ".2.", "x,0,1/4"),
    WyckoffPosition::new(413, 8, 'k', "2..", "0,1/2,z"),
    WyckoffPosition::new(413, 4, 'j', "m.2m", "x,x,1/2"),
    WyckoffPosition::new(413, 4, 'i', "m.2m", "x,x,0"),
    WyckoffPosition::new(413, 4, 'h', "2.mm", "1/2,1/2,z"),
    WyckoffPosition::new(413, 4, 'g', "2.mm", "0,0,z"),
    WyckoffPosition::new(413, 4, 'f', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(413, 4, 'e', "222.", "0,1/2,1/4"),
    WyckoffPosition::new(413, 2, 'd', "-42m", "1/2,1/2,1/4"),
    WyckoffPosition::new(413, 2, 'c', "m.mm", "1/2,1/2,0"),
    WyckoffPosition::new(413, 2, 'b', "-42m", "0,0,1/4"),
    WyckoffPosition::new(413, 2, 'a', "m.mm", "0,0,0"),
    WyckoffPosition::new(414, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(414, 8, 'j', "..2", "x,x+1/2,0"),
    WyckoffPosition::new(414, 8, 'i', ".2.", "x,0,3/4"),
    WyckoffPosition::new(414, 8, 'h', ".2.", "x,0,1/4"),
    WyckoffPosition::new(414, 8, 'g', "2..", "0,0,z"),
    WyckoffPosition::new(414, 8, 'f', "2..", "0,1/2,z"),
    WyckoffPosition::new(414, 8, 'e', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(414, 4, 'd', "-4..", "0,0,0"),
    WyckoffPosition::new(414, 4, 'c', "2.22", "0,1/2,0"),
    WyckoffPosition::new(414, 4, 'b', "222.", "0,0,1/4"),
    WyckoffPosition::new(414, 4, 'a', "222.", "0,1/2,1/4"),
    WyckoffPosition::new(415, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(415, 8, 'j', "..2", "x,x,1/4"),
    WyckoffPosition::new(415, 8, 'i', ".2.", "x,1/4,1/2"),
    WyckoffPosition::new(415, 8, 'h', ".2.", "x,1/4,0"),
    WyckoffPosition::new(415, 8, 'g', "2..", "3/4,1/4,z"),
    WyckoffPosition::new(415, 8, 'f', "2..", "1/4,1/4,z"),
    WyckoffPosition::new(415, 8, 'e', "-1", "0,0,0"),
    WyckoffPosition::new(415, 4, 'd', "-4..", "3/4,1/4,3/4"),
    WyckoffPosition::new(415, 4, 'c', "2.22", "1/4,1/4,1/4"),
    WyckoffPosition::new(415, 4, 'b', "222.", "3/4,1/4,0"),
    WyckoffPosition::new(415, 4, 'a', "222.", "1/4,1/4,0"),
    WyckoffPosition::new(416, 16, 'n', "1", "x,y,z"),
    WyckoffPosition::new(416, 8, 'm', "..m", "x,x,z"),
    WyckoffPosition::new(416, 8, 'l', "..2", "x,x+1/2,3/4"),
    WyckoffPosition::new(416, 8, 'k', "..2", "x,x+1/2,1/4"),
    WyckoffPosition::new(416, 8, 'j', ".2.", "x,0,1/2"),
    WyckoffPosition::new(416, 8, 'i', ".2.", "x,0,0"),
    WyckoffPosition::new(416, 8, 'h', "2..", "0,1/2,z"),
    WyckoffPosition::new(416, 4, 'g', "2.mm", "0,0,z"),
    WyckoffPosition::new(416, 4, 'f', "..2/m", "3/4,3/4,3/4"),
    WyckoffPosition::new(416, 4, 'e', "..2/m", "1/4,1/4,1/4"),
    WyckoffPosition::new(416, 4, 'd', "2.22", "0,1/2,1/4"),
    WyckoffPosition::new(416, 4, 'c', "222.", "0,1/2,0"),
    WyckoffPosition::new(416, 2, 'b', "-42m", "0,0,1/2"),
    WyckoffPosition::new(416, 2, 'a', "-42m", "0,0,0"),
    WyckoffPosition::new(417, 16, 'n', "1", "x,y,z"),
    WyckoffPosition::new(417, 8, 'm', "..m", "x,-x,z"),
    WyckoffPosition::new(417, 8, 'l', "..2", "x,x,1/2"),
    WyckoffPosition::new(417, 8, 'k', "..2", "x,x,0"),
    WyckoffPosition::new(417, 8, 'j', ".2.", "x,1/4,1/4"),
    WyckoffPosition::new(417, 8, 'i', ".2.", "x,1/4,3/4"),
    WyckoffPosition::new(417, 8, 'h', "2..", "1/4,1/4,z"),
    WyckoffPosition::new(417, 4, 'g', "2.mm", "3/4,1/4,z"),
    WyckoffPosition::new(417, 4, 'f', "..2/m", "0,0,0"),
    WyckoffPosition::new(417, 4, 'e', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(417, 4, 'd', "2.22", "1/4,1/4,0"),
    WyckoffPosition::new(417, 4, 'c', "222.", "1/4,1/4,1/4"),
    WyckoffPosition::new(417, 2, 'b', "-42m", "3/4,1/4,1/4"),
    WyckoffPosition::new(417, 2, 'a', "-42m", "1/4,3/4,1/4"),
    WyckoffPosition::new(418, 16, 'i', "1", "x,y,z"),
    WyckoffPosition::new(418, 8, 'h', "m..", "x,y,0"),
    WyckoffPosition::new(418, 8, 'g', "..2", "x,x+1/2,1/4"),
    WyckoffPosition::new(418, 8, 'f', "2..", "0,1/2,z"),
    WyckoffPosition::new(418, 8, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(418, 4, 'd', "2.22", "0,1/2,1/4"),
    WyckoffPosition::new(418, 4, 'c', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(418, 4, 'b', "-4..", "0,0,1/4"),
    WyckoffPosition::new(418, 4, 'a', "2/m..", "0,0,0"),
    WyckoffPosition::new(419, 16, 'k', "1", "x,y,z"),
    WyckoffPosition::new(419, 8, 'j', "..m", "x,x,z"),
    WyckoffPosition::new(419, 8, 'i', "m..", "x,y,0"),
    WyckoffPosition::new(419, 8, 'h', "2..", "0,1/2,z"),
    WyckoffPosition::new(419, 4, 'g', "m.2m", "x,-x,0"),
    WyckoffPosition::new(419, 4, 'f', "m.2m", "x,x,0"),
    WyckoffPosition::new(419, 4, 'e', "2.mm", "0,0,z"),
    WyckoffPosition::new(419, 4, 'd', "-4..", "0,1/2,1/4"),
    WyckoffPosition::new(419, 4, 'c', "2/m..", "0,1/2,0"),
    WyckoffPosition::new(419, 2, 'b', "m.mm", "0,0,1/2"),
    WyckoffPosition::new(419, 2, 'a', "m.mm", "0,0,0"),
    WyckoffPosition::new(420, 16, 'h', "1", "x,y,z"),
    WyckoffPosition::new(420, 8, 'g', ".m.", "0,y,z"),
    WyckoffPosition::new(420, 8, 'f', "..2", "x,x,0"),
    WyckoffPosition::new(420, 8, 'e', "-1", "1/4,1/4,1/4"),
    WyckoffPosition::new(420, 4, 'd', "2mm.", "0,1/2,z"),
    WyckoffPosition::new(420, 4, 'c', "2mm.", "0,0,z"),
    WyckoffPosition::new(420, 2, 'b', "-4m2", "0,0,1/2"),
    WyckoffPosition::new(420, 2, 'a', "-4m2", "0,0,0"),
    WyckoffPosition::new(421, 16, 'h', "1", "x,y,z"),
    WyckoffPosition::new(421, 8, 'g', ".m.", "1/4,y,z"),
    WyckoffPosition::new(421, 8, 'f', "..2", "x,-x,1/4"),
    WyckoffPosition::new(421, 8, 'e', "-1", "0,0,0"),
    WyckoffPosition::new(421, 4, 'd', "2mm.", "1/4,1/4,z"),
    WyckoffPosition::new(421, 4, 'c', "2mm.", "3/4,1/4,z"),
    WyckoffPosition::new(421, 2, 'b', "-4m2", "3/4,1/4,1/4"),
    WyckoffPosition::new(421, 2, 'a', "-4m2", "3/4,1/4,3/4"),
    WyckoffPosition::new(422, 16, 'j', "1", "x,y,z"),
    WyckoffPosition::new(422, 8, 'i', "..m", "x,x+1/2,z"),
    WyckoffPosition::new(422, 8, 'h', "..2", "x,x,3/4"),
    WyckoffPosition::new(422, 8, 'g', "..2", "x,x,1/4"),
    WyckoffPosition::new(422, 8, 'f', "2..", "0,0,z"),
    WyckoffPosition::new(422, 4, 'e', "2.mm", "0,1/2,z"),
    WyckoffPosition::new(422, 4, 'd', "..2/m", "1/4,1/4,3/4"),
    WyckoffPosition::new(422, 4, 'c', "..2/m", "1/4,1/4,1/4"),
    WyckoffPosition::new(422, 4, 'b', "-4..", "0,0,0"),
    WyckoffPosition::new(422, 4, 'a', "2.22", "0,0,1/4"),
    WyckoffPosition::new(423, 16, 'j', "1", "x,y,z"),
    WyckoffPosition::new(423, 8, 'i', "..m", "x,x,z"),
    WyckoffPosition::new(423, 8, 'h', "..2", "x,-x,0"),
    WyckoffPosition::new(423, 8, 'g', "..2", "x,-x,1/2"),
    WyckoffPosition::new(423, 8, 'f', "2..", "3/4,1/4,z"),
    WyckoffPosition::new(423, 4, 'e', "2.mm", "1/4,1/4,z"),
    WyckoffPosition::new(423, 4, 'd', "..2/m", "0,0,0"),
    WyckoffPosition::new(423, 4, 'c', "..2/m", "0,0,1/2"),
    WyckoffPosition::new(423, 4, 'b', "-4..", "3/4,1/4,3/4"),
    WyckoffPosition::new(423, 4, 'a', "2.22", "3/4,1/4,0"),
    WyckoffPosition::new(424, 32, 'o', "1", "x,y,z"),
    WyckoffPosition::new(424, 16, 'n', ".m.", "0,y,z"),
    WyckoffPosition::new(424, 16, 'm', "..m", "x,x,z"),
    WyckoffPosition::new(424, 16, 'l', "m..", "x,y,0"),
    WyckoffPosition::new(424, 16, 'k', "..2", "x,x+1/2,1/4"),
    WyckoffPosition::new(424, 8, 'j', "m2m.", "x,1/2,0"),
    WyckoffPosition::new(424, 8, 'i', "m2m.", "x,0,0"),
    WyckoffPosition::new(424, 8, 'h', "m.2m", "x,x,0"),
    WyckoffPosition::new(424, 8, 'g', "2mm.", "0,1/2,z"),
    WyckoffPosition::new(424, 8, 'f', "..2/m", "1/4,1/4,1/4"),
    WyckoffPosition::new(424, 4, 'e', "4mm", "0,0,z"),
    WyckoffPosition::new(424, 4, 'd', "-4m2", "0,1/2,1/4"),
    WyckoffPosition::new(424, 4, 'c', "mmm.", "0,1/2,0"),
    WyckoffPosition::new(424, 2, 'b', "4/mmm", "0,0,1/2"),
    WyckoffPosition::new(424, 2, 'a', "4/mmm", "0,0,0"),
    WyckoffPosition::new(425, 32, 'm', "1", "x,y,z"),
    WyckoffPosition::new(425, 16, 'l', "..m", "x,x+1/2,z"),
    WyckoffPosition::new(425, 16, 'k', "m..", "x,y,0"),
    WyckoffPosition::new(425, 16, 'j', ".2.", "x,0,1/4"),
    WyckoffPosition::new(425, 16, 'i', "..2", "x,x,1/4"),
    WyckoffPosition::new(425, 8, 'h', "m.2m", "x,x+1/2,0"),
    WyckoffPosition::new(425, 8, 'g', "2.mm", "0,1/2,z"),
    WyckoffPosition::new(425, 8, 'f', "4..", "0,0,z"),
    WyckoffPosition::new(425, 8, 'e', "..2/m", "1/4,1/4,1/4"),
    WyckoffPosition::new(425, 4, 'd', "m.mm", "0,1/2,0"),
    WyckoffPosition::new(425, 4, 'c', "4/m..", "0,0,0"),
    WyckoffPosition::new(425, 4, 'b', "-42m", "0,1/2,1/4"),
    WyckoffPosition::new(425, 4, 'a', "422", "0,0,1/4"),
    WyckoffPosition::new(426, 32, 'i', "1", "x,y,z"),
    WyckoffPosition::new(426, 16, 'h', ".m.", "0,y,z"),
    WyckoffPosition::new(426, 16, 'g', "..2", "x,x,0"),
    WyckoffPosition::new(426, 16, 'f', ".2.", "x,1/4,1/8"),
    WyckoffPosition::new(426, 8, 'e', "2mm.", "0,0,z"),
    WyckoffPosition::new(426, 8, 'd', ".2/m.", "0,1/4,5/8"),
    WyckoffPosition::new(426, 8, 'c', ".2/m.", "0,1/4,1/8"),
    WyckoffPosition::new(426, 4, 'b', "-4m2", "0,0,1/2"),
    WyckoffPosition::new(426, 4, 'a', "-4m2", "0,0,0"),
    WyckoffPosition::new(427, 32, 'i', "1", "x,y,z"),
    WyckoffPosition::new(427, 16, 'h', ".m.", "0,y,z"),
    WyckoffPosition::new(427, 16, 'g', "..2", "x,x+1/4,7/8"),
    WyckoffPosition::new(427, 16, 'f', ".2.", "x,0,0"),
    WyckoffPosition::new(427, 8, 'e', "2mm.", "0,1/4,z"),
    WyckoffPosition::new(427, 8, 'd', ".2/m.", "0,0,1/2"),
    WyckoffPosition::new(427, 8, 'c', ".2/m.", "0,0,0"),
    WyckoffPosition::new(427, 4, 'b', "-4m2", "0,1/4,3/8"),
    WyckoffPosition::new(427, 4, 'a', "-4m2", "0,3/4,1/8"),
    WyckoffPosition::new(428, 32, 'g', "1", "x,y,z"),
    WyckoffPosition::new(428, 16, 'f', "..2", "x,x,1/4"),
    WyckoffPosition::new(428, 16, 'e', ".2.", "1/4,y,1/8"),
    WyckoffPosition::new(428, 16, 'd', "2..", "0,0,z"),
    WyckoffPosition::new(428, 16, 'c', "-1", "0,1/4,1/8"),
    WyckoffPosition::new(428, 8, 'b', "2.22", "0,0,1/4"),
    WyckoffPosition::new(428, 8, 'a', "-4..", "0,0,0"),
    WyckoffPosition::new(429, 32, 'g', "1", "x,y,z"),
    WyckoffPosition::new(429, 16, 'f', "..2", "x,x+1/4,1/8"),
    WyckoffPosition::new(429, 16, 'e', ".2.", "x,0,1/4"),
    WyckoffPosition::new(429, 16, 'd', "2..", "0,1/4,z"),
    WyckoffPosition::new(429, 16, 'c', "-1", "0,0,0"),
    WyckoffPosition::new(429, 8, 'b', "2.22", "0,1/4,1/8"),
    WyckoffPosition::new(429, 8, 'a', "-4..", "0,1/4,3/8"),
    WyckoffPosition::new(430, 3, 'd', "1", "x,y,z"),
    WyckoffPosition::new(430, 1, 'c', "3..", "2/3,1/3,z"),
    WyckoffPosition::new(430, 1, 'b', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(430, 1, 'a', "3..", "0,0,z"),
    WyckoffPosition::new(431, 3, 'a', "1", "x,y,z"),
    WyckoffPosition::new(432, 3, 'a', "1", "x,y,z"),
    WyckoffPosition::new(433, 9, 'b', "1", "x,y,z"),
    WyckoffPosition::new(433, 3, 'a', "3.", "0,0,z"),
    WyckoffPosition::new(434, 3, 'b', "1", "x,y,z"),
    WyckoffPosition::new(434, 1, 'a', "3.", "x,x,x"),
    WyckoffPosition::new(435, 6, 'g', "1", "x,y,z"),
    WyckoffPosition::new(435, 3, 'f', "-1", "1/2,0,1/2"),
    WyckoffPosition::new(435, 3, 'e', "-1", "1/2,0,0"),
    WyckoffPosition::new(435, 2, 'd', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(435, 2, 'c', "3..", "0,0,z"),
    WyckoffPosition::new(435, 1, 'b', "-3..", "0,0,1/2"),
    WyckoffPosition::new(435, 1, 'a', "-3..", "0,0,0"),
    WyckoffPosition::new(436, 18, 'f', "1", "x,y,z"),
    WyckoffPosition::new(436, 9, 'e', "-1", "1/2,0,0"),
    WyckoffPosition::new(436, 9, 'd', "-1", "1/2,0,1/2"),
    WyckoffPosition::new(436, 6, 'c', "3.", "0,0,z"),
    WyckoffPosition::new(436, 3, 'b', "-3.", "0,0,1/2"),
    WyckoffPosition::new(436, 3, 'a', "-3.", "0,0,0"),
    WyckoffPosition::new(437, 6, 'f', "1", "x,y,z"),
    WyckoffPosition::new(437, 3, 'e', "-1", "0,1/2,1/2"),
    WyckoffPosition::new(437, 3, 'd', "-1", "1/2,0,0"),
    WyckoffPosition::new(437, 2, 'c', "3.", "x,x,x"),
    WyckoffPosition::new(437, 1, 'b', "-3.", "1/2,1/2,1/2"),
    WyckoffPosition::new(437, 1, 'a', "-3.", "0,0,0"),
    WyckoffPosition::new(438, 6, 'l', "1", "x,y,z"),
    WyckoffPosition::new(438, 3, 'k', "..2", "x,-x,1/2"),
    WyckoffPosition::new(438, 3, 'j', "..2", "x,-x,0"),
    WyckoffPosition::new(438, 2, 'i', "3..", "2/3,1/3,z"),
    WyckoffPosition::new(438, 2, 'h', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(438, 2, 'g', "3..", "0,0,z"),
    WyckoffPosition::new(438, 1, 'f', "3.2", "2/3,1/3,1/2"),
    WyckoffPosition::new(438, 1, 'e', "3.2", "2/3,1/3,0"),
    WyckoffPosition::new(438, 1, 'd', "3.2", "1/3,2/3,1/2"),
    WyckoffPosition::new(438, 1, 'c', "3.2", "1/3,2/3,0"),
    WyckoffPosition::new(438, 1, 'b', "3.2", "0,0,1/2"),
    WyckoffPosition::new(438, 1, 'a', "3.2", "0,0,0"),
    WyckoffPosition::new(439, 6, 'g', "1", "x,y,z"),
    WyckoffPosition::new(439, 3, 'f', ".2.", "x,0,1/2"),
    WyckoffPosition::new(439, 3, 'e', ".2.", "x,0,0"),
    WyckoffPosition::new(439, 2, 'd', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(439, 2, 'c', "3..", "0,0,z"),
    WyckoffPosition::new(439, 1, 'b', "32.", "0,0,1/2"),
    WyckoffPosition::new(439, 1, 'a', "32.", "0,0,0"),
    WyckoffPosition::new(440, 6, 'c', "1", "x,y,z"),
    WyckoffPosition::new(440, 3, 'b', "..2", "x,-x,5/6"),
    WyckoffPosition::new(440, 3, 'a', "..2", "x,-x,1/3"),
    WyckoffPosition::new(441, 6, 'c', "1", "x,y,z"),
    WyckoffPosition::new(441, 3, 'b', ".2.", "x,0,5/6"),
    WyckoffPosition::new(441, 3, 'a', ".2.", "x,0,1/3"),
    WyckoffPosition::new(442, 6, 'c', "1", "x,y,z"),
    WyckoffPosition::new(442, 3, 'b', "..2", "x,-x,1/6"),
    WyckoffPosition::new(442, 3, 'a', "..2", "x,-x,2/3"),
    WyckoffPosition::new(443, 6, 'c', "1", "x,y,z"),
    WyckoffPosition::new(443, 3, 'b', ".2.", "x,0,1/6"),
    WyckoffPosition::new(443, 3, 'a', ".2.", "x,0,2/3"),
    WyckoffPosition::new(444, 18, 'f', "1", "x,y,z"),
    WyckoffPosition::new(444, 9, 'e', ".2", "x,0,1/2"),
    WyckoffPosition::new(444, 9, 'd', ".2", "x,0,0"),
    WyckoffPosition::new(444, 6, 'c', "3.", "0,0,z"),
    WyckoffPosition::new(444, 3, 'b', "32", "0,0,1/2"),
    WyckoffPosition::new(444, 3, 'a', "32", "0,0,0"),
    WyckoffPosition::new(445, 6, 'f', "1", "x,y,z"),
    WyckoffPosition::new(445, 3, 'e', ".2", "1/2,y,-y"),
    WyckoffPosition::new(445, 3, 'd', ".2", "0,y,-y"),
    WyckoffPosition::new(445, 2, 'c', "3.", "x,x,x"),
    WyckoffPosition::new(445, 1, 'b', "32", "1/2,1/2,1/2"),
    WyckoffPosition::new(445, 1, 'a', "32", "0,0,0"),
    WyckoffPosition::new(446, 6, 'e', "1", "x,y,z"),
    WyckoffPosition::new(446, 3, 'd', ".m.", "x,-x,z"),
    WyckoffPosition::new(446, 1, 'c', "3m.", "2/3,1/3,z"),
    WyckoffPosition::new(446, 1, 'b', "3m.", "1/3,2/3,z"),
    WyckoffPosition::new(446, 1, 'a', "3m.", "0,0,z"),
    WyckoffPosition::new(447, 6, 'd', "1", "x,y,z"),
    WyckoffPosition::new(447, 3, 'c', "..m", "x,0,z"),
    WyckoffPosition::new(447, 2, 'b', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(447, 1, 'a', "3.m", "0,0,z"),
    WyckoffPosition::new(448, 6, 'd', "1", "x,y,z"),
    WyckoffPosition::new(448, 2, 'c', "3..", "2/3,1/3,z"),
    WyckoffPosition::new(448, 2, 'b', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(448, 2, 'a', "3..", "0,0,z"),
    WyckoffPosition::new(449, 6, 'c', "1", "x,y,z"),
    WyckoffPosition::new(449, 2, 'b', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(449, 2, 'a', "3..", "0,0,z"),
    WyckoffPosition::new(450, 18, 'c', "1", "x,y,z"),
    WyckoffPosition::new(450, 9, 'b', ".m", "x,-x,z"),
    WyckoffPosition::new(450, 3, 'a', "3m", "0,0,z"),
    WyckoffPosition::new(451, 6, 'c', "1", "x,y,z"),
    WyckoffPosition::new(451, 3, 'b', ".m", "x,x,z"),
    WyckoffPosition::new(451, 1, 'a', "3m", "x,x,x"),
    WyckoffPosition::new(452, 18, 'b', "1", "x,y,z"),
    WyckoffPosition::new(452, 6, 'a', "3.", "0,0,z"),
    WyckoffPosition::new(453, 6, 'b', "1", "x,y,z"),
    WyckoffPosition::new(453, 2, 'a', "3.", "x,x,x"),
    WyckoffPosition::new(454, 12, 'l', "1", "x,y,z"),
    WyckoffPosition::new(454, 6, 'k', "..m", "x,0,z"),
    WyckoffPosition::new(454, 6, 'j', "..2", "x,-x,1/2"),
    WyckoffPosition::new(454, 6, 'i', "..2", "x,-x,0"),
    WyckoffPosition::new(454, 4, 'h', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(454, 3, 'g', "..2/m", "1/2,0,1/2"),
    WyckoffPosition::new(454, 3, 'f', "..2/m", "1/2,0,0"),
    WyckoffPosition::new(454, 2, 'e', "3.m", "0,0,z"),
    WyckoffPosition::new(454, 2, 'd', "3.2", "1/3,2/3,1/2"),
    WyckoffPosition::new(454, 2, 'c', "3.2", "1/3,2/3,0"),
    WyckoffPosition::new(454, 1, 'b', "-3.m", "0,0,1/2"),
    WyckoffPosition::new(454, 1, 'a', "-3.m", "0,0,0"),
    WyckoffPosition::new(455, 12, 'i', "1", "x,y,z"),
    WyckoffPosition::new(455, 6, 'h', "..2", "x,-x,1/4"),
    WyckoffPosition::new(455, 6, 'g', "-1", "1/2,0,0"),
    WyckoffPosition::new(455, 4, 'f', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(455, 4, 'e', "3..", "0,0,z"),
    WyckoffPosition::new(455, 2, 'd', "3.2", "2/3,1/3,1/4"),
    WyckoffPosition::new(455, 2, 'c', "3.2", "1/3,2/3,1/4"),
    WyckoffPosition::new(455, 2, 'b', "-3..", "0,0,0"),
    WyckoffPosition::new(455, 2, 'a', "3.2", "0,0,1/4"),
    WyckoffPosition::new(456, 12, 'j', "1", "x,y,z"),
    WyckoffPosition::new(456, 6, 'i', ".m.", "x,-x,z"),
    WyckoffPosition::new(456, 6, 'h', ".2.", "x,0,1/2"),
    WyckoffPosition::new(456, 6, 'g', ".2.", "x,0,0"),
    WyckoffPosition::new(456, 3, 'f', ".2/m.", "1/2,0,1/2"),
    WyckoffPosition::new(456, 3, 'e', ".2/m.", "1/2,0,0"),
    WyckoffPosition::new(456, 2, 'd', "3m.", "1/3,2/3,z"),
    WyckoffPosition::new(456, 2, 'c', "3m.", "0,0,z"),
    WyckoffPosition::new(456, 1, 'b', "-3m.", "0,0,1/2"),
    WyckoffPosition::new(456, 1, 'a', "-3m.", "0,0,0"),
    WyckoffPosition::new(457, 12, 'g', "1", "x,y,z"),
    WyckoffPosition::new(457, 6, 'f', ".2.", "x,0,1/4"),
    WyckoffPosition::new(457, 6, 'e', "-1", "1/2,0,0"),
    WyckoffPosition::new(457, 4, 'd', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(457, 4, 'c', "3..", "0,0,z"),
    WyckoffPosition::new(457, 2, 'b', "-3..", "0,0,0"),
    WyckoffPosition::new(457, 2, 'a', "32.", "0,0,1/4"),
    WyckoffPosition::new(458, 36, 'i', "1", "x,y,z"),
    WyckoffPosition::new(458, 18, 'h', ".m", "x,-x,z"),
    WyckoffPosition::new(458, 18, 'g', ".2", "x,0,1/2"),
    WyckoffPosition::new(458, 18, 'f', ".2", "x,0,0"),
    WyckoffPosition::new(458, 9, 'e', ".2/m", "1/2,0,0"),
    WyckoffPosition::new(458, 9, 'd', ".2/m", "1/2,0,1/2"),
    WyckoffPosition::new(458, 6, 'c', "3m", "0,0,z"),
    WyckoffPosition::new(458, 3, 'b', "-3m", "0,0,1/2"),
    WyckoffPosition::new(458, 3, 'a', "-3m", "0,0,0"),
    WyckoffPosition::new(459, 12, 'i', "1", "x,y,z"),
    WyckoffPosition::new(459, 6, 'h', ".m", "x,x,z"),
    WyckoffPosition::new(459, 6, 'g', ".2", "x,-x,1/2"),
    WyckoffPosition::new(459, 6, 'f', ".2", "x,-x,0"),
    WyckoffPosition::new(459, 3, 'e', ".2/m", "0,1/2,1/2"),
    WyckoffPosition::new(459, 3, 'd', ".2/m", "1/2,0,0"),
    WyckoffPosition::new(459, 2, 'c', "3m", "x,x,x"),
    WyckoffPosition::new(459, 1, 'b', "-3m", "1/2,1/2,1/2"),
    WyckoffPosition::new(459, 1, 'a', "-3m", "0,0,0"),
    WyckoffPosition::new(460, 36, 'f', "1", "x,y,z"),
    WyckoffPosition::new(460, 18, 'e', ".2", "x,0,1/4"),
    WyckoffPosition::new(460, 18, 'd', "-1", "1/2,0,0"),
    WyckoffPosition::new(460, 12, 'c', "3.", "0,0,z"),
    WyckoffPosition::new(460, 6, 'b', "-3.", "0,0,0"),
    WyckoffPosition::new(460, 6, 'a', "32", "0,0,1/4"),
    WyckoffPosition::new(461, 12, 'f', "1", "x,y,z"),
    WyckoffPosition::new(461, 6, 'e', ".2", "x,-x+1/2,1/4"),
    WyckoffPosition::new(461, 6, 'd', "-1", "1/2,0,0"),
    WyckoffPosition::new(461, 4, 'c', "3.", "x,x,x"),
    WyckoffPosition::new(461, 2, 'b', "-3.", "0,0,0"),
    WyckoffPosition::new(461, 2, 'a', "32", "1/4,1/4,1/4"),
    WyckoffPosition::new(462, 6, 'd', "1", "x,y,z"),
    WyckoffPosition::new(462, 3, 'c', "2..", "1/2,0,z"),
    WyckoffPosition::new(462, 2, 'b', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(462, 1, 'a', "6..", "0,0,z"),
    WyckoffPosition::new(463, 6, 'a', "1", "x,y,z"),
    WyckoffPosition::new(464, 6, 'a', "1", "x,y,z"),
    WyckoffPosition::new(465, 6, 'c', "1", "x,y,z"),
    WyckoffPosition::new(465, 3, 'b', "2..", "1/2,1/2,z"),
    WyckoffPosition::new(465, 3, 'a', "2..", "0,0,z"),
    WyckoffPosition::new(466, 6, 'c', "1", "x,y,z"),
    WyckoffPosition::new(466, 3, 'b', "2..", "1/2,1/2,z"),
    WyckoffPosition::new(466, 3, 'a', "2..", "0,0,z"),
    WyckoffPosition::new(467, 6, 'c', "1", "x,y,z"),
    WyckoffPosition::new(467, 2, 'b', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(467, 2, 'a', "3..", "0,0,z"),
    WyckoffPosition::new(468, 6, 'l', "1", "x,y,z"),
    WyckoffPosition::new(468, 3, 'k', "m..", "x,y,1/2"),
    WyckoffPosition::new(468, 3, 'j', "m..", "x,y,0"),
    WyckoffPosition::new(468, 2, 'i', "3..", "2/3,1/3,z"),
    WyckoffPosition::new(468, 2, 'h', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(468, 2, 'g', "3..", "0,0,z"),
    WyckoffPosition::new(468, 1, 'f', "-6..", "2/3,1/3,1/2"),
    WyckoffPosition::new(468, 1, 'e', "-6..", "2/3,1/3,0"),
    WyckoffPosition::new(468, 1, 'd', "-6..", "1/3,2/3,1/2"),
    WyckoffPosition::new(468, 1, 'c', "-6..", "1/3,2/3,0"),
    WyckoffPosition::new(468, 1, 'b', "-6..", "0,0,1/2"),
    WyckoffPosition::new(468, 1, 'a', "-6..", "0,0,0"),
    WyckoffPosition::new(469, 12, 'l', "1", "x,y,z"),
    WyckoffPosition::new(469, 6, 'k', "m..", "x,y,1/2"),
    WyckoffPosition::new(469, 6, 'j', "m..", "x,y,0"),
    WyckoffPosition::new(469, 6, 'i', "2..", "1/2,0,z"),
    WyckoffPosition::new(469, 4, 'h', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(469, 3, 'g', "2/m..", "1/2,0,1/2"),
    WyckoffPosition::new(469, 3, 'f', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(469, 2, 'e', "6..", "0,0,z"),
    WyckoffPosition::new(469, 2, 'd', "-6..", "1/3,2/3,1/2"),
    WyckoffPosition::new(469, 2, 'c', "-6..", "1/3,2/3,0"),
    WyckoffPosition::new(469, 1, 'b', "6/m..", "0,0,1/2"),
    WyckoffPosition::new(469, 1, 'a', "6/m..", "0,0,0"),
    WyckoffPosition::new(470, 12, 'i', "1", "x,y,z"),
    WyckoffPosition::new(470, 6, 'h', "m..", "x,y,1/4"),
    WyckoffPosition::new(470, 6, 'g', "-1", "1/2,0,0"),
    WyckoffPosition::new(470, 4, 'f', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(470, 4, 'e', "3..", "0,0,z"),
    WyckoffPosition::new(470, 2, 'd', "-6..", "2/3,1/3,1/4"),
    WyckoffPosition::new(470, 2, 'c', "-6..", "1/3,2/3,1/4"),
    WyckoffPosition::new(470, 2, 'b', "-3..", "0,0,0"),
    WyckoffPosition::new(470, 2, 'a', "-6..", "0,0,1/4"),
    WyckoffPosition::new(471, 12, 'n', "1", "x,y,z"),
    WyckoffPosition::new(471, 6, 'm', "..2", "x,-x,1/2"),
    WyckoffPosition::new(471, 6, 'l', "..2", "x,-x,0"),
    WyckoffPosition::new(471, 6, 'k', ".2.", "x,0,1/2"),
    WyckoffPosition::new(471, 6, 'j', ".2.", "x,0,0"),
    WyckoffPosition::new(471, 6, 'i', "2..", "1/2,0,z"),
    WyckoffPosition::new(471, 4, 'h', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(471, 3, 'g', "222", "1/2,0,1/2"),
    WyckoffPosition::new(471, 3, 'f', "222", "1/2,0,0"),
    WyckoffPosition::new(471, 2, 'e', "6..", "0,0,z"),
    WyckoffPosition::new(471, 2, 'd', "3.2", "1/3,2/3,1/2"),
    WyckoffPosition::new(471, 2, 'c', "3.2", "1/3,2/3,0"),
    WyckoffPosition::new(471, 1, 'b', "622", "0,0,1/2"),
    WyckoffPosition::new(471, 1, 'a', "622", "0,0,0"),
    WyckoffPosition::new(472, 12, 'c', "1", "x,y,z"),
    WyckoffPosition::new(472, 6, 'b', "..2", "x,2x,1/4"),
    WyckoffPosition::new(472, 6, 'a', ".2.", "x,0,0"),
    WyckoffPosition::new(473, 12, 'c', "1", "x,y,z"),
    WyckoffPosition::new(473, 6, 'b', "..2", "x,2x,3/4"),
    WyckoffPosition::new(473, 6, 'a', ".2.", "x,0,0"),
    WyckoffPosition::new(474, 12, 'k', "1", "x,y,z"),
    WyckoffPosition::new(474, 6, 'j', "..2", "x,2x,1/2"),
    WyckoffPosition::new(474, 6, 'i', "..2", "x,2x,0"),
    WyckoffPosition::new(474, 6, 'h', ".2.", "x,0,1/2"),
    WyckoffPosition::new(474, 6, 'g', ".2.", "x,0,0"),
    WyckoffPosition::new(474, 6, 'f', "2..", "1/2,0,z"),
    WyckoffPosition::new(474, 6, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(474, 3, 'd', "222", "1/2,0,1/2"),
    WyckoffPosition::new(474, 3, 'c', "222", "1/2,0,0"),
    WyckoffPosition::new(474, 3, 'b', "222", "0,0,1/2"),
    WyckoffPosition::new(474, 3, 'a', "222", "0,0,0"),
    WyckoffPosition::new(475, 12, 'k', "1", "x,y,z"),
    WyckoffPosition::new(475, 6, 'j', "..2", "x,2x,1/2"),
    WyckoffPosition::new(475, 6, 'i', "..2", "x,2x,0"),
    WyckoffPosition::new(475, 6, 'h', ".2.", "x,0,1/2"),
    WyckoffPosition::new(475, 6, 'g', ".2.", "x,0,0"),
    WyckoffPosition::new(475, 6, 'f', "2..", "1/2,0,z"),
    WyckoffPosition::new(475, 6, 'e', "2..", "0,0,z"),
    WyckoffPosition::new(475, 3, 'd', "222", "1/2,0,1/2"),
    WyckoffPosition::new(475, 3, 'c', "222", "1/2,0,0"),
    WyckoffPosition::new(475, 3, 'b', "222", "0,0,1/2"),
    WyckoffPosition::new(475, 3, 'a', "222", "0,0,0"),
    WyckoffPosition::new(476, 12, 'i', "1", "x,y,z"),
    WyckoffPosition::new(476, 6, 'h', "..2", "x,2x,1/4"),
    WyckoffPosition::new(476, 6, 'g', ".2.", "x,0,0"),
    WyckoffPosition::new(476, 4, 'f', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(476, 4, 'e', "3..", "0,0,z"),
    WyckoffPosition::new(476, 2, 'd', "3.2", "1/3,2/3,3/4"),
    WyckoffPosition::new(476, 2, 'c', "3.2", "1/3,2/3,1/4"),
    WyckoffPosition::new(476, 2, 'b', "3.2", "0,0,1/4"),
    WyckoffPosition::new(476, 2, 'a', "32.", "0,0,0"),
    WyckoffPosition::new(477, 12, 'f', "1", "x,y,z"),
    WyckoffPosition::new(477, 6, 'e', ".m.", "x,-x,z"),
    WyckoffPosition::new(477, 6, 'd', "..m", "x,0,z"),
    WyckoffPosition::new(477, 3, 'c', "2mm", "1/2,0,z"),
    WyckoffPosition::new(477, 2, 'b', "3m.", "1/3,2/3,z"),
    WyckoffPosition::new(477, 1, 'a', "6mm", "0,0,z"),
    WyckoffPosition::new(478, 12, 'd', "1", "x,y,z"),
    WyckoffPosition::new(478, 6, 'c', "2..", "1/2,0,z"),
    WyckoffPosition::new(478, 4, 'b', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(478, 2, 'a', "6..", "0,0,z"),
    WyckoffPosition::new(479, 12, 'd', "1", "x,y,z"),
    WyckoffPosition::new(479, 6, 'c', "..m", "x,0,z"),
    WyckoffPosition::new(479, 4, 'b', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(479, 2, 'a', "3.m", "0,0,z"),
    WyckoffPosition::new(480, 12, 'd', "1", "x,y,z"),
    WyckoffPosition::new(480, 6, 'c', ".m.", "x,-x,z"),
    WyckoffPosition::new(480, 2, 'b', "3m.", "1/3,2/3,z"),
    WyckoffPosition::new(480, 2, 'a', "3m.", "0,0,z"),
    WyckoffPosition::new(481, 12, 'o', "1", "x,y,z"),
    WyckoffPosition::new(481, 6, 'n', ".m.", "x,-x,z"),
    WyckoffPosition::new(481, 6, 'm', "m..", "x,y,1/2"),
    WyckoffPosition::new(481, 6, 'l', "m..", "x,y,0"),
    WyckoffPosition::new(481, 3, 'k', "mm2", "x,-x,1/2"),
    WyckoffPosition::new(481, 3, 'j', "mm2", "x,-x,0"),
    WyckoffPosition::new(481, 2, 'i', "3m.", "2/3,1/3,z"),
    WyckoffPosition::new(481, 2, 'h', "3m.", "1/3,2/3,z"),
    WyckoffPosition::new(481, 2, 'g', "3m.", "0,0,z"),
    WyckoffPosition::new(481, 1, 'f', "-6m2", "2/3,1/3,1/2"),
    WyckoffPosition::new(481, 1, 'e', "-6m2", "2/3,1/3,0"),
    WyckoffPosition::new(481, 1, 'd', "-6m2", "1/3,2/3,1/2"),
    WyckoffPosition::new(481, 1, 'c', "-6m2", "1/3,2/3,0"),
    WyckoffPosition::new(481, 1, 'b', "-6m2", "0,0,1/2"),
    WyckoffPosition::new(481, 1, 'a', "-6m2", "0,0,0"),
    WyckoffPosition::new(482, 12, 'l', "1", "x,y,z"),
    WyckoffPosition::new(482, 6, 'k', "m..", "x,y,1/4"),
    WyckoffPosition::new(482, 6, 'j', "..2", "x,-x,0"),
    WyckoffPosition::new(482, 4, 'i', "3..", "2/3,1/3,z"),
    WyckoffPosition::new(482, 4, 'h', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(482, 4, 'g', "3..", "0,0,z"),
    WyckoffPosition::new(482, 2, 'f', "-6..", "2/3,1/3,1/4"),
    WyckoffPosition::new(482, 2, 'e', "3.2", "2/3,1/3,0"),
    WyckoffPosition::new(482, 2, 'd', "-6..", "1/3,2/3,1/4"),
    WyckoffPosition::new(482, 2, 'c', "3.2", "1/3,2/3,0"),
    WyckoffPosition::new(482, 2, 'b', "-6..", "0,0,1/4"),
    WyckoffPosition::new(482, 2, 'a', "3.2", "0,0,0"),
    WyckoffPosition::new(483, 12, 'l', "1", "x,y,z"),
    WyckoffPosition::new(483, 6, 'k', "m..", "x,y,1/2"),
    WyckoffPosition::new(483, 6, 'j', "m..", "x,y,0"),
    WyckoffPosition::new(483, 6, 'i', "..m", "x,0,z"),
    WyckoffPosition::new(483, 4, 'h', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(483, 3, 'g', "m2m", "x,0,1/2"),
    WyckoffPosition::new(483, 3, 'f', "m2m", "x,0,0"),
    WyckoffPosition::new(483, 2, 'e', "3.m", "0,0,z"),
    WyckoffPosition::new(483, 2, 'd', "-6..", "1/3,2/3,1/2"),
    WyckoffPosition::new(483, 2, 'c', "-6..", "1/3,2/3,0"),
    WyckoffPosition::new(483, 1, 'b', "-62m", "0,0,1/2"),
    WyckoffPosition::new(483, 1, 'a', "-62m", "0,0,0"),
    WyckoffPosition::new(484, 12, 'i', "1", "x,y,z"),
    WyckoffPosition::new(484, 6, 'h', "m..", "x,y,1/4"),
    WyckoffPosition::new(484, 6, 'g', ".2.", "x,0,0"),
    WyckoffPosition::new(484, 4, 'f', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(484, 4, 'e', "3..", "0,0,z"),
    WyckoffPosition::new(484, 2, 'd', "-6..", "2/3,1/3,1/4"),
    WyckoffPosition::new(484, 2, 'c', "-6..", "1/3,2/3,1/4"),
    WyckoffPosition::new(484, 2, 'b', "-6..", "0,0,1/4"),
    WyckoffPosition::new(484, 2, 'a', "32.", "0,0,0"),
    WyckoffPosition::new(485, 24, 'r', "1", "x,y,z"),
    WyckoffPosition::new(485, 12, 'q', "m..", "x,y,1/2"),
    WyckoffPosition::new(485, 12, 'p', "m..", "x,y,0"),
    WyckoffPosition::new(485, 12, 'o', ".m.", "x,2x,z"),
    WyckoffPosition::new(485, 12, 'n', "..m", "x,0,z"),
    WyckoffPosition::new(485, 6, 'm', "mm2", "x,2x,1/2"),
    WyckoffPosition::new(485, 6, 'l', "mm2", "x,2x,0"),
    WyckoffPosition::new(485, 6, 'k', "m2m", "x,0,1/2"),
    WyckoffPosition::new(485, 6, 'j', "m2m", "x,0,0"),
    WyckoffPosition::new(485, 6, 'i', "2mm", "1/2,0,z"),
    WyckoffPosition::new(485, 4, 'h', "3m.", "1/3,2/3,z"),
    WyckoffPosition::new(485, 3, 'g', "mmm", "1/2,0,1/2"),
    WyckoffPosition::new(485, 3, 'f', "mmm", "1/2,0,0"),
    WyckoffPosition::new(485, 2, 'e', "6mm", "0,0,z"),
    WyckoffPosition::new(485, 2, 'd', "-6m2", "1/3,2/3,1/2"),
    WyckoffPosition::new(485, 2, 'c', "-6m2", "1/3,2/3,0"),
    WyckoffPosition::new(485, 1, 'b', "6/mmm", "0,0,1/2"),
    WyckoffPosition::new(485, 1, 'a', "6/mmm", "0,0,0"),
    WyckoffPosition::new(486, 24, 'm', "1", "x,y,z"),
    WyckoffPosition::new(486, 12, 'l', "m..", "x,y,0"),
    WyckoffPosition::new(486, 12, 'k', "..2", "x,2x,1/4"),
    WyckoffPosition::new(486, 12, 'j', ".2.", "x,0,1/4"),
    WyckoffPosition::new(486, 12, 'i', "2..", "1/2,0,z"),
    WyckoffPosition::new(486, 8, 'h', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(486, 6, 'g', "2/m..", "1/2,0,0"),
    WyckoffPosition::new(486, 6, 'f', "222", "1/2,0,1/4"),
    WyckoffPosition::new(486, 4, 'e', "6..", "0,0,z"),
    WyckoffPosition::new(486, 4, 'd', "-6..", "1/3,2/3,0"),
    WyckoffPosition::new(486, 4, 'c', "3.2", "1/3,2/3,1/4"),
    WyckoffPosition::new(486, 2, 'b', "6/m..", "0,0,0"),
    WyckoffPosition::new(486, 2, 'a', "622", "0,0,1/4"),
    WyckoffPosition::new(487, 24, 'l', "1", "x,y,z"),
    WyckoffPosition::new(487, 12, 'k', "..m", "x,0,z"),
    WyckoffPosition::new(487, 12, 'j', "m..", "x,y,1/4"),
    WyckoffPosition::new(487, 12, 'i', "..2", "x,2x,0"),
    WyckoffPosition::new(487, 8, 'h', "3..", "1/3,2/3,z"),
    WyckoffPosition::new(487, 6, 'g', "m2m", "x,0,1/4"),
    WyckoffPosition::new(487, 6, 'f', "..2/m", "1/2,0,0"),
    WyckoffPosition::new(487, 4, 'e', "3.m", "0,0,z"),
    WyckoffPosition::new(487, 4, 'd', "3.2", "1/3,2/3,0"),
    WyckoffPosition::new(487, 4, 'c', "-6..", "1/3,2/3,1/4"),
    WyckoffPosition::new(487, 2, 'b', "-3.m", "0,0,0"),
    WyckoffPosition::new(487, 2, 'a', "-62m", "0,0,1/4"),
    WyckoffPosition::new(488, 24, 'l', "1", "x,y,z"),
    WyckoffPosition::new(488, 12, 'k', ".m.", "x,2x,z"),
    WyckoffPosition::new(488, 12, 'j', "m..", "x,y,1/4"),
    WyckoffPosition::new(488, 12, 'i', ".2.", "x,0,0"),
    WyckoffPosition::new(488, 6, 'h', "mm2", "x,2x,1/4"),
    WyckoffPosition::new(488, 6, 'g', ".2/m.", "1/2,0,0"),
    WyckoffPosition::new(488, 4, 'f', "3m.", "1/3,2/3,z"),
    WyckoffPosition::new(488, 4, 'e', "3m.", "0,0,z"),
    WyckoffPosition::new(488, 2, 'd', "-6m2", "1/3,2/3,3/4"),
    WyckoffPosition::new(488, 2, 'c', "-6m2", "1/3,2/3,1/4"),
    WyckoffPosition::new(488, 2, 'b', "-6m2", "0,0,1/4"),
    WyckoffPosition::new(488, 2, 'a', "-3m.", "0,0,0"),
    WyckoffPosition::new(489, 12, 'j', "1", "x,y,z"),
    WyckoffPosition::new(489, 6, 'i', "2..", "x,1/2,1/2"),
    WyckoffPosition::new(489, 6, 'h', "2..", "x,1/2,0"),
    WyckoffPosition::new(489, 6, 'g', "2..", "x,0,1/2"),
    WyckoffPosition::new(489, 6, 'f', "2..", "x,0,0"),
    WyckoffPosition::new(489, 4, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(489, 3, 'd', "222..", "1/2,0,0"),
    WyckoffPosition::new(489, 3, 'c', "222..", "0,1/2,1/2"),
    WyckoffPosition::new(489, 1, 'b', "23.", "1/2,1/2,1/2"),
    WyckoffPosition::new(489, 1, 'a', "23.", "0,0,0"),
    WyckoffPosition::new(490, 48, 'h', "1", "x,y,z"),
    WyckoffPosition::new(490, 24, 'g', "2..", "x,1/4,1/4"),
    WyckoffPosition::new(490, 24, 'f', "2..", "x,0,0"),
    WyckoffPosition::new(490, 16, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(490, 4, 'd', "23.", "3/4,3/4,3/4"),
    WyckoffPosition::new(490, 4, 'c', "23.", "1/4,1/4,1/4"),
    WyckoffPosition::new(490, 4, 'b', "23.", "1/2,1/2,1/2"),
    WyckoffPosition::new(490, 4, 'a', "23.", "0,0,0"),
    WyckoffPosition::new(491, 24, 'f', "1", "x,y,z"),
    WyckoffPosition::new(491, 12, 'e', "2..", "x,1/2,0"),
    WyckoffPosition::new(491, 12, 'd', "2..", "x,0,0"),
    WyckoffPosition::new(491, 8, 'c', ".3.", "x,x,x"),
    WyckoffPosition::new(491, 6, 'b', "222..", "0,1/2,1/2"),
    WyckoffPosition::new(491, 2, 'a', "23.", "0,0,0"),
    WyckoffPosition::new(492, 12, 'b', "1", "x,y,z"),
    WyckoffPosition::new(492, 4, 'a', ".3.", "x,x,x"),
    WyckoffPosition::new(493, 24, 'c', "1", "x,y,z"),
    WyckoffPosition::new(493, 12, 'b', "2..", "x,0,1/4"),
    WyckoffPosition::new(493, 8, 'a', ".3.", "x,x,x"),
    WyckoffPosition::new(494, 24, 'l', "1", "x,y,z"),
    WyckoffPosition::new(494, 12, 'k', "m..", "1/2,y,z"),
    WyckoffPosition::new(494, 12, 'j', "m..", "0,y,z"),
    WyckoffPosition::new(494, 8, 'i', ".3.", "x,x,x"),
    WyckoffPosition::new(494, 6, 'h', "mm2..", "x,1/2,1/2"),
    WyckoffPosition::new(494, 6, 'g', "mm2..", "x,1/2,0"),
    WyckoffPosition::new(494, 6, 'f', "mm2..", "x,0,1/2"),
    WyckoffPosition::new(494, 6, 'e', "mm2..", "x,0,0"),
    WyckoffPosition::new(494, 3, 'd', "mmm..", "1/2,0,0"),
    WyckoffPosition::new(494, 3, 'c', "mmm..", "0,1/2,1/2"),
    WyckoffPosition::new(494, 1, 'b', "m-3.", "1/2,1/2,1/2"),
    WyckoffPosition::new(494, 1, 'a', "m-3.", "0,0,0"),
    WyckoffPosition::new(495, 24, 'h', "1", "x,y,z"),
    WyckoffPosition::new(495, 12, 'g', "2..", "x,1/2,0"),
    WyckoffPosition::new(495, 12, 'f', "2..", "x,0,0"),
    WyckoffPosition::new(495, 8, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(495, 6, 'd', "222..", "0,1/2,1/2"),
    WyckoffPosition::new(495, 4, 'c', ".-3.", "3/4,3/4,3/4"),
    WyckoffPosition::new(495, 4, 'b', ".-3.", "1/4,1/4,1/4"),
    WyckoffPosition::new(495, 2, 'a', "23.", "0,0,0"),
    WyckoffPosition::new(496, 24, 'h', "1", "x,y,z"),
    WyckoffPosition::new(496, 12, 'g', "2..", "x,3/4,1/4"),
    WyckoffPosition::new(496, 12, 'f', "2..", "x,1/4,1/4"),
    WyckoffPosition::new(496, 8, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(496, 6, 'd', "222..", "1/4,3/4,3/4"),
    WyckoffPosition::new(496, 4, 'c', ".-3.", "1/2,1/2,1/2"),
    WyckoffPosition::new(496, 4, 'b', ".-3.", "0,0,0"),
    WyckoffPosition::new(496, 2, 'a', "23.", "1/4,1/4,1/4"),
    WyckoffPosition::new(497, 96, 'i', "1", "x,y,z"),
    WyckoffPosition::new(497, 48, 'h', "m..", "0,y,z"),
    WyckoffPosition::new(497, 48, 'g', "2..", "x,1/4,1/4"),
    WyckoffPosition::new(497, 32, 'f', ".3.", "x,x,x"),
    WyckoffPosition::new(497, 24, 'e', "mm2..", "x,0,0"),
    WyckoffPosition::new(497, 24, 'd', "2/m..", "0,1/4,1/4"),
    WyckoffPosition::new(497, 8, 'c', "23.", "1/4,1/4,1/4"),
    WyckoffPosition::new(497, 4, 'b', "m-3.", "1/2,1/2,1/2"),
    WyckoffPosition::new(497, 4, 'a', "m-3.", "0,0,0"),
    WyckoffPosition::new(498, 96, 'g', "1", "x,y,z"),
    WyckoffPosition::new(498, 48, 'f', "2..", "x,0,0"),
    WyckoffPosition::new(498, 32, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(498, 16, 'd', ".-3.", "5/8,5/8,5/8"),
    WyckoffPosition::new(498, 16, 'c', ".-3.", "1/8,1/8,1/8"),
    WyckoffPosition::new(498, 8, 'b', "23.", "1/2,1/2,1/2"),
    WyckoffPosition::new(498, 8, 'a', "23.", "0,0,0"),
    WyckoffPosition::new(499, 96, 'g', "1", "x,y,z"),
    WyckoffPosition::new(499, 48, 'f', "2..", "x,1/8,1/8"),
    WyckoffPosition::new(499, 32, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(499, 16, 'd', ".-3.", "1/2,1/2,1/2"),
    WyckoffPosition::new(499, 16, 'c', ".-3.", "0,0,0"),
    WyckoffPosition::new(499, 8, 'b', "23.", "5/8,5/8,5/8"),
    WyckoffPosition::new(499, 8, 'a', "23.", "1/8,1/8,1/8"),
    WyckoffPosition::new(500, 48, 'h', "1", "x,y,z"),
    WyckoffPosition::new(500, 24, 'g', "m..", "0,y,z"),
    WyckoffPosition::new(500, 16, 'f', ".3.", "x,x,x"),
    WyckoffPosition::new(500, 12, 'e', "mm2..", "x,0,1/2"),
    WyckoffPosition::new(500, 12, 'd', "mm2..", "x,0,0"),
    WyckoffPosition::new(500, 8, 'c', ".-3.", "1/4,1/4,1/4"),
    WyckoffPosition::new(500, 6, 'b', "mmm..", "0,1/2,1/2"),
    WyckoffPosition::new(500, 2, 'a', "m-3.", "0,0,0"),
    WyckoffPosition::new(501, 24, 'd', "1", "x,y,z"),
    WyckoffPosition::new(501, 8, 'c', ".3.", "x,x,x"),
    WyckoffPosition::new(501, 4, 'b', ".-3.", "1/2,1/2,1/2"),
    WyckoffPosition::new(501, 4, 'a', ".-3.", "0,0,0"),
    WyckoffPosition::new(502, 48, 'e', "1", "x,y,z"),
    WyckoffPosition::new(502, 24, 'd', "2..", "x,0,1/4"),
    WyckoffPosition::new(502, 16, 'c', ".3.", "x,x,x"),
    WyckoffPosition::new(502, 8, 'b', ".-3.", "1/4,1/4,1/4"),
    WyckoffPosition::new(502, 8, 'a', ".-3.", "0,0,0"),
    WyckoffPosition::new(503, 24, 'k', "1", "x,y,z"),
    WyckoffPosition::new(503, 12, 'j', "..2", "1/2,y,y"),
    WyckoffPosition::new(503, 12, 'i', "..2", "0,y,y"),
    WyckoffPosition::new(503, 12, 'h', "2..", "x,1/2,0"),
    WyckoffPosition::new(503, 8, 'g', ".3.", "x,x,x"),
    WyckoffPosition::new(503, 6, 'f', "4..", "x,1/2,1/2"),
    WyckoffPosition::new(503, 6, 'e', "4..", "x,0,0"),
    WyckoffPosition::new(503, 3, 'd', "42.2", "1/2,0,0"),
    WyckoffPosition::new(503, 3, 'c', "42.2", "0,1/2,1/2"),
    WyckoffPosition::new(503, 1, 'b', "432", "1/2,1/2,1/2"),
    WyckoffPosition::new(503, 1, 'a', "432", "0,0,0"),
    WyckoffPosition::new(504, 24, 'm', "1", "x,y,z"),
    WyckoffPosition::new(504, 12, 'l', "..2", "1/4,y,y+1/2"),
    WyckoffPosition::new(504, 12, 'k', "..2", "1/4,y,-y+1/2"),
    WyckoffPosition::new(504, 12, 'j', "2..", "x,1/2,0"),
    WyckoffPosition::new(504, 12, 'i', "2..", "x,0,1/2"),
    WyckoffPosition::new(504, 12, 'h', "2..", "x,0,0"),
    WyckoffPosition::new(504, 8, 'g', ".3.", "x,x,x"),
    WyckoffPosition::new(504, 6, 'f', "2.22", "1/4,1/2,0"),
    WyckoffPosition::new(504, 6, 'e', "2.22", "1/4,0,1/2"),
    WyckoffPosition::new(504, 6, 'd', "222..", "0,1/2,1/2"),
    WyckoffPosition::new(504, 4, 'c', ".32", "3/4,3/4,3/4"),
    WyckoffPosition::new(504, 4, 'b', ".32", "1/4,1/4,1/4"),
    WyckoffPosition::new(504, 2, 'a', "23.", "0,0,0"),
    WyckoffPosition::new(505, 96, 'j', "1", "x,y,z"),
    WyckoffPosition::new(505, 48, 'i', "2..", "x,1/4,1/4"),
    WyckoffPosition::new(505, 48, 'h', "..2", "1/2,y,y"),
    WyckoffPosition::new(505, 48, 'g', "..2", "0,y,y"),
    WyckoffPosition::new(505, 32, 'f', ".3.", "x,x,x"),
    WyckoffPosition::new(505, 24, 'e', "4..", "x,0,0"),
    WyckoffPosition::new(505, 24, 'd', "2.22", "0,1/4,1/4"),
    WyckoffPosition::new(505, 8, 'c', "23.", "1/4,1/4,1/4"),
    WyckoffPosition::new(505, 4, 'b', "432", "1/2,1/2,1/2"),
    WyckoffPosition::new(505, 4, 'a', "432", "0,0,0"),
    WyckoffPosition::new(506, 96, 'h', "1", "x,y,z"),
    WyckoffPosition::new(506, 48, 'g', "..2", "1/8,y,-y+1/4"),
    WyckoffPosition::new(506, 48, 'f', "2..", "x,0,0"),
    WyckoffPosition::new(506, 32, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(506, 16, 'd', ".32", "5/8,5/8,5/8"),
    WyckoffPosition::new(506, 16, 'c', ".32", "1/8,1/8,1/8"),
    WyckoffPosition::new(506, 8, 'b', "23.", "1/2,1/2,1/2"),
    WyckoffPosition::new(506, 8, 'a', "23.", "0,0,0"),
    WyckoffPosition::new(507, 48, 'j', "1", "x,y,z"),
    WyckoffPosition::new(507, 24, 'i', "..2", "1/4,y,-y+1/2"),
    WyckoffPosition::new(507, 24, 'h', "..2", "0,y,y"),
    WyckoffPosition::new(507, 24, 'g', "2..", "x,1/2,0"),
    WyckoffPosition::new(507, 16, 'f', ".3.", "x,x,x"),
    WyckoffPosition::new(507, 12, 'e', "4..", "x,0,0"),
    WyckoffPosition::new(507, 12, 'd', "2.22", "1/4,1/2,0"),
    WyckoffPosition::new(507, 8, 'c', ".32", "1/4,1/4,1/4"),
    WyckoffPosition::new(507, 6, 'b', "42.2", "0,1/2,1/2"),
    WyckoffPosition::new(507, 2, 'a', "432", "0,0,0"),
    WyckoffPosition::new(508, 24, 'e', "1", "x,y,z"),
    WyckoffPosition::new(508, 12, 'd', "..2", "1/8,y,-y+1/4"),
    WyckoffPosition::new(508, 8, 'c', ".3.", "x,x,x"),
    WyckoffPosition::new(508, 4, 'b', ".32", "5/8,5/8,5/8"),
    WyckoffPosition::new(508, 4, 'a', ".32", "1/8,1/8,1/8"),
    WyckoffPosition::new(509, 24, 'e', "1", "x,y,z"),
    WyckoffPosition::new(509, 12, 'd', "..2", "1/8,y,y+1/4"),
    WyckoffPosition::new(509, 8, 'c', ".3.", "x,x,x"),
    WyckoffPosition::new(509, 4, 'b', ".32", "7/8,7/8,7/8"),
    WyckoffPosition::new(509, 4, 'a', ".32", "3/8,3/8,3/8"),
    WyckoffPosition::new(510, 48, 'i', "1", "x,y,z"),
    WyckoffPosition::new(510, 24, 'h', "..2", "1/8,y,-y+1/4"),
    WyckoffPosition::new(510, 24, 'g', "..2", "1/8,y,y+1/4"),
    WyckoffPosition::new(510, 24, 'f', "2..", "x,0,1/4"),
    WyckoffPosition::new(510, 16, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(510, 12, 'd', "2.22", "5/8,0,1/4"),
    WyckoffPosition::new(510, 12, 'c', "2.22", "1/8,0,1/4"),
    WyckoffPosition::new(510, 8, 'b', ".32", "7/8,7/8,7/8"),
    WyckoffPosition::new(510, 8, 'a', ".32", "1/8,1/8,1/8"),
    WyckoffPosition::new(511, 24, 'j', "1", "x,y,z"),
    WyckoffPosition::new(511, 12, 'i', "..m", "x,x,z"),
    WyckoffPosition::new(511, 12, 'h', "2..", "x,1/2,0"),
    WyckoffPosition::new(511, 6, 'g', "2.mm", "x,1/2,1/2"),
    WyckoffPosition::new(511, 6, 'f', "2.mm", "x,0,0"),
    WyckoffPosition::new(511, 4, 'e', ".3m", "x,x,x"),
    WyckoffPosition::new(511, 3, 'd', "-42.m", "1/2,0,0"),
    WyckoffPosition::new(511, 3, 'c', "-42.m", "0,1/2,1/2"),
    WyckoffPosition::new(511, 1, 'b', "-43m", "1/2,1/2,1/2"),
    WyckoffPosition::new(511, 1, 'a', "-43m", "0,0,0"),
    WyckoffPosition::new(512, 96, 'i', "1", "x,y,z"),
    WyckoffPosition::new(512, 48, 'h', "..m", "x,x,z"),
    WyckoffPosition::new(512, 24, 'g', "2.mm", "x,1/4,1/4"),
    WyckoffPosition::new(512, 24, 'f', "2.mm", "x,0,0"),
    WyckoffPosition::new(512, 16, 'e', ".3m", "x,x,x"),
    WyckoffPosition::new(512, 4, 'd', "-43m", "3/4,3/4,3/4"),
    WyckoffPosition::new(512, 4, 'c', "-43m", "1/4,1/4,1/4"),
    WyckoffPosition::new(512, 4, 'b', "-43m", "1/2,1/2,1/2"),
    WyckoffPosition::new(512, 4, 'a', "-43m", "0,0,0"),
    WyckoffPosition::new(513, 48, 'h', "1", "x,y,z"),
    WyckoffPosition::new(513, 24, 'g', "..m", "x,x,z"),
    WyckoffPosition::new(513, 24, 'f', "2..", "x,1/2,0"),
    WyckoffPosition::new(513, 12, 'e', "2.mm", "x,0,0"),
    WyckoffPosition::new(513, 12, 'd', "-4..", "1/4,1/2,0"),
    WyckoffPosition::new(513, 8, 'c', ".3m", "x,x,x"),
    WyckoffPosition::new(513, 6, 'b', "-42.m", "0,1/2,1/2"),
    WyckoffPosition::new(513, 2, 'a', "-43m", "0,0,0"),
    WyckoffPosition::new(514, 24, 'i', "1", "x,y,z"),
    WyckoffPosition::new(514, 12, 'h', "2..", "x,0,1/2"),
    WyckoffPosition::new(514, 12, 'g', "2..", "x,1/2,0"),
    WyckoffPosition::new(514, 12, 'f', "2..", "x,0,0"),
    WyckoffPosition::new(514, 8, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(514, 6, 'd', "-4..", "1/4,0,1/2"),
    WyckoffPosition::new(514, 6, 'c', "-4..", "1/4,1/2,0"),
    WyckoffPosition::new(514, 6, 'b', "222..", "0,1/2,1/2"),
    WyckoffPosition::new(514, 2, 'a', "23.", "0,0,0"),
    WyckoffPosition::new(515, 96, 'h', "1", "x,y,z"),
    WyckoffPosition::new(515, 48, 'g', "2..", "x,1/4,1/4"),
    WyckoffPosition::new(515, 48, 'f', "2..", "x,0,0"),
    WyckoffPosition::new(515, 32, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(515, 24, 'd', "-4..", "1/4,0,0"),
    WyckoffPosition::new(515, 24, 'c', "-4..", "0,1/4,1/4"),
    WyckoffPosition::new(515, 8, 'b', "23.", "1/4,1/4,1/4"),
    WyckoffPosition::new(515, 8, 'a', "23.", "0,0,0"),
    WyckoffPosition::new(516, 48, 'e', "1", "x,y,z"),
    WyckoffPosition::new(516, 24, 'd', "2..", "x,0,1/4"),
    WyckoffPosition::new(516, 16, 'c', ".3.", "x,x,x"),
    WyckoffPosition::new(516, 12, 'b', "-4..", "7/8,0,1/4"),
    WyckoffPosition::new(516, 12, 'a', "-4..", "3/8,0,1/4"),
    WyckoffPosition::new(517, 48, 'n', "1", "x,y,z"),
    WyckoffPosition::new(517, 24, 'm', "..m", "x,x,z"),
    WyckoffPosition::new(517, 24, 'l', "m..", "1/2,y,z"),
    WyckoffPosition::new(517, 24, 'k', "m..", "0,y,z"),
    WyckoffPosition::new(517, 12, 'j', "m.m2", "1/2,y,y"),
    WyckoffPosition::new(517, 12, 'i', "m.m2", "0,y,y"),
    WyckoffPosition::new(517, 12, 'h', "mm2..", "x,1/2,0"),
    WyckoffPosition::new(517, 8, 'g', ".3m", "x,x,x"),
    WyckoffPosition::new(517, 6, 'f', "4m.m", "x,1/2,1/2"),
    WyckoffPosition::new(517, 6, 'e', "4m.m", "x,0,0"),
    WyckoffPosition::new(517, 3, 'd', "4/mm.m", "1/2,0,0"),
    WyckoffPosition::new(517, 3, 'c', "4/mm.m", "0,1/2,1/2"),
    WyckoffPosition::new(517, 1, 'b', "m-3m", "1/2,1/2,1/2"),
    WyckoffPosition::new(517, 1, 'a', "m-3m", "0,0,0"),
    WyckoffPosition::new(518, 48, 'i', "1", "x,y,z"),
    WyckoffPosition::new(518, 24, 'h', "..2", "0,y,y"),
    WyckoffPosition::new(518, 24, 'g', "2..", "x,0,1/2"),
    WyckoffPosition::new(518, 16, 'f', ".3.", "x,x,x"),
    WyckoffPosition::new(518, 12, 'e', "4..", "x,0,0"),
    WyckoffPosition::new(518, 12, 'd', "-4..", "1/4,0,1/2"),
    WyckoffPosition::new(518, 8, 'c', ".-3.", "1/4,1/4,1/4"),
    WyckoffPosition::new(518, 6, 'b', "42.2", "0,1/2,1/2"),
    WyckoffPosition::new(518, 2, 'a', "432", "0,0,0"),
    WyckoffPosition::new(519, 48, 'i', "1", "x,y,z"),
    WyckoffPosition::new(519, 24, 'h', "..2", "1/4,y,y"),
    WyckoffPosition::new(519, 24, 'g', "2..", "x,3/4,1/4"),
    WyckoffPosition::new(519, 16, 'f', ".3.", "x,x,x"),
    WyckoffPosition::new(519, 12, 'e', "4..", "x,1/4,1/4"),
    WyckoffPosition::new(519, 12, 'd', "-4..", "0,3/4,1/4"),
    WyckoffPosition::new(519, 8, 'c', ".-3.", "0,0,0"),
    WyckoffPosition::new(519, 6, 'b', "42.2", "3/4,1/4,1/4"),
    WyckoffPosition::new(519, 2, 'a', "432", "1/4,1/4,1/4"),
    WyckoffPosition::new(520, 48, 'l', "1", "x,y,z"),
    WyckoffPosition::new(520, 24, 'k', "m..", "0,y,z"),
    WyckoffPosition::new(520, 24, 'j', "..2", "1/4,y,y+1/2"),
    WyckoffPosition::new(520, 16, 'i', ".3.", "x,x,x"),
    WyckoffPosition::new(520, 12, 'h', "mm2..", "x,1/2,0"),
    WyckoffPosition::new(520, 12, 'g', "mm2..", "x,0,1/2"),
    WyckoffPosition::new(520, 12, 'f', "mm2..", "x,0,0"),
    WyckoffPosition::new(520, 8, 'e', ".32", "1/4,1/4,1/4"),
    WyckoffPosition::new(520, 6, 'd', "-4m.2", "1/4,1/2,0"),
    WyckoffPosition::new(520, 6, 'c', "-4m.2", "1/4,0,1/2"),
    WyckoffPosition::new(520, 6, 'b', "mmm..", "0,1/2,1/2"),
    WyckoffPosition::new(520, 2, 'a', "m-3.", "0,0,0"),
    WyckoffPosition::new(521, 48, 'l', "1", "x,y,z"),
    WyckoffPosition::new(521, 24, 'k', "..m", "x,x,z"),
    WyckoffPosition::new(521, 24, 'j', "..2", "1/4,y,y+1/2"),
    WyckoffPosition::new(521, 24, 'i', "..2", "1/4,y,-y+1/2"),
    WyckoffPosition::new(521, 24, 'h', "2..", "x,0,1/2"),
    WyckoffPosition::new(521, 12, 'g', "2.mm", "x,0,0"),
    WyckoffPosition::new(521, 12, 'f', "2.22", "1/4,0,1/2"),
    WyckoffPosition::new(521, 8, 'e', ".3m", "x,x,x"),
    WyckoffPosition::new(521, 6, 'd', "-42.m", "0,1/2,1/2"),
    WyckoffPosition::new(521, 4, 'c', ".-3m", "3/4,3/4,3/4"),
    WyckoffPosition::new(521, 4, 'b', ".-3m", "1/4,1/4,1/4"),
    WyckoffPosition::new(521, 2, 'a', "-43m", "0,0,0"),
    WyckoffPosition::new(522, 48, 'l', "1", "x,y,z"),
    WyckoffPosition::new(522, 24, 'k', "..m", "x,x,z"),
    WyckoffPosition::new(522, 24, 'j', "..2", "1/2,y,-y"),
    WyckoffPosition::new(522, 24, 'i', "..2", "1/2,y,y+1/2"),
    WyckoffPosition::new(522, 24, 'h', "2..", "x,1/4,3/4"),
    WyckoffPosition::new(522, 12, 'g', "2.mm", "x,1/4,1/4"),
    WyckoffPosition::new(522, 12, 'f', "2.22", "1/2,1/4,3/4"),
    WyckoffPosition::new(522, 8, 'e', ".3m", "x,x,x"),
    WyckoffPosition::new(522, 6, 'd', "-42.m", "1/4,3/4,3/4"),
    WyckoffPosition::new(522, 4, 'c', ".-3m", "1/2,1/2,1/2"),
    WyckoffPosition::new(522, 4, 'b', ".-3m", "0,0,0"),
    WyckoffPosition::new(522, 2, 'a', "-43m", "1/4,1/4,1/4"),
    WyckoffPosition::new(523, 192, 'l', "1", "x,y,z"),
    WyckoffPosition::new(523, 96, 'k', "..m", "x,x,z"),
    WyckoffPosition::new(523, 96, 'j', "m..", "0,y,z"),
    WyckoffPosition::new(523, 48, 'i', "m.m2", "1/2,y,y"),
    WyckoffPosition::new(523, 48, 'h', "m.m2", "0,y,y"),
    WyckoffPosition::new(523, 48, 'g', "2.mm", "x,1/4,1/4"),
    WyckoffPosition::new(523, 32, 'f', ".3m", "x,x,x"),
    WyckoffPosition::new(523, 24, 'e', "4m.m", "x,0,0"),
    WyckoffPosition::new(523, 24, 'd', "m.mm", "0,1/4,1/4"),
    WyckoffPosition::new(523, 8, 'c', "-43m", "1/4,1/4,1/4"),
    WyckoffPosition::new(523, 4, 'b', "m-3m", "1/2,1/2,1/2"),
    WyckoffPosition::new(523, 4, 'a', "m-3m", "0,0,0"),
    WyckoffPosition::new(524, 192, 'j', "1", "x,y,z"),
    WyckoffPosition::new(524, 96, 'i', "m..", "0,y,z"),
    WyckoffPosition::new(524, 96, 'h', "..2", "1/4,y,y"),
    WyckoffPosition::new(524, 64, 'g', ".3.", "x,x,x"),
    WyckoffPosition::new(524, 48, 'f', "4..", "x,1/4,1/4"),
    WyckoffPosition::new(524, 48, 'e', "mm2..", "x,0,0"),
    WyckoffPosition::new(524, 24, 'd', "4/m..", "0,1/4,1/4"),
    WyckoffPosition::new(524, 24, 'c', "-4m.2", "1/4,0,0"),
    WyckoffPosition::new(524, 8, 'b', "m-3.", "0,0,0"),
    WyckoffPosition::new(524, 8, 'a', "432", "1/4,1/4,1/4"),
    WyckoffPosition::new(525, 192, 'i', "1", "x,y,z"),
    WyckoffPosition::new(525, 96, 'h', "..2", "1/8,y,-y+1/4"),
    WyckoffPosition::new(525, 96, 'g', "..m", "x,x,z"),
    WyckoffPosition::new(525, 48, 'f', "2.mm", "x,0,0"),
    WyckoffPosition::new(525, 32, 'e', ".3m", "x,x,x"),
    WyckoffPosition::new(525, 16, 'd', ".-3m", "5/8,5/8,5/8"),
    WyckoffPosition::new(525, 16, 'c', ".-3m", "1/8,1/8,1/8"),
    WyckoffPosition::new(525, 8, 'b', "-43m", "1/2,1/2,1/2"),
    WyckoffPosition::new(525, 8, 'a', "-43m", "0,0,0"),
    WyckoffPosition::new(526, 192, 'i', "1", "x,y,z"),
    WyckoffPosition::new(526, 96, 'h', "..2", "0,y,-y"),
    WyckoffPosition::new(526, 96, 'g', "..m", "x,x,z"),
    WyckoffPosition::new(526, 48, 'f', "2.mm", "x,1/8,1/8"),
    WyckoffPosition::new(526, 32, 'e', ".3m", "x,x,x"),
    WyckoffPosition::new(526, 16, 'd', ".-3m", "1/2,1/2,1/2"),
    WyckoffPosition::new(526, 16, 'c', ".-3m", "0,0,0"),
    WyckoffPosition::new(526, 8, 'b', "-43m", "3/8,3/8,3/8"),
    WyckoffPosition::new(526, 8, 'a', "-43m", "1/8,1/8,1/8"),
    WyckoffPosition::new(527, 192, 'h', "1", "x,y,z"),
    WyckoffPosition::new(527, 96, 'g', "..2", "1/8,y,-y+1/4"),
    WyckoffPosition::new(527, 96, 'f', "2..", "x,0,0"),
    WyckoffPosition::new(527, 64, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(527, 48, 'd', "-4..", "1/4,0,0"),
    WyckoffPosition::new(527, 32, 'c', ".-3.", "3/8,3/8,3/8"),
    WyckoffPosition::new(527, 32, 'b', ".32", "1/8,1/8,1/8"),
    WyckoffPosition::new(527, 16, 'a', "23.", "0,0,0"),
    WyckoffPosition::new(528, 192, 'h', "1", "x,y,z"),
    WyckoffPosition::new(528, 96, 'g', "..2", "1/4,y,-y"),
    WyckoffPosition::new(528, 96, 'f', "2..", "x,1/8,1/8"),
    WyckoffPosition::new(528, 64, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(528, 48, 'd', "-4..", "7/8,1/8,1/8"),
    WyckoffPosition::new(528, 32, 'c', ".-3.", "0,0,0"),
    WyckoffPosition::new(528, 32, 'b', ".32", "1/4,1/4,1/4"),
    WyckoffPosition::new(528, 16, 'a', "23.", "1/8,1/8,1/8"),
    WyckoffPosition::new(529, 96, 'l', "1", "x,y,z"),
    WyckoffPosition::new(529, 48, 'k', "..m", "x,x,z"),
    WyckoffPosition::new(529, 48, 'j', "m..", "0,y,z"),
    WyckoffPosition::new(529, 48, 'i', "..2", "1/4,y,-y+1/2"),
    WyckoffPosition::new(529, 24, 'h', "m.m2", "0,y,y"),
    WyckoffPosition::new(529, 24, 'g', "mm2..", "x,0,1/2"),
    WyckoffPosition::new(529, 16, 'f', ".3m", "x,x,x"),
    WyckoffPosition::new(529, 12, 'e', "4m.m", "x,0,0"),
    WyckoffPosition::new(529, 12, 'd', "-4m.2", "1/4,0,1/2"),
    WyckoffPosition::new(529, 8, 'c', ".-3m", "1/4,1/4,1/4"),
    WyckoffPosition::new(529, 6, 'b', "4/mm.m", "0,1/2,1/2"),
    WyckoffPosition::new(529, 2, 'a', "m-3m", "0,0,0"),
    WyckoffPosition::new(530, 96, 'h', "1", "x,y,z"),
    WyckoffPosition::new(530, 48, 'g', "..2", "1/8,y,-y+1/4"),
    WyckoffPosition::new(530, 48, 'f', "2..", "x,0,1/4"),
    WyckoffPosition::new(530, 32, 'e', ".3.", "x,x,x"),
    WyckoffPosition::new(530, 24, 'd', "-4..", "3/8,0,1/4"),
    WyckoffPosition::new(530, 24, 'c', "2.22", "1/8,0,1/4"),
    WyckoffPosition::new(530, 16, 'b', ".32", "1/8,1/8,1/8"),
    WyckoffPosition::new(530, 16, 'a', ".-3.", "0,0,0"),
];

#[cfg(test)]
mod tests {
    use rstest::rstest;

    use super::WyckoffPositionSpace;
    use nalgebra::{matrix, vector};

    #[rstest]
    #[case("-y, x, z+1/2", matrix![0, -1, 0; 1, 0, 0; 0, 0, 1], vector![0.0, 0.0, 0.5])]
    #[case("x,x-y+1/4,z+1/4", matrix![1, 0, 0; 1, -1, 0; 0, 0, 1], vector![0.0, 0.25, 0.25])]
    #[case("-x+2z,y,z", matrix![-1, 0, 2; 0, 1, 0; 0, 0, 1], vector![0.0, 0.0, 0.0])]
    #[case("1/4,1/4,1/4", matrix![0, 0, 0; 0, 0, 0; 0, 0, 0], vector![0.25, 0.25, 0.25])]
    fn test_wyckoff_position_space(
        #[case] coordinates: &str,
        #[case] linear: nalgebra::Matrix3<i32>,
        #[case] origin: nalgebra::Vector3<f64>,
    ) {
        let space = WyckoffPositionSpace::new(coordinates);
        assert_eq!(space.linear, linear);
        assert_relative_eq!(space.origin, origin);
    }
}
